@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -21,9 +21,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "client.h"
 
-
-extern	struct model_s	*cl_mod_powerscreen;
-
 /*
 =========================================================================
 
@@ -101,7 +98,7 @@ void CL_ParseDelta (entity_state_t *from, entity_state_t *to, int number, int bi
 		to->modelindex3 = MSG_ReadByte (&net_message);
 	if (bits & U_MODEL4)
 		to->modelindex4 = MSG_ReadByte (&net_message);
-		
+
 	if (bits & U_FRAME8)
 		to->frame = MSG_ReadByte (&net_message);
 	if (bits & U_FRAME16)
@@ -134,7 +131,7 @@ void CL_ParseDelta (entity_state_t *from, entity_state_t *to, int number, int bi
 		to->origin[1] = MSG_ReadCoord (&net_message);
 	if (bits & U_ORIGIN3)
 		to->origin[2] = MSG_ReadCoord (&net_message);
-		
+
 	if (bits & U_ANGLE1)
 		to->angles[0] = MSG_ReadAngle(&net_message);
 	if (bits & U_ANGLE2)
@@ -268,7 +265,7 @@ void CL_ParsePacketEntities (frame_t *oldframe, frame_t *newframe)
 			if (cl_shownet->value == 3)
 				Com_Printf ("   unchanged: %i\n", oldnum);
 			CL_DeltaEntity (newframe, oldnum, oldstate, 0);
-			
+
 			oldindex++;
 
 			if (oldindex >= oldframe->num_entities)
@@ -333,7 +330,7 @@ void CL_ParsePacketEntities (frame_t *oldframe, frame_t *newframe)
 		if (cl_shownet->value == 3)
 			Com_Printf ("   unchanged: %i\n", oldnum);
 		CL_DeltaEntity (newframe, oldnum, oldstate, 0);
-		
+
 		oldindex++;
 
 		if (oldindex >= oldframe->num_entities)
@@ -524,7 +521,7 @@ void CL_ParseFrame (void)
 	// If the frame is delta compressed from data that we
 	// no longer have available, we must suck up the rest of
 	// the frame, but not use it, then ask for a non-compressed
-	// message 
+	// message
 	if (cl.frame.deltaframe <= 0)
 	{
 		cl.frame.valid = true;		// uncompressed frame
@@ -551,7 +548,7 @@ void CL_ParseFrame (void)
 			cl.frame.valid = true;	// valid delta parse
 	}
 
-	// clamp time 
+	// clamp time
 	if (cl.time > cl.frame.servertime)
 		cl.time = cl.frame.servertime;
 	else if (cl.time < cl.frame.servertime - 100)
@@ -594,7 +591,7 @@ void CL_ParseFrame (void)
 				SCR_EndLoadingPlaque ();	// get rid of loading plaque
 		}
 		cl.sound_prepped = true;	// can start mixing ambient sounds
-	
+
 		// fire entity events
 		CL_FireEntityEvents (&cl.frame);
 		CL_CheckPredictionError ();
@@ -652,13 +649,13 @@ struct model_s *S_RegisterSexedModel (entity_state_t *ent, char *base)
 				Com_sprintf (buffer, sizeof(buffer), "players/male/weapon.md2");
 				mdl = R_RegisterModel(buffer);
 			}
-		} 
+		}
 	}
 
 	return mdl;
 }
 
-// PMM - used in shell code 
+// PMM - used in shell code
 extern int Developer_searchpath (int who);
 // pmm
 /*
@@ -667,6 +664,11 @@ CL_AddPacketEntities
 
 ===============
 */
+struct model_s
+{
+	char		name[MAX_QPATH];
+};
+extern void CL_MuzzleFlashParticle (vec3_t org, vec3_t angles, qboolean from_client);
 void CL_AddPacketEntities (frame_t *frame)
 {
 	entity_t			ent;
@@ -733,7 +735,7 @@ void CL_AddPacketEntities (frame_t *frame)
 		ent.backlerp = 1.0 - cl.lerpfrac;
 
 		// create a new entity
-	
+
 		// tweak the color of beams
 		if ( renderfx & RF_BEAM )
 		{	// the four beam colors are encoded in 32 bits of skinnum (hack)
@@ -765,17 +767,17 @@ void CL_AddPacketEntities (frame_t *frame)
 				ent.model = cl.model_draw[s1->modelindex];
 			}
 		}
-		
+
 		if (renderfx & (RF_FRAMELERP|RF_BEAM))
 		{	// step origin discretely, because the frames
 			// do the animation properly
 			VectorCopy (cent->current.origin, ent.origin);
 			VectorCopy (cent->current.old_origin, ent.oldorigin);
 		}
-		else if (s1->number == cl.playernum+1) 
+		else if (s1->number == cl.playernum+1)
 		{
 			for (i=0; i<3; i++) {
-				ent.origin[i] = ent.oldorigin[i] = cent->current.origin[i] + cl.lerpfrac * 
+				ent.origin[i] = ent.oldorigin[i] = cent->current.origin[i] + cl.lerpfrac *
 					(cent->current.origin[i] - cent->prev.origin[i]);
 			}
 		}
@@ -783,7 +785,7 @@ void CL_AddPacketEntities (frame_t *frame)
 		{	// interpolate origin
 			for (i=0 ; i<3 ; i++)
 			{
-				ent.origin[i] = ent.oldorigin[i] = cent->prev.origin[i] + cl.lerpfrac * 
+				ent.origin[i] = ent.oldorigin[i] = cent->prev.origin[i] + cl.lerpfrac *
 					(cent->current.origin[i] - cent->prev.origin[i]);
 			}
 		}
@@ -804,11 +806,11 @@ void CL_AddPacketEntities (frame_t *frame)
 			ent.angles[0] = 0;
 			ent.angles[1] = autorotate;
 			ent.angles[2] = 0;
-			// bobbing items 
-			bob_scale = (0.005f + s1->number * 0.00001f) * 0.5; 
-			bob = 5 + cos( (cl.time + 1000) * bob_scale ) * 5; 
-			ent.oldorigin[2] += bob; 
-			ent.origin[2] += bob; 
+			// bobbing items
+			bob_scale = (0.005f + s1->number * 0.00001f) * 0.5;
+			bob = 5 + cos( (cl.time + 1000) * bob_scale ) * 5;
+			ent.oldorigin[2] += bob;
+			ent.origin[2] += bob;
 
 		}
 		else
@@ -832,7 +834,7 @@ void CL_AddPacketEntities (frame_t *frame)
 				VectorCopy (cl.predicted_origin, ent.origin);
 				VectorCopy (cl.predicted_origin, ent.oldorigin);
 			}
-	
+
 		}
 
 		// if set to invisible, skip
@@ -913,14 +915,21 @@ void CL_AddPacketEntities (frame_t *frame)
 
 		ci = &cl.clientinfo[s1->skinnum & 0xff];
 
-		//something isn't quite working right - we need to know if this god damn thing is a player 
-		//model - hmmm - actually checking the patch would do it!
+		//give health an "aura"
+		if(cl_healthaura->value) {
+			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex)], "models/items/healing/small/tris.md2"))
+				CL_SmallHealthParticles(ent.origin);
+			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex)], "models/items/healing/medium/tris.md2"))
+				CL_MedHealthParticles(ent.origin);
+			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex)], "models/items/healing/large/tris.md2"))
+				CL_LargeHealthParticles(ent.origin);
+		}
 
 		if (s1->modelindex2)
 		{
 			if (s1->modelindex2 == 255 || (ci->helmet && playermodel))
 			{	// custom weapon
-				
+
 				i = (s1->skinnum >> 8); // 0 is default weapon model
 				if (!cl_vwep->value || i > MAX_CLIENTWEAPONMODELS - 1)
 					i = 0;
@@ -932,85 +941,74 @@ void CL_AddPacketEntities (frame_t *frame)
 						ent.model = cl.baseclientinfo.weaponmodel[0];
 				}
 			}
-			else
-				ent.model = cl.model_draw[s1->modelindex2];
+			else {
 
-			// PMM - check for the defender sphere shell .. make it translucent
-			// replaces the previous version which used the high bit on modelindex2 to determine transparency
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/items/shell/tris.md2"))
-			{
-				ent.alpha = 0.32;
-				ent.flags = RF_TRANSLUCENT;
+				ent.model = cl.model_draw[s1->modelindex2];
 			}
-			// pmm
-				
+
+			
 			//here is where we will set the alpha for certain model parts - would like to eventually
 			//do something a little less uh, hardcoded.
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/items/quaddama/unit.md2"))
-			{
-				ent.alpha = 0.4;
-				ent.flags = RF_TRANSLUCENT;
-			}
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex)], "models/objects/blank/tris.md2"))
-			{
-				ent.alpha = 0.1;
-				ent.flags = RF_TRANSLUCENT;
-			}
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/tube/cover.md2"))
-			{
-				ent.alpha = 0.4;
-				ent.flags = RF_TRANSLUCENT;
-			}
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/receptor/bulb.md2"))
-			{
-				ent.alpha = 0.4;
-				ent.flags = RF_TRANSLUCENT;
-			}
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/electrode/cover.md2"))
-			{
-				ent.alpha = 0.4;
-				ent.flags = RF_TRANSLUCENT;
-			}
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/scope/cover.md2"))
-			{
-				ent.alpha = 0.4;
-				ent.flags = RF_TRANSLUCENT;
-			}
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/console/cover.md2"))
-			{
-				ent.alpha = 0.4;
-				ent.flags = RF_TRANSLUCENT;
-			}
 			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/items/healing/globe/tris.md2"))
 			{
 				ent.alpha = 0.4;
 				ent.flags = RF_TRANSLUCENT;
 			}
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "players/war/helmet.md2"))
+			else if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/items/quaddama/unit.md2"))
 			{
 				ent.alpha = 0.4;
 				ent.flags = RF_TRANSLUCENT;
 			}
-			if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex)], "models/objects/blank/tris.md2"))
+			else if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/tube/cover.md2"))
+			{
+				ent.alpha = 0.4;
+				ent.flags = RF_TRANSLUCENT;
+			}
+			else if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/receptor/bulb.md2"))
+			{
+				ent.alpha = 0.4;
+				ent.flags = RF_TRANSLUCENT;
+			}
+			else if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/electrode/cover.md2"))
+			{
+				ent.alpha = 0.4;
+				ent.flags = RF_TRANSLUCENT;
+			}
+			else if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/scope/cover.md2"))
+			{
+				ent.alpha = 0.4;
+				ent.flags = RF_TRANSLUCENT;
+			}
+			else if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "models/misc/console/cover.md2"))
+			{
+				ent.alpha = 0.4;
+				ent.flags = RF_TRANSLUCENT;
+			}
+			else if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex2)], "players/war/helmet.md2"))
+			{
+				ent.alpha = 0.4;
+				ent.flags = RF_TRANSLUCENT;
+			}
+			else if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex)], "models/objects/blank/tris.md2"))
 			{
 				ent.alpha = 0.1;
 				ent.flags = RF_TRANSLUCENT;
 			}
-			
+
 			if (s1->number == cl.playernum+1) {
 				ent.flags |= RF_VIEWERMODEL;
-			
+
 			}
-			
+
 			V_AddEntity (&ent);
 
 			//PGM - make sure these get reset.
 			ent.flags = 0;
 			ent.alpha = 0;
 			//PGM
-			
+
 		}
-	
+
 		if (s1->modelindex3 || (ci->helmet && playermodel))
 		{
 			if(ci->helmet && playermodel)
@@ -1021,20 +1019,19 @@ void CL_AddPacketEntities (frame_t *frame)
 			//look for clear player helmets and flag accordingly
 			strcpy(modelpath, cl.configstrings[CS_MODELS+(s1->modelindex3)]);
 			len = strlen (modelpath);
-			
+
 			i = -1;
 			strcpy(modelname, " ");
 
 			done = false;
 
-#ifdef __unix__
-			
+
 			while(!done) {
 				if(modelpath[len] == 'h')
 					done = true;
 				else {
 					modelname[i] = modelpath[len];
-				
+
 				}
 				if(len < 1)
 					done = true;
@@ -1047,28 +1044,10 @@ void CL_AddPacketEntities (frame_t *frame)
 				ent.alpha = 0.4;
 				ent.flags = RF_TRANSLUCENT;
 			}
-#else
-			while(!done) {
-				if((modelpath[len] == '/') || (modelpath[len] == '\\'))
-					done = true;
-				else {
-					modelname[i] = modelpath[len];
-				
-				}
-				if(len < 1)
-					done = true;
-				len--;
-				i++;
-			}
-			if (!Q_strcasecmp (modelname, "2dm.temleh") || ci->helmet)
-			{
-				ent.alpha = 0.4;
-				ent.flags = RF_TRANSLUCENT;
-			}
-#endif
+
 			if (s1->number == cl.playernum+1) {
 				ent.flags |= RF_VIEWERMODEL;
-			}	
+			}
 			V_AddEntity (&ent);
 		}
 
@@ -1085,28 +1064,18 @@ void CL_AddPacketEntities (frame_t *frame)
 				||!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex4)], "models/items/flags/flag2.md2"))
 				V_AddEntity (&ent);
 			else if(!ci->helmet) //because we don't want any extraneous models like brainlet
-				//gunracks or war machine riders being drawn if helmt exists, meaning that 
+				//gunracks or war machine riders being drawn if helmt exists, meaning that
 				//the entity had defaulted
 				V_AddEntity (&ent);
 		}
 
-		if ( effects & EF_POWERSCREEN )
-		{
-			ent.model = cl_mod_powerscreen;
-			ent.oldframe = 0;
-			ent.frame = 0;
-			ent.flags |= (RF_TRANSLUCENT | RF_SHELL_GREEN);
-			ent.alpha = 0.30;
-			V_AddEntity (&ent);
-		}
-
 		// add automatic particle trails
 		if ( (effects&~EF_ROTATE) )
 		{
 			if (effects & EF_ROCKET)
 			{
 				CL_RocketTrail (cent->lerp_origin, ent.origin, cent);
-				V_AddLight (ent.origin, 200, 1, 1, 0);
+				V_AddLight (ent.origin, 200, .4, .4, .1);
 			}
 			if (effects & EF_SHIPEXHAUST)
 			{
@@ -1116,14 +1085,6 @@ void CL_AddPacketEntities (frame_t *frame)
 			if (effects & EF_ROCKETEXHAUST)
 			{
 				CL_RocketExhaust (cent->lerp_origin, ent.origin, cent);
-				V_AddLight (ent.origin, 200, 1, 1, 0);
-			}
-			// PGM - Do not reorder EF_BLASTER and EF_HYPERBLASTER. 
-			// EF_BLASTER | EF_TRACKER is a special case for EF_BLASTER2... Cheese!
-			else if (effects & EF_BLASTER)
-			{
-				CL_BlasterTrail (cent->lerp_origin, ent.origin);
-				V_AddLight (ent.origin, 200, 1, 1, 0);
 			}
 			else if (effects & EF_HYPERBLASTER)
 			{
@@ -1137,21 +1098,6 @@ void CL_AddPacketEntities (frame_t *frame)
 			{
 				CL_DiminishingTrail (cent->lerp_origin, ent.origin, cent, effects);
 			}
-			else if (effects & EF_BFG)
-			{
-				static int bfg_lightramp[6] = {300, 400, 600, 300, 150, 75};
-
-				if (effects & EF_ANIM_ALLFAST)
-				{
-					CL_BfgParticles (&ent);
-					i = 200;
-				}
-				else
-				{
-					i = bfg_lightramp[s1->frame];
-				}
-				V_AddLight (ent.origin, i, 0, 1, 0);
-			}
 			else if (effects & EF_FLAG1)
 			{
 				vec3_t right;
@@ -1161,15 +1107,15 @@ void CL_AddPacketEntities (frame_t *frame)
 				AngleVectors (ent.angles, NULL, right, up);
 				VectorMA (ent.origin, 16, right, start);
 				VectorMA (start, 32, up, start);
-				CL_BlueTeamLight(start);
-				
+				CL_RedTeamLight(start);
+
 				VectorMA (ent.origin, -16, right, start);
 				VectorMA (start, 32, up, start);
-				CL_BlueTeamLight(start);
+				CL_RedTeamLight(start);
 			}
 			else if (effects & EF_FLAG2)
 			{
-				
+
 				vec3_t right;
 				vec3_t start;
 				vec3_t up;
@@ -1177,18 +1123,18 @@ void CL_AddPacketEntities (frame_t *frame)
 				AngleVectors (ent.angles, NULL, right, up);
 				VectorMA (ent.origin, 16, right, start);
 				VectorMA (start, 32, up, start);
-				CL_RedTeamLight(start);
-			
+				CL_BlueTeamLight(start);
+
 				VectorMA (ent.origin, -16, right, start);
 				VectorMA (start, 32, up, start);
-				CL_RedTeamLight(start);
+				CL_BlueTeamLight(start);
 			}
 
 			else if (effects & EF_GREENGIB)
 			{
-				CL_DiminishingTrail (cent->lerp_origin, ent.origin, cent, effects);				
+				CL_DiminishingTrail (cent->lerp_origin, ent.origin, cent, effects);
 			}
-		
+
 			else if (effects & EF_PLASMA)
 			{
 				CL_BlasterBall (cent->lerp_origin, ent.origin);
@@ -1202,20 +1148,23 @@ end:
 
 /*
 ==============
-CL_AddViewWeapon 
+CL_AddViewWeapon
 ==============
 */
+
 void CL_AddViewWeapon (player_state_t *ps, player_state_t *ops)
 {
 	entity_t	gun;		// view model
 	int			i;
 
+
 	memset (&gun, 0, sizeof(gun));
 
 	if (gun_model)
 		gun.model = gun_model;	// development tool
 	else
 		gun.model = cl.model_draw[ps->gunindex];
+
 	if (!gun.model)
 		return;
 
@@ -1242,12 +1191,18 @@ void CL_AddViewWeapon (player_state_t *ps, player_state_t *ops)
 			gun.oldframe = ops->gunframe;
 	}
 
+
 	gun.flags = RF_MINLIGHT | RF_DEPTHHACK | RF_WEAPONMODEL;
 	gun.backlerp = 1.0 - cl.lerpfrac;
 	VectorCopy (gun.origin, gun.oldorigin);	// don't lerp at all
 
-	V_AddEntity (&gun);
+	//add a muzzleflash for chaingun
+	if(!(strcmp("models/weapons/v_shotg2/tris.md2", gun.model->name))) {
+		if(gun.frame > 4 && gun.frame < 14)
+			CL_MuzzleFlashParticle(gun.origin, gun.angles, true);
+	}
 
+	V_AddEntity (&gun);
 	//add shells for viewweaps (all of em!)
 	{
 		int oldeffects = gun.flags, pnum;
@@ -1269,7 +1224,7 @@ void CL_AddViewWeapon (player_state_t *ps, player_state_t *ops)
 
 					gun.flags |= RF_TRANSLUCENT;
 					gun.alpha = 0.30;
-										
+
 					if (s1->effects & EF_COLOR_SHELL && gun.flags & (RF_SHELL_RED|RF_SHELL_BLUE|RF_SHELL_GREEN))
 					{
 						gun.skin = R_RegisterSkin ("gfx/shell.pcx");
@@ -1283,7 +1238,7 @@ void CL_AddViewWeapon (player_state_t *ps, player_state_t *ops)
 
 						V_AddEntity (&gun);
 					}
-					if (s1->effects & EF_QUAD)
+					if (s1->effects & EF_QUAD && cl_gun->value)
 					{
 						gun.skin = R_RegisterSkin ("gfx/shell_quad.pcx");
 						gun.flags = oldeffects | RF_TRANSLUCENT | RF_SHELL_BLUE;
@@ -1296,6 +1251,25 @@ void CL_AddViewWeapon (player_state_t *ps, player_state_t *ops)
 		gun.flags = oldeffects;
 	}
 
+	//add windows for vehicles
+	if(!(strcmp("vehicles/bomber/v_wep.md2", gun.model->name))) {
+		gun.model = R_RegisterModel("vehicles/bomber/window.md2");
+		gun.flags |= RF_TRANSLUCENT;
+		gun.alpha = 0.30;
+		V_AddEntity (&gun);
+	}
+	if(!(strcmp("vehicles/strafer/v_wep.md2", gun.model->name))) {
+		gun.model = R_RegisterModel("vehicles/bomber/window.md2");
+		gun.flags |= RF_TRANSLUCENT;
+		gun.alpha = 0.30;
+		V_AddEntity (&gun);
+	}
+	if(!(strcmp("vehicles/hover/v_wep.md2", gun.model->name))) {
+		gun.model = R_RegisterModel("vehicles/hover/window.md2");
+		gun.flags |= RF_TRANSLUCENT;
+		gun.alpha = 0.30;
+		V_AddEntity (&gun);
+	}
 }
 
 
@@ -1332,14 +1306,14 @@ void CL_CalcViewValues (void)
 	lerp = cl.lerpfrac;
 
 	// calculate the origin
-	if ((cl_predict->value) && !(cl.frame.playerstate.pmove.pm_flags & PMF_NO_PREDICTION))
+	if ( !cl.attractloop && !ps->stats[STAT_CHASE] && cl_predict->value && !(cl.frame.playerstate.pmove.pm_flags & PMF_NO_PREDICTION))  //not for demo/chasecam
 	{	// use predicted values
 		unsigned	delta;
 
 		backlerp = 1.0 - lerp;
 		for (i=0 ; i<3 ; i++)
 		{
-			cl.refdef.vieworg[i] = cl.predicted_origin[i] + ops->viewoffset[i] 
+			cl.refdef.vieworg[i] = cl.predicted_origin[i] + ops->viewoffset[i]
 				+ cl.lerpfrac * (ps->viewoffset[i] - ops->viewoffset[i])
 				- backlerp * cl.prediction_error[i];
 		}
@@ -1352,8 +1326,8 @@ void CL_CalcViewValues (void)
 	else
 	{	// just use interpolated values
 		for (i=0 ; i<3 ; i++)
-			cl.refdef.vieworg[i] = ops->pmove.origin[i]*0.125 + ops->viewoffset[i] 
-				+ lerp * (ps->pmove.origin[i]*0.125 + ps->viewoffset[i] 
+			cl.refdef.vieworg[i] = ops->pmove.origin[i]*0.125 + ops->viewoffset[i]
+				+ lerp * (ps->pmove.origin[i]*0.125 + ps->viewoffset[i]
 				- (ops->pmove.origin[i]*0.125 + ops->viewoffset[i]) );
 	}
 
