@@ -493,6 +493,9 @@ void CL_ParticleEffect (vec3_t org, vec3_t dir, int color, int count)
 	cparticle_t	*p;
 	float		d;
 
+	if((color == 450 || color == 550) && cl_noblood->value)
+		return;
+
 	for (i=0 ; i<count ; i++)
 	{
 		if (!(p = new_particle()))
@@ -651,6 +654,7 @@ void CL_BulletSparks (vec3_t org, vec3_t dir)
 		p->alphavel = -1.0 / (0.5 + frand()*0.3);
 	}
 }
+
 /*
 ===============
 CL_SplashEffect
@@ -667,15 +671,15 @@ void CL_SplashEffect (vec3_t org, vec3_t dir, int color, int count)
 		for( i=0; i<3; i++)
 			dir[i] *= frand()*2;
 
-		//draw a fatter particle at splash point(we should eventually place a rotated particle)
+		//draw rings that expand outward
 		if(!(p = new_particle()))
 			return;
-		p->type = PARTICLE_SPARK;
-		p->texnum = r_particletexture->texnum;
+		p->type = PARTICLE_FLAT;
+		p->texnum = r_hittexture->texnum;
 		p->blendsrc = GL_SRC_ALPHA;
 		p->blenddst = GL_ONE;
-		p->scale = 2;
-		p->scalevel = 0;
+		p->scale = 2*i;
+		p->scalevel = 8;
 		p->color = color + (rand()&2);
 		for (j=0 ; j<3 ; j++)
 		{
@@ -683,9 +687,9 @@ void CL_SplashEffect (vec3_t org, vec3_t dir, int color, int count)
 			p->vel[j] = 0;
 		}
 		p->accel[0] = p->accel[1] = p->accel[2] = 0;
-		p->alpha = .5;
+		p->alpha = .3;
 
-		p->alphavel = -1.0 / (1 + frand()*0.3);
+		p->alphavel = -0.3 / (1 + frand()*0.3);
 		
 		//shoot off small plume of water
 		for (i=0 ; i<12 ; i++)
@@ -745,7 +749,7 @@ void CL_LaserSparks (vec3_t org, vec3_t dir, int color, int count)
 		p->alpha = .5;
 
 		p->alphavel = -1.0 / (2 + frand()*0.3);
-		if (p)
+		if (p && k < 5)
 			addParticleLight (p,
 						p->scale*10, 10,
 					0, 1, 0);
@@ -827,7 +831,7 @@ void CL_ItemRespawnParticles (vec3_t org)
 
 		p->alphavel = -1.0 / (1.0 + frand()*0.3);
 
-		if (p)
+		if (p && i < 4)
 			addParticleLight (p,
 						p->scale*30, 10,
 					0, 1, 1);
@@ -891,17 +895,17 @@ void CL_ExplosionParticles (vec3_t org)
 					p->texnum = r_explosion1texture->texnum;
 					break;
 			}
-			if (p)
+			if (p && i < 3)
 				addParticleLight (p,
-						p->scale*200, 0,
-					1, 1, 0.1);
+						p->scale*100*i, 0,
+					.4, .4, 0.1);
 		}
 	}
 }
 
 /*
 ===============
-CL_MuzzleParticles
+CL_MuzzleParticles - changed this to a smoke effect in 6.06
 ===============
 */
 void CL_MuzzleParticles (vec3_t org)
@@ -914,23 +918,22 @@ void CL_MuzzleParticles (vec3_t org)
 		if (!(p = new_particle()))
 			return;
 
-		p->type = PARTICLE_BLASTER_MZFLASH;
-		p->texnum = r_bflashtexture->texnum;
-		p->scale = 4 + (rand()&7);
-		p->color = 0xe0;
-		p->blendsrc = GL_SRC_ALPHA;
-		p->blenddst = GL_ONE;
-
 		for (j=0 ; j<3 ; j++)
 		{
-			p->org[j] = org[j] + ((rand()%2)-1);
-			p->vel[j] = 0;
+			p->org[j] = org[j] + crand()*1;
+			p->vel[j] = crand()*5;
 		}
-		p->accel[0] = p->accel[1] = 0;
-		p->accel[2] = 0;
-		p->alpha = 0.4;
-
-		p->alphavel = -2.8 / (0.5 + frand()*0.3);
+				
+		p->alphavel = -1.0 / (30+frand()*1.4); //smoke lingers longer
+		p->alpha = .07;
+		p->type = PARTICLE_SMOKE; 
+		p->texnum = r_smoketexture->texnum;
+		p->blendsrc = GL_SRC_ALPHA;
+		p->blenddst = GL_ONE_MINUS_SRC_ALPHA;
+		p->scale = 1 + (rand()&4);
+		p->scalevel = 12.0;
+		p->color = 15;
+		p->accel[2] = 20;
 	}
 	
 }
@@ -971,10 +974,70 @@ void CL_BlueMuzzleParticles (vec3_t org)
 
 /*
 ===============
-CL_Leaderfield
+CL_MuzzleFlashParticle
 ===============
 */
-void CL_Leaderfield (vec3_t org)
+extern cvar_t *r_lefthand;
+void CL_MuzzleFlashParticle (vec3_t org, vec3_t angles, qboolean from_client)
+{
+	int			j;
+	cparticle_t	*p;
+	vec3_t		mflashorg, vforward, vright, vup, vec;
+	float		rightoffset, len;
+
+	if(!from_client) {
+		VectorSubtract (org, cl.refdef.vieworg, vec);
+		len = VectorNormalize (vec);
+		if(len < 128)
+			return;
+	}
+	
+	VectorCopy(org, mflashorg);
+	for (j=0 ; j<3 ; j++)
+	{
+		mflashorg[j] = mflashorg[j] + ((rand()%2)-1);
+
+	}
+
+	if(from_client) {
+		AngleVectors (angles, vforward, vright, vup);
+		
+		if (r_lefthand->value == 1.0F)
+			rightoffset = -2.4;
+		else
+			rightoffset = 2.4;
+
+		VectorMA(mflashorg, 24, vforward, mflashorg);
+		VectorMA(mflashorg, rightoffset, vright, mflashorg);
+		VectorMA(mflashorg, -2.5, vup, mflashorg);
+	}
+
+	if (!(p = new_particle()))
+		return;
+
+	p->type = PARTICLE_BLUE_MZFLASH;
+	p->texnum = r_bflashtexture->texnum;
+	p->scale = 7 + (rand()&4);
+	p->blendsrc = GL_SRC_ALPHA;
+	p->blenddst = GL_ONE;
+	for (j=0 ; j<3 ; j++)
+	{
+		p->org[j] = mflashorg[j];
+		p->vel[j] = 0;
+	}
+	p->accel[0] = p->accel[1] = 0;
+	p->accel[2] = 0;
+	p->alpha = 0.8;
+	p->color = 0xd9;
+	p->alphavel = -100;
+	
+}
+/*
+===============
+CL_SmartMuzzle
+===============
+*/
+void CL_SmartMuzzle (vec3_t org)
 {
 	int			i, j;
 	cparticle_t	*p;
@@ -1003,6 +1066,42 @@ void CL_Leaderfield (vec3_t org)
 		p->alphavel = -2.8 / (0.5 + frand()*0.3);
 	}
 	
+}
+
+/*
+===============
+CL_SmartMuzzle
+===============
+*/
+void CL_Voltage (vec3_t org)
+{
+	int			i, j;
+	cparticle_t	*p;
+
+	for ( i = 0; i < 3; i++)
+	{
+		if (!(p = new_particle()))
+			return;
+
+		p->type = PARTICLE_LEADER_FIELD;
+		p->texnum = r_voltagetexture->texnum;
+		p->scale = 14 + (rand()&14);
+		p->color = 0xff;
+		p->blendsrc = GL_SRC_ALPHA;
+		p->blenddst = GL_ONE;
+
+		for (j=0 ; j<3 ; j++)
+		{
+			p->org[j] = org[j] + ((rand()%2)-1);
+			p->vel[j] = 0;
+		}
+		p->accel[0] = p->accel[1] = 0;
+		p->accel[2] = 0;
+		p->alpha = 0.7;
+
+		p->alphavel = -2.8 / (0.5 + frand()*0.3);
+	}
+	
 }
 /*
 ===============
@@ -1097,11 +1196,10 @@ void CL_DustParticles (vec3_t org)
 		p->blendsrc = GL_SRC_ALPHA;
 		p->blenddst = GL_ONE_MINUS_SRC_ALPHA;
 		p->scale = 4 + (rand()&2);
+		p->color = 15; 
 		p->scalevel = 1.5;
 		for (j=0 ; j<3 ; j++)
 		{
-		//	p->org[j] = org[j] + ((rand()%32)-16);
-		//	p->vel[j] = (rand()%384)-192;
 			p->org[j] = org[j] + ((rand()%4)-2);
 			p->vel[j] = (rand()%88)-44;
 		}
@@ -1121,42 +1219,141 @@ CL_BigTeleportParticles
 */
 void CL_BigTeleportParticles (vec3_t org)
 {
-	int			i;
+	int			i, j;
 	cparticle_t	*p;
-	float		angle, dist;
-	static int colortable[4] = {2*8,13*8,21*8,18*8};
 
-	for (i=0 ; i<24 ; i++)
+	for (i=1 ; i<3 ; i++)
 	{
 		if (!(p = new_particle()))
 			return;
 
-		p->type = PARTICLE_BLUE_MZFLASH;//colortable[rand()&3];
-		p->texnum = r_cflashtexture->texnum;
-		p->scale = 16 + (rand()&7);
+		p->type = PARTICLE_BLUE_MZFLASH;
+		p->texnum = r_leaderfieldtexture->texnum;
+		p->scale = 16*i + (rand()&7);
 		p->blendsrc = GL_SRC_ALPHA;
 		p->blenddst = GL_ONE;
-		p->color = 0x74;
+		if(i>1)
+			p->color = 0xd4;
+		else
+			p->color = 0x74;
+		p->scalevel = 30;
+		for (j=0 ; j<3 ; j++)
+		{
+			p->org[j] = org[j];
+			p->vel[j] = 0;
+		}
 
-		angle = M_PI*2*(rand()&1023)/1023.0;
-		dist = rand()&11;
-		p->org[0] = org[0] + cos(angle)*dist;
-		p->vel[0] = cos(angle)*(20+(rand()&23));
-		p->accel[0] = -cos(angle)*30;
-
-		p->org[1] = org[1] + sin(angle)*dist;
-		p->vel[1] = sin(angle)*(20+(rand()&23));
-		p->accel[1] = -sin(angle)*100;
-
-		p->org[2] = org[2] + 8 + (rand()%40);
-		p->vel[2] = -100 + (rand()&31);
-		p->accel[2] = PARTICLE_GRAVITY*24;
+		p->accel[0] = p->accel[1] = 0;
+		p->accel[2] = 0;
 		p->alpha = 0.5;
 
-		p->alphavel = -0.6 / (0.5 + frand()*0.3);
+		p->alphavel = -0.9 / (0.5 + frand()*0.3);
 	}
 }
+/*
+===============
+CL_HealthParticles
+===============
+*/
+void CL_SmallHealthParticles (vec3_t org)
+{
+	cparticle_t	*p;
+	float		angle, dist;
 
+	if (!(p = new_particle()))
+			return;
+
+	p->type = PARTICLE_BLUE_MZFLASH;
+	p->texnum = r_cflashtexture->texnum;
+	p->scale = 10 + (rand()&7);
+	p->blendsrc = GL_SRC_ALPHA;
+	p->blenddst = GL_ONE;
+	p->color = 0xd4 + (rand() & 1);
+
+	angle = M_PI*2*(rand()&1023)/1023.0;
+	dist = rand()&5;
+	p->org[0] = org[0] + cos(angle)*dist;
+	p->vel[0] = cos(angle)*(6+(rand()&6));
+	p->accel[0] = -cos(angle)*6;
+
+	p->org[1] = org[1] + sin(angle)*dist;
+	p->vel[1] = sin(angle)*(6+(rand()&6));
+	p->accel[1] = -sin(angle)*100;
+
+	p->org[2] = org[2] + 8 + (rand()%10);
+	p->vel[2] = -10 + (rand()&6);
+	p->accel[2] = PARTICLE_GRAVITY*10;
+	p->alpha = 0.2;
+
+	p->alphavel = -2.6 / (0.5 + frand()*0.3);
+	
+}
+void CL_MedHealthParticles (vec3_t org)
+{
+	cparticle_t	*p;
+	float		angle, dist;
+
+	if (!(p = new_particle()))
+			return;
+
+	p->type = PARTICLE_BLUE_MZFLASH;
+	p->texnum = r_cflashtexture->texnum;
+	p->scale = 10 + (rand()&7);
+	p->blendsrc = GL_SRC_ALPHA;
+	p->blenddst = GL_ONE;
+	p->color = 0x74 + (rand() & 1);
+
+	angle = M_PI*2*(rand()&1023)/1023.0;
+	dist = rand()&5;
+	p->org[0] = org[0] + cos(angle)*dist;
+	p->vel[0] = cos(angle)*(6+(rand()&6));
+	p->accel[0] = -cos(angle)*6;
+
+	p->org[1] = org[1] + sin(angle)*dist;
+	p->vel[1] = sin(angle)*(6+(rand()&6));
+	p->accel[1] = -sin(angle)*100;
+
+	p->org[2] = org[2] + 8 + (rand()%10);
+	p->vel[2] = -10 + (rand()&6);
+	p->accel[2] = PARTICLE_GRAVITY*10;
+	p->alpha = 0.3;
+
+	p->alphavel = -2.6 / (0.5 + frand()*0.3);
+	
+}
+void CL_LargeHealthParticles (vec3_t org)
+{
+	cparticle_t	*p;
+	float		angle, dist;
+
+	if (!(p = new_particle()))
+			return;
+
+	p->type = PARTICLE_BLUE_MZFLASH;
+	p->texnum = r_cflashtexture->texnum;
+	p->scale = 10 + (rand()&7);
+	p->blendsrc = GL_SRC_ALPHA;
+	p->blenddst = GL_ONE;
+	p->color = 0xff + (rand() & 1);
+
+	angle = M_PI*2*(rand()&1023)/1023.0;
+	dist = rand()&5;
+	p->org[0] = org[0] + cos(angle)*dist;
+	p->vel[0] = cos(angle)*(6+(rand()&6));
+	p->accel[0] = -cos(angle)*6;
+
+	p->org[1] = org[1] + sin(angle)*dist;
+	p->vel[1] = sin(angle)*(6+(rand()&6));
+	p->accel[1] = -sin(angle)*100;
+
+	p->org[2] = org[2] + 8 + (rand()%10);
+	p->vel[2] = -10 + (rand()&6);
+	p->accel[2] = PARTICLE_GRAVITY*10;
+	p->alpha = 0.3;
+
+	p->alphavel = -2.6 / (0.5 + frand()*0.3);
+	
+}
 /*
 ===============
 CL_BlasterParticles
@@ -1257,13 +1454,11 @@ void CL_BlasterBall (vec3_t start, vec3_t end)
 	float		len;
 	int			j;
 	cparticle_t	*p;
-	int			dec;
 
 	VectorCopy (start, move);
 	VectorSubtract (end, start, vec);
 	len = VectorNormalize (vec);
 
-	dec = 5;
 	VectorScale (vec, 5, vec);
 
 	if (!(p = new_particle()))
@@ -1273,9 +1468,10 @@ void CL_BlasterBall (vec3_t start, vec3_t end)
 
 	p->alpha = 1;
 	p->alphavel = -50.0;
-	p->type = PARTICLE_SHOT;
+	p->type = PARTICLE_HIT;
 	p->texnum = r_shottexture->texnum;
 	p->scale = 8;
+
 	p->blendsrc = GL_ONE;
 	p->blenddst = GL_ONE;
 	p->color = 0x72;
@@ -1286,6 +1482,31 @@ void CL_BlasterBall (vec3_t start, vec3_t end)
 		p->accel[j] = 0;
 	}
 
+	
+	if (!(p = new_particle())) 
+		return;
+
+	VectorClear (p->accel);
+
+	p->alpha = .5;
+	p->alphavel = -50.0;
+	p->type = PARTICLE_SHOT;
+	p->texnum = r_cflashtexture->texnum;
+	p->scale = 15;
+	p->angle[1] = cl.refdef.viewangles[0];
+	p->angle[0] = sin(len);
+	p->angle[2] = cl.refdef.viewangles[2];
+
+	p->blendsrc = GL_ONE;
+	p->blenddst = GL_ONE;
+	p->color = 0x79;
+	for (j=0 ; j<3 ; j++)
+	{
+		p->org[j] = move[j];
+		p->vel[j] = 0;
+		p->accel[j] = 0;
+	}
+
 	VectorAdd (move, vec, move);
 }
 
@@ -1296,7 +1517,7 @@ Team Lights
 ===============
 */
 
-void CL_RedTeamLight(vec3_t pos)
+void CL_BlueTeamLight(vec3_t pos)
 {
 	
 	int			i,j;
@@ -1313,7 +1534,7 @@ void CL_RedTeamLight(vec3_t pos)
 		p->texnum = r_flaretexture->texnum;
 		p->blendsrc = GL_ONE;
 		p->blenddst = GL_ONE;
-		p->color = 0x72;
+		p->color = 0x74;
 		p->scale = 10*i;
 		p->alphavel = -50;
 		for (j=0 ; j<3 ; j++)
@@ -1324,7 +1545,7 @@ void CL_RedTeamLight(vec3_t pos)
 		}
 	}
 }
-void CL_BlueTeamLight(vec3_t pos)
+void CL_RedTeamLight(vec3_t pos)
 {
 	
 	int			j,i;
@@ -1369,6 +1590,9 @@ void CL_DiminishingTrail (vec3_t start, vec3_t end, centity_t *old, int flags)
 	float		orgscale;
 	float		velscale;
 
+	if (((flags & EF_GIB) || (flags & EF_GREENGIB)) && cl_noblood->value)
+		return;
+
 	VectorCopy (start, move);
 	VectorSubtract (end, start, vec);
 	len = VectorNormalize (vec);
@@ -1602,6 +1826,225 @@ void CL_RocketExhaust (vec3_t start, vec3_t end, centity_t *old)
 		VectorAdd (move, vec, move);
 	}
 }
+
+/*
+===============
+Wall Impacts
+
+===============
+*/
+
+void RotateForNormal(vec3_t normal, vec3_t result){
+	float forward, pitch, yaw;
+	
+	forward = sqrt(normal[0] * normal[0] + normal[1] * normal[1]);
+	pitch = (int)(atan2(normal[2], forward) * 180 / M_PI);
+	yaw = (int)(atan2(normal[1], normal[0]) * 180 / M_PI);
+	
+	if(pitch < 0)
+		pitch += 360;
+	
+	result[PITCH] = -pitch;
+	result[YAW] =  yaw;
+}
+void CL_BulletMarks(vec3_t org, vec3_t dir){
+	cparticle_t *p;
+	vec3_t		v;
+	int			j;
+	
+	if(!(p = new_particle()))
+		return;
+	
+	p->texnum = r_bullettexture->texnum;
+	p->color = 0 + (rand() & 1);
+	p->type = PARTICLE_DECAL;
+	p->blendsrc = GL_ZERO;
+	p->blenddst = GL_ONE_MINUS_SRC_ALPHA;
+	p->scale = .5;
+	p->scalevel = 0;
+	
+	VectorScale(dir, -1, v);
+	RotateForNormal(v, p->angle);
+	p->angle[ROLL] = rand() % 360;
+	VectorAdd(org, dir, p->org);
+	
+	p->alpha = 0.5;
+	p->alphavel = -0.2 / (2.0 + frand() * 0.3);
+	for (j=0 ; j<3 ; j++)
+	{
+			p->accel[j] = 0;
+			p->vel[j] = 0;
+	}
+}
+void CL_BeamgunMark(vec3_t org, vec3_t dir, float dur){
+	cparticle_t *p;
+	vec3_t		v;
+	int			j;
+	
+	if(!(p = new_particle()))
+		return;
+	
+	p->texnum = r_bullettexture->texnum;
+	p->color = 0xd4 + (rand() & 1);
+	p->type = PARTICLE_DECAL;
+	p->blendsrc = GL_SRC_ALPHA;
+	p->blenddst = GL_ONE;
+	p->scale = .75;
+	p->scalevel = 0;
+	
+	VectorScale(dir, -1, v);
+	RotateForNormal(v, p->angle);
+	p->angle[ROLL] = rand() % 360;
+	VectorAdd(org, dir, p->org);
+	
+	p->alpha = 0.5;
+	p->alphavel = -dur / (2.0 + frand() * 0.3);
+	for (j=0 ; j<3 ; j++)
+	{
+			p->accel[j] = 0;
+			p->vel[j] = 0;
+	}
+	if(!(p = new_particle()))
+		return;
+	
+	p->texnum = r_bullettexture->texnum;
+	p->color = 0xd4 + (rand() & 1);
+	p->type = PARTICLE_DECAL;
+	p->blendsrc = GL_SRC_ALPHA;
+	p->blenddst = GL_ONE;
+	p->scale = 1.5;
+	p->scalevel = 0;
+	
+	VectorScale(dir, -1, v);
+	RotateForNormal(v, p->angle);
+	p->angle[ROLL] = rand() % 360;
+	VectorAdd(org, dir, p->org);
+	
+	p->alpha = 0.5;
+	p->alphavel = -dur / (2.0 + frand() * 0.3);
+	for (j=0 ; j<3 ; j++)
+	{
+			p->accel[j] = 0;
+			p->vel[j] = 0;
+	}
+}
+
+void CL_BlasterMark(vec3_t org, vec3_t dir){
+	cparticle_t *p;
+	vec3_t		v;
+	int			j;
+	
+	if(!(p = new_particle()))
+		return;
+	
+	p->texnum = r_bullettexture->texnum;
+	p->color = 0x74 + (rand() & 1);
+	p->type = PARTICLE_DECAL;
+	p->blendsrc = GL_SRC_ALPHA;
+	p->blenddst = GL_ONE;
+	p->scale = .75;
+	p->scalevel = 0;
+	
+	VectorScale(dir, -1, v);
+	RotateForNormal(v, p->angle);
+	p->angle[ROLL] = rand() % 360;
+	VectorAdd(org, dir, p->org);
+	
+	p->alpha = 0.7;
+	p->alphavel = -0.4 / (2.0 + frand() * 0.3);
+	for (j=0 ; j<3 ; j++)
+	{
+			p->accel[j] = 0;
+			p->vel[j] = 0;
+	}
+	if(!(p = new_particle()))
+		return;
+	
+	p->texnum = r_bullettexture->texnum;
+	p->color = 0x74 + (rand() & 1);
+	p->type = PARTICLE_DECAL;
+	p->blendsrc = GL_SRC_ALPHA;
+	p->blenddst = GL_ONE;
+	p->scale = 1.5;
+	p->scalevel = 0;
+	
+	VectorScale(dir, -1, v);
+	RotateForNormal(v, p->angle);
+	p->angle[ROLL] = rand() % 360;
+	VectorAdd(org, dir, p->org);
+	
+	p->alpha = 0.5;
+	p->alphavel = -0.4 / (2.0 + frand() * 0.3);
+	for (j=0 ; j<3 ; j++)
+	{
+			p->accel[j] = 0;
+			p->vel[j] = 0;
+	}
+}
+
+void CL_VaporizerMarks(vec3_t org, vec3_t dir){
+	cparticle_t *p;
+	vec3_t		v, forward, right, up;
+	int			i,j;
+	float		scatter;
+
+	for(i = 0; i < 6; i ++) {
+		if(!(p = new_particle()))
+			return;
+		
+		p->texnum = r_bullettexture->texnum;
+		p->color = 0xd4 + (rand()&7);
+		p->type = PARTICLE_DECAL;
+		p->blendsrc = GL_SRC_ALPHA;
+		p->blenddst = GL_ONE;
+		p->scale = .75;
+		p->scalevel = 0;
+		
+		VectorScale(dir, -1, v);
+		RotateForNormal(v, p->angle);
+		p->angle[ROLL] = rand() % 360;
+		VectorAdd(org, dir, p->org);
+
+		AngleVectors(p->angle, forward, right, up);
+
+		scatter = ((rand()%8)-4);
+		VectorMA(p->org, scatter, up, p->org);
+		
+		p->alpha = 0.7;
+		p->alphavel = -0.4 / (2.0 + frand() * 0.3);
+		for (j=0 ; j<3 ; j++)
+		{
+				p->accel[j] = 0;
+				p->vel[j] = 0;
+		}
+		if(!(p = new_particle()))
+			return;
+		
+		p->texnum = r_bullettexture->texnum;
+		p->color = 0x74 + (rand()&7);
+		p->type = PARTICLE_DECAL;
+		p->blendsrc = GL_SRC_ALPHA;
+		p->blenddst = GL_ONE;
+		p->scale = 1.5;
+		p->scalevel = 0;
+		
+		VectorScale(dir, -1, v);
+		RotateForNormal(v, p->angle);
+		p->angle[ROLL] = rand() % 360;
+		VectorAdd(org, dir, p->org);
+
+		VectorMA(p->org, scatter, up, p->org);
+		
+		p->alpha = 0.5;
+		p->alphavel = -0.4 / (2.0 + frand() * 0.3);
+		for (j=0 ; j<3 ; j++)
+		{
+				p->accel[j] = 0;
+				p->vel[j] = 0;
+		}
+	}
+}
+
 /*
 ===============
 Particle Beams
@@ -2062,7 +2505,7 @@ void CL_NewLightning (vec3_t start, vec3_t end)
 			p->vel[j] = 0;
 			p->accel[j] = 0;
 		}
-		if (p)
+		if (p && len < 4)
 			addParticleLight (p,
 						p->scale*150, 0,
 					.25, 0, .3);
@@ -2285,68 +2728,6 @@ void CL_BubbleTrail (vec3_t start, vec3_t end)
 	}
 }
 
-/*
-===============
-CL_BfgParticles
-===============
-*/
-void CL_BfgParticles (entity_t *ent)
-{
-	int			i;
-	cparticle_t	*p;
-	float		angle;
-	float		sr, sp, sy, cr, cp, cy;
-	vec3_t		forward;
-	float		dist = 64;
-	vec3_t		v;
-	float		ltime;
-	int			beamlength = 16;
-	
-	if (!avelocities[0][0])
-	{
-		for (i=0 ; i<NUMVERTEXNORMALS*3 ; i++)
-			avelocities[0][i] = (rand()&255) * 0.01;
-	}
-
-
-	ltime = (float)cl.time / 1000.0;
-	for (i=0 ; i<NUMVERTEXNORMALS ; i++)
-	{
-		angle = ltime * avelocities[i][0];
-		sy = sin(angle);
-		cy = cos(angle);
-		angle = ltime * avelocities[i][1];
-		sp = sin(angle);
-		cp = cos(angle);
-		angle = ltime * avelocities[i][2];
-		sr = sin(angle);
-		cr = cos(angle);
-	
-		forward[0] = cp*cy;
-		forward[1] = cp*sy;
-		forward[2] = -sp;
-
-		if (!(p = new_particle()))
-			return;
-
-		dist = sin(ltime + i)*64;
-		p->org[0] = ent->origin[0] + bytedirs[i][0]*dist + forward[0]*beamlength;
-		p->org[1] = ent->origin[1] + bytedirs[i][1]*dist + forward[1]*beamlength;
-		p->org[2] = ent->origin[2] + bytedirs[i][2]*dist + forward[2]*beamlength;
-
-		VectorClear (p->vel);
-		VectorClear (p->accel);
-
-		VectorSubtract (p->org, ent->origin, v);
-		dist = VectorLength(v) / 90.0;
-		p->color = floor (0xd0 + dist * 7);
-		p->colorvel = 0;
-
-		p->alpha = 1.0 - dist;
-		p->alphavel = -100;
-	}
-}
-
 /*
 ===============
 CL_BFGExplosionParticles
@@ -2381,7 +2762,7 @@ void CL_BFGExplosionParticles (vec3_t org)
 		p->alpha = 0.4;
 
 		p->alphavel = -0.8 / (2.5 + frand()*0.3);
-		if (p)
+		if (p && i >124)
 			addParticleLight (p,
 						p->scale*60, 10,
 					0, 1, 1);
@@ -2404,8 +2785,7 @@ void CL_TeleportParticles (vec3_t start)
 	cparticle_t	*p;
 	int			i;
 	vec3_t		dir;
-	float		step = 16.0, rstep;
-	float		rot;
+	float		step = 16.0;
 
 	VectorCopy (start, move);
 	VectorCopy (start, end);
@@ -2414,39 +2794,33 @@ void CL_TeleportParticles (vec3_t start)
 	VectorSubtract (end, start, vec);
 	len = VectorNormalize (vec);
 
-	rstep = 4;
 	for (i=0 ; i<len ; i+=step)
 	{
 
-		for (rot = 0; rot < 360; rot += rstep)
-		{
-			if (!(p = new_particle()))
-				return;
+		if (!(p = new_particle()))
+			return;
+		
+		VectorClear (p->accel);
 			
-			VectorClear (p->accel);
-			
-			dir[0] = cos(rot)*20;
-			dir[1] = sin(rot)*20;
-			dir[2] = 0;
 												
-			p->alpha = 0.3;
-			p->alphavel = -1.0 / (2+frand()*0.2);
-			p->type = PARTICLE_FIREBALL;
-			p->texnum = r_explosiontexture->texnum;
-			p->blendsrc = GL_SRC_ALPHA;
-			p->blenddst = GL_ONE;
-			p->color = 0x74 + (rand()&7);
-			p->scale = 6 + (rand()&4) ;
-			p->scalevel = 0;
-			for(j = 0; j < 3; j++) {
-				p->org[j] = start[j] + dir[j];
-				p->vel[j] = 0;
-			}
-			if (p)
-			addParticleLight (p,
-						p->scale*50, 10,
-					0, 1, 1);
+		p->alpha = 0.9;
+		p->alphavel = -1.5 / (2+frand()*0.2);
+		p->type = PARTICLE_FLAT;
+		p->texnum = r_hittexture->texnum;
+		p->blendsrc = GL_ONE;
+		p->blenddst = GL_ONE;
+		p->color = 0x74 + (rand()&7);
+		p->scale = 24 + (rand()&4) ;
+		p->scalevel = 0;
+		for(j = 0; j < 3; j++) {
+			p->org[j] = start[j] + dir[j];
+			p->vel[j] = 0;
 		}
+		if (p && i < 1)
+		addParticleLight (p,
+					p->scale, 10,
+				0, 1, 1);
+		
 		start[2] += 16;
 	}
 }
