@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -59,12 +59,9 @@ cvar_t	*cl_autoskins;
 cvar_t	*cl_footsteps;
 cvar_t	*cl_timeout;
 cvar_t	*cl_predict;
-//cvar_t	*cl_minfps;
 cvar_t	*cl_maxfps;
 cvar_t	*cl_gun;
 cvar_t  *cl_showPlayerNames;
-cvar_t	*cl_nobrainlets;
-cvar_t  *enginemode;
 
 cvar_t	*cl_add_particles;
 cvar_t	*cl_add_lights;
@@ -115,9 +112,15 @@ cvar_t  *cl_master;
 cvar_t  *cl_master2;
 
 //custom huds
-cvar_t	*cl_hudimage1; 
+cvar_t	*cl_hudimage1;
 cvar_t	*cl_hudimage2;
 
+//health aura
+cvar_t	*cl_healthaura;
+
+//blood
+cvar_t  *cl_noblood;
+
 client_static_t	cls;
 client_state_t	cl;
 
@@ -148,9 +151,6 @@ typedef struct _SERVERINFO {
 	char szMapName[256];
 	int curClients;
 	int maxClients;
-#ifdef _WINDOWS
-	DWORD startPing;
-#endif
 	int	ping;
 	PLAYERINFO players[64];
 	int temporary;
@@ -158,6 +158,7 @@ typedef struct _SERVERINFO {
 
 SERVERINFO servers[64];
 int numServers = 0;
+extern unsigned int starttime;
 
 //======================================================================
 
@@ -316,7 +317,7 @@ void CL_Record_f (void)
 			buf.cursize = 0;
 		}
 
-		MSG_WriteByte (&buf, svc_spawnbaseline);		
+		MSG_WriteByte (&buf, svc_spawnbaseline);
 		MSG_WriteDeltaEntity (&nullstate, &cl_entities[i].baseline, &buf, true, true);
 	}
 
@@ -411,7 +412,7 @@ void CL_ForwardToServer_f (void)
 		Com_Printf ("Can't \"%s\", not connected\n", Cmd_Argv(0));
 		return;
 	}
-	
+
 	// don't forward the first argument
 	if (Cmd_Argc() > 1)
 	{
@@ -561,9 +562,9 @@ void CL_Connect_f (void)
 	if (Cmd_Argc() != 2)
 	{
 		Com_Printf ("usage: connect <server>\n");
-		return;	
+		return;
 	}
-	
+
 	if (Com_ServerState ())
 	{	// if running a local server, kill it and reissue
 		SV_Shutdown (va("Server quit\n", msg), false);
@@ -641,7 +642,7 @@ void CL_Rcon_f (void)
 		if (to.port == 0)
 			to.port = BigShort (PORT_SERVER);
 	}
-	
+
 	NET_SendPacket (NS_CLIENT, strlen(message)+1, message, to);
 }
 
@@ -685,7 +686,7 @@ void CL_Disconnect (void)
 	if (cl_timedemo && cl_timedemo->value)
 	{
 		int	time;
-		
+
 		time = Sys_Milliseconds () - cl.timedemo_start;
 		if (time > 0)
 			Com_Printf ("%i frames, %3.1f seconds: %3.1f fps\n", cl.timedemo_frames,
@@ -714,8 +715,11 @@ void CL_Disconnect (void)
 	CL_ClearState ();
 
 	// stop download
-	if (cls.download) {
-		fclose(cls.download);
+	if(cls.download){
+		if(cls.downloadhttp)  // clean up http downloads
+			CL_HttpDownloadCleanup();
+		else  // or just stop legacy ones
+			fclose(cls.download);
 		cls.download = NULL;
 	}
 
@@ -820,7 +824,7 @@ void CL_Reconnect_f (void)
 		Com_Printf ("reconnecting...\n");
 		cls.state = ca_connected;
 		MSG_WriteChar (&cls.netchan.message, clc_stringcmd);
-		MSG_WriteString (&cls.netchan.message, "new");		
+		MSG_WriteString (&cls.netchan.message, "new");
 		return;
 	}
 
@@ -861,7 +865,7 @@ Get a list of servers from the master
 ===================
 */
 void GetServerList (void) {
-	
+
 	char *requeststring;
 	netadr_t adr;
 
@@ -874,7 +878,7 @@ void GetServerList (void) {
 
 	// send a broadcast packet
 	Com_Printf( "querying %s...\n", cl_master->string );
-	
+
 	if( NET_StringToAdr( cl_master->string, &adr ) ) {
 		if( !adr.port )
 			adr.port = BigShort( PORT_MASTER );
@@ -895,7 +899,7 @@ Handle a reply from getservers message to master server
 void CL_ParseGetServersResponse()
 {
 	cvar_t		*noudp;
-	cvar_t		*noipx;	
+	cvar_t		*noipx;
 	netadr_t	adr;
 	char		adrString[32];
 	byte		addr[4];
@@ -941,6 +945,9 @@ void CL_ParseGetServersResponse()
 		if (++numServers == 64)
 			break;
 	}
+	//set the start time for pings
+	starttime = Sys_Milliseconds();
+
 }
 
 /*
@@ -999,8 +1006,8 @@ void CL_PingServers_f (void)
 			adr.port = BigShort(PORT_SERVER);
 
 		Netchan_OutOfBandPrint (NS_CLIENT, adr, va("status %i", PROTOCOL_VERSION));
-		
-	}	
+
+	}
 
 	// -JD restart the menu music that was stopped during this procedure
 	S_StartMusic("misc/menumusic.wav");
@@ -1022,7 +1029,7 @@ void CL_Skins_f (void)
 	{
 		if (!cl.configstrings[CS_PLAYERSKINS+i][0])
 			continue;
-		Com_Printf ("client %i: %s\n", i, cl.configstrings[CS_PLAYERSKINS+i]); 
+		Com_Printf ("client %i: %s\n", i, cl.configstrings[CS_PLAYERSKINS+i]);
 		SCR_UpdateScreen ();
 		Sys_SendKeyEvents ();	// pump message loop
 		CL_ParseClientinfo (i);
@@ -1041,7 +1048,7 @@ void CL_ConnectionlessPacket (void)
 {
 	char	*s;
 	char	*c;
-	
+
 	MSG_BeginReading (&net_message);
 	MSG_ReadLong (&net_message);	// skip the -1
 
@@ -1052,7 +1059,7 @@ void CL_ConnectionlessPacket (void)
 	c = Cmd_Argv(0);
 
 	Com_Printf ("%s: %s\n", NET_AdrToString (net_from), c);
-	
+
 	if(!strncmp(c, "servers", 7)) {
 		CL_ParseGetServersResponse();
 		return;
@@ -1068,8 +1075,14 @@ void CL_ConnectionlessPacket (void)
 		}
 		Netchan_Setup (NS_CLIENT, &cls.netchan, net_from, cls.quakePort);
 		MSG_WriteChar (&cls.netchan.message, clc_stringcmd);
-		MSG_WriteString (&cls.netchan.message, "new");	
+		MSG_WriteString (&cls.netchan.message, "new");
 		cls.state = ca_connected;
+
+		memset(cls.downloadurl, 0, sizeof(cls.downloadurl));
+		if(Cmd_Argc() == 2)  // http download url
+		{
+			strncpy(cls.downloadurl, Cmd_Argv(1), sizeof(cls.downloadurl) - 1);
+		}
 		return;
 	}
 
@@ -1195,7 +1208,7 @@ void CL_ReadPackets (void)
 	}
 	else
 		cl.timeoutcount = 0;
-	
+
 }
 
 
@@ -1292,6 +1305,8 @@ void CL_RequestNextDownload (void)
 			if (!CL_CheckOrDownloadFile(cl.configstrings[CS_MODELS+1]))
 				return; // started a download
 	}
+
+redoSkins:;
 	if (precache_check >= CS_MODELS && precache_check < CS_MODELS+MAX_MODELS) {
 		if (allow_download_models->value) {
 			while (precache_check < CS_MODELS+MAX_MODELS &&
@@ -1338,14 +1353,14 @@ void CL_RequestNextDownload (void)
 
 				while (precache_model_skin - 1 < LittleLong(pheader->num_skins)) {
 					if (!CL_CheckOrDownloadFile((char *)precache_model +
-						LittleLong(pheader->ofs_skins) + 
+						LittleLong(pheader->ofs_skins) +
 						(precache_model_skin - 1)*MAX_SKINNAME)) {
 						precache_model_skin++;
 						return; // started a download
 					}
 					precache_model_skin++;
 				}
-				if (precache_model) { 
+				if (precache_model) {
 					FS_FreeFile(precache_model);
 					precache_model = 0;
 				}
@@ -1353,9 +1368,16 @@ void CL_RequestNextDownload (void)
 				precache_check++;
 			}
 		}
+		if (precache_model)
+		{
+			precache_check = CS_MODELS + 2;
+			precache_model_skin = 0;
+
+			goto redoSkins;
+		}
 		precache_check = CS_SOUNDS;
 	}
-	if (precache_check >= CS_SOUNDS && precache_check < CS_SOUNDS+MAX_SOUNDS) { 
+	if (precache_check >= CS_SOUNDS && precache_check < CS_SOUNDS+MAX_SOUNDS) {
 		if (allow_download_sounds->value) {
 			if (precache_check == CS_SOUNDS)
 				precache_check++; // zero is blank
@@ -1477,13 +1499,13 @@ void CL_RequestNextDownload (void)
 			return;
 		}
 	}
-	
+
 	if (precache_check > ENV_CNT && precache_check < TEXTURE_CNT) {
 			if (allow_download->value && allow_download_maps->value) {
 				while (precache_check < TEXTURE_CNT) {
 					int n = precache_check++ - ENV_CNT - 1;
 
-					Com_sprintf(fn, sizeof(fn), "env/%s%s.tga", 
+					Com_sprintf(fn, sizeof(fn), "env/%s%s.tga",
 							cl.configstrings[CS_SKY], env_suf[n/2]);
 					if (!CL_CheckOrDownloadFile(fn))
 						return; // started a download
@@ -1565,6 +1587,8 @@ void CL_InitLocal (void)
 
 	CL_InitInput ();
 
+	CL_InitHttpDownload();
+
 	adr0 = Cvar_Get( "adr0", "", CVAR_ARCHIVE );
 	adr1 = Cvar_Get( "adr1", "", CVAR_ARCHIVE );
 	adr2 = Cvar_Get( "adr2", "", CVAR_ARCHIVE );
@@ -1592,11 +1616,10 @@ void CL_InitLocal (void)
 	cl_noskins = Cvar_Get ("cl_noskins", "0", CVAR_ARCHIVE);
 	cl_autoskins = Cvar_Get ("cl_autoskins", "0", 0);
 	cl_predict = Cvar_Get ("cl_predict", "1", 0);
-//	cl_minfps = Cvar_Get ("cl_minfps", "5", 0);
 	cl_maxfps = Cvar_Get ("cl_maxfps", "90", CVAR_ARCHIVE);
 	cl_showPlayerNames = Cvar_Get ("cl_showplayernames", "0", CVAR_ARCHIVE);
-	cl_nobrainlets = Cvar_Get ("cl_nobrainlets", "0", CVAR_ARCHIVE);
-	enginemode = Cvar_Get ("enginemode", "0", CVAR_ARCHIVE);
+	cl_healthaura = Cvar_Get ("cl_healthaura", "1", CVAR_ARCHIVE);
+	cl_noblood = Cvar_Get ("cl_noblood", "0", CVAR_ARCHIVE);
 
 	cl_upspeed = Cvar_Get ("cl_upspeed", "200", 0);
 	cl_forwardspeed = Cvar_Get ("cl_forwardspeed", "200", 0);
@@ -1712,6 +1735,23 @@ void CL_InitLocal (void)
 	Cvar_SetValue("scriptsloaded", 0);
 
 	strcpy(map_music, "music/none.wav");
+
+	//register all our menu gfx
+	R_RegisterPic("m_main");
+	R_RegisterPic("m_options");
+	R_RegisterPic("m_options_back");
+	R_RegisterPic("m_video");
+	R_RegisterPic("m_controls");
+	R_RegisterPic("m_controls_back");
+	R_RegisterPic("m_player");
+	R_RegisterPic("m_player_back");
+	R_RegisterPic("m_bots");
+	R_RegisterPic("m_startserver");
+	R_RegisterPic("m_startserver_back");
+	R_RegisterPic("m_dmoptions");
+	R_RegisterPic("m_mutators");
+	R_RegisterPic("m_single");
+	R_RegisterPic("m_quit");
 }
 
 
@@ -1770,9 +1810,7 @@ cheatvar_t	cheatvars[] = {
 	{"r_drawflat", "0"},
 	{"paused", "0"},
 	{"fixedtime", "0"},
-	{"sw_draworder", "0"},
 	{"gl_lightmap", "0"},
-	{"gl_saturatelighting", "0"},
 	{NULL, NULL}
 };
 
@@ -1783,7 +1821,7 @@ void CL_FixCvarCheats (void)
 	int			i;
 	cheatvar_t	*var;
 
-	if ( !strcmp(cl.configstrings[CS_MAXCLIENTS], "1") 
+	if ( !strcmp(cl.configstrings[CS_MAXCLIENTS], "1")
 		|| !cl.configstrings[CS_MAXCLIENTS][0] )
 		return;		// single player can cheat
 
@@ -1844,6 +1882,8 @@ CL_Frame
 
 ==================
 */
+qboolean send_packet_now = false;  // instant packets, like firing weapons
+
 void CL_Frame (int msec)
 {
 	static int	extratime;
@@ -1858,9 +1898,11 @@ void CL_Frame (int msec)
 	{
 		if (cls.state == ca_connected && extratime < 100)
 			return;			// don't flood packets out while connecting
-		if (extratime < 1000/cl_maxfps->value)
+		if (extratime < 1000/cl_maxfps->value && !send_packet_now)
 			return;			// framerate is too high
 	}
+	if(send_packet_now)
+		send_packet_now = false;
 
 	// let the mouse activate or deactivate
 	IN_Frame ();
@@ -1871,13 +1913,9 @@ void CL_Frame (int msec)
 	cls.realtime = curtime;
 
 	extratime = 0;
-#if 0
-	if (cls.frametime > (1.0 / cl_minfps->value))
-		cls.frametime = (1.0 / cl_minfps->value);
-#else
+
 	if (cls.frametime > (1.0 / 5))
 		cls.frametime = (1.0 / 5);
-#endif
 
 	// if in the debugger last frame, don't timeout
 	if (msec > 5000)
@@ -1886,6 +1924,9 @@ void CL_Frame (int msec)
 	// fetch results from server
 	CL_ReadPackets ();
 
+	// run http downloads
+	CL_HttpDownloadThink();
+
 	// send a new command message to the server
 	CL_SendCommand ();
 
@@ -1906,8 +1947,6 @@ void CL_Frame (int msec)
 
 	// update audio
 	S_Update (cl.refdef.vieworg, cl.v_forward, cl.v_right, cl.v_up);
-	
-	CDAudio_Update();
 
 	// advance local effects for next frame
 	CL_RunDLights ();
@@ -1940,6 +1979,8 @@ void CL_Frame (int msec)
 }
 
 
+
+
 //============================================================================
 
 /*
@@ -1954,26 +1995,25 @@ void CL_Init (void)
 
 	// all archived variables will now be loaded
 
-	Con_Init ();	
+	Con_Init ();
 #if defined __unix__ || defined __sgi
-	S_Init ();	
+	S_Init ();
 	VID_Init ();
 #else
 	VID_Init ();
 	S_Init ();	// sound must be initialized after window is created
 #endif
-	
+
 	V_Init ();
-	
+
 	net_message.data = net_message_buffer;
 	net_message.maxsize = sizeof(net_message_buffer);
 
-	M_Init ();	
-	
+	M_Init ();
+
 	SCR_Init ();
 	cls.disable_screen = true;	// don't draw yet
 
-	CDAudio_Init ();
 	CL_InitLocal ();
 	IN_Init ();
 
@@ -1995,7 +2035,7 @@ to run quit through here before the final handoff to the sys code.
 void CL_Shutdown(void)
 {
 	static qboolean isdown = false;
-	
+
 	if (isdown)
 	{
 		printf ("recursive shutdown\n");
@@ -2003,9 +2043,9 @@ void CL_Shutdown(void)
 	}
 	isdown = true;
 
-	CL_WriteConfiguration (); 
+	CL_ShutdownHttpDownload();
+	CL_WriteConfiguration ();
 
-	CDAudio_Shutdown ();
 	S_Shutdown();
 	IN_Shutdown ();
 	VID_Shutdown();
