@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -39,7 +39,7 @@ char *svc_strings[256] =
 	"svc_stufftext",
 	"svc_serverdata",
 	"svc_configstring",
-	"svc_spawnbaseline",	
+	"svc_spawnbaseline",
 	"svc_centerprint",
 	"svc_download",
 	"svc_playerinfo",
@@ -88,16 +88,17 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 	FILE *fp;
 	char	name[MAX_OSPATH];
 	char	shortname[MAX_OSPATH];
+	qboolean	modelskin = false;
 
 	if (strstr (filename, ".."))
 	{
 		Com_Printf ("Refusing to download a path with ..\n");
 		return true;
 	}
-
-	//if pcx, strip extension and change to .tga, we never dl .pcx anymore
+	
+    //if pcx, strip extension and change to .tga, we never dl .pcx anymore
     if(filename[strlen(filename)-1] == 'x') {
-
+		modelskin = true;
 		//if this is coming from a player model don't bother
 		if(filename[0] != 'm' && filename[0] != 'v')
 			return true;
@@ -105,13 +106,11 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 		sprintf(filename, "%s.tga", shortname);
 	}
 
+
 	if (FS_LoadFile (filename, NULL) != -1)
 	{	// it exists, no need to download
 		return true;
 	}
-
-//		return true; //we don't want to download anything in single player mode, period.
-
 	strcpy (cls.downloadname, filename);
 
 	// download to a temp name, and only rename
@@ -120,6 +119,12 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 	COM_StripExtension (cls.downloadname, cls.downloadtempname);
 	strcat (cls.downloadtempname, ".tmp");
 
+	// attempt an http download if available(never try to dl game model skins here)
+	if(!modelskin) {
+		if(cls.downloadurl[0] && CL_HttpDownload())  
+			return false;
+	}
+
 //ZOID
 	// check to see if we already have a tmp for this file, if so, try to resume
 	// open the file if not opened yet
@@ -149,6 +154,7 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 
 	cls.downloadnumber++;
 
+	send_packet_now = true;
 	return false;
 }
 
@@ -236,9 +242,14 @@ void CL_ParseDownload (void)
 	// read the data
 	size = MSG_ReadShort (&net_message);
 	percent = MSG_ReadByte (&net_message);
-	if (size == -1)
+	if (size < 0) //fix issues with bad data being dl'd
 	{
-		Com_Printf ("Server does not have this file.\n");
+		Com_Printf ("Server does not have file %s.\n", cls.downloadname);
+		
+		//nuke the temp filename, we don't want that getting left around.
+		cls.downloadtempname[0] = 0;
+		cls.downloadname[0] = 0;
+
 		if (cls.download)
 		{
 			// if here, we tried to resume a file but the server said no
@@ -255,7 +266,7 @@ void CL_ParseDownload (void)
 		CL_DownloadFileName(name, sizeof(name), cls.downloadtempname);
 
 		FS_CreatePath (name);
-
+ 
 		cls.download = fopen (name, "wb");
 		if (!cls.download)
 		{
@@ -272,19 +283,11 @@ void CL_ParseDownload (void)
 	if (percent != 100)
 	{
 		// request next block
-// change display routines by zoid
-#if 0
-		Com_Printf (".");
-		if (10*(percent/10) != cls.downloadpercent)
-		{
-			cls.downloadpercent = 10*(percent/10);
-			Com_Printf ("%i%%", cls.downloadpercent);
-		}
-#endif
 		cls.downloadpercent = percent;
 
 		MSG_WriteByte (&cls.netchan.message, clc_stringcmd);
 		SZ_Print (&cls.netchan.message, "nextdl");
+		send_packet_now = true;
 	}
 	else
 	{
@@ -330,7 +333,7 @@ void CL_ParseServerData (void)
 	extern cvar_t	*fs_gamedirvar;
 	char	*str;
 	int		i;
-	
+
 	Com_DPrintf ("Serverdata packet received.\n");
 //
 // wipe the client_state_t struct
@@ -461,13 +464,6 @@ void CL_LoadClientinfo (clientinfo_t *ci, char *s)
 			t = model_name;
 		*t = 0;
 
-		if(cl_nobrainlets->value) {  //show them as a martian enforcer instead.
-			if(!strcmp("brainlet", model_name)) {
-				strcpy(model_name, "martianenforcer");
-				ci->helmet = R_RegisterModel("players/martianenforcer/helmet.md2");
-			}
-		}
-
 		// isolate the skin name
 		strcpy (skin_name, s + strlen(model_name) + 1);
 
@@ -520,7 +516,7 @@ void CL_LoadClientinfo (clientinfo_t *ci, char *s)
 		ci->weaponmodel[0] = NULL;
 		return;
 	}
-	
+
 }
 
 /*
@@ -588,15 +584,10 @@ void CL_ParseConfigString (void)
 		strcpy (cl.configstrings[i], s);
 	}
 
-	// do something apropriate 
+	// do something apropriate
 
 	if (i >= CS_LIGHTS && i < CS_LIGHTS+MAX_LIGHTSTYLES)
 		CL_SetLightstyle (i - CS_LIGHTS);
-	else if (i == CS_CDTRACK)
-	{
-		if (cl.refresh_prepped)
-			CDAudio_Play (atoi(cl.configstrings[CS_CDTRACK]), true);
-	}
 	else if (i >= CS_MODELS && i < CS_MODELS+MAX_MODELS)
 	{
 		if (cl.refresh_prepped)
@@ -646,7 +637,7 @@ void CL_ParseStartSoundPacket(void)
     int 	channel, ent;
     int 	sound_num;
     float 	volume;
-    float 	attenuation;  
+    float 	attenuation;
 	int		flags;
 	float	ofs;
 
@@ -657,11 +648,11 @@ void CL_ParseStartSoundPacket(void)
 		volume = MSG_ReadByte (&net_message) / 255.0;
 	else
 		volume = DEFAULT_SOUND_PACKET_VOLUME;
-	
+
     if (flags & SND_ATTENUATION)
 		attenuation = MSG_ReadByte (&net_message) / 64.0;
 	else
-		attenuation = DEFAULT_SOUND_PACKET_ATTENUATION;	
+		attenuation = DEFAULT_SOUND_PACKET_ATTENUATION;
 
     if (flags & SND_OFFSET)
 		ofs = MSG_ReadByte (&net_message) / 1000.0;
@@ -670,7 +661,7 @@ void CL_ParseStartSoundPacket(void)
 
 	if (flags & SND_ENT)
 	{	// entity reletive
-		channel = MSG_ReadShort(&net_message); 
+		channel = MSG_ReadShort(&net_message);
 		ent = channel>>3;
 		if (ent > MAX_EDICTS)
 			Com_Error (ERR_DROP,"CL_ParseStartSoundPacket: ent = %i", ent);
@@ -686,7 +677,7 @@ void CL_ParseStartSoundPacket(void)
 	if (flags & SND_POS)
 	{	// positioned in space
 		MSG_ReadPos (&net_message, pos_v);
- 
+
 		pos = pos_v;
 	}
 	else	// use entity number
@@ -696,7 +687,7 @@ void CL_ParseStartSoundPacket(void)
 		return;
 
 	S_StartSound (pos, ent, channel, cl.sound_precache[sound_num], volume, attenuation, ofs);
-}       
+}
 
 
 void SHOWNET(char *s)
@@ -750,29 +741,32 @@ void CL_ParseServerMessage (void)
 			else
 				SHOWNET(svc_strings[cmd]);
 		}
-	
+
 	// other commands
 		switch (cmd)
 		{
 		default:
 			Com_Error (ERR_DROP,"CL_ParseServerMessage: Illegible server message\n");
 			break;
-			
+
 		case svc_nop:
 //			Com_Printf ("svc_nop\n");
 			break;
-			
+
 		case svc_disconnect:
 			Com_Error (ERR_DISCONNECT,"Server disconnected\n");
 			break;
 
 		case svc_reconnect:
 			Com_Printf ("Server disconnected, reconnecting\n");
-			if (cls.download) {
-				//ZOID, close download
-				fclose (cls.download);
-				cls.download = NULL;
-			}
+			// stop download
+				if(cls.download){
+					if(cls.downloadhttp)  // clean up http downloads
+						CL_HttpDownloadCleanup();
+					else  // or just stop legacy ones
+						fclose(cls.download);
+					cls.download = NULL;
+				}
 			cls.state = ca_connecting;
 			cls.connect_time = -99999;	// CL_CheckForResend() will fire immediately
 			break;
@@ -787,30 +781,30 @@ void CL_ParseServerMessage (void)
 			Com_Printf ("%s", MSG_ReadString (&net_message));
 			con.ormask = 0;
 			break;
-			
+
 		case svc_centerprint:
 			SCR_CenterPrint (MSG_ReadString (&net_message));
 			break;
-			
+
 		case svc_stufftext:
 			s = MSG_ReadString (&net_message);
 			Com_DPrintf ("stufftext: %s\n", s);
 			Cbuf_AddText (s);
 			break;
-			
+
 		case svc_serverdata:
 			Cbuf_Execute ();		// make sure any stuffed commands are done
 			CL_ParseServerData ();
 			break;
-			
+
 		case svc_configstring:
 			CL_ParseConfigString ();
 			break;
-			
+
 		case svc_sound:
 			CL_ParseStartSoundPacket();
 			break;
-			
+
 		case svc_spawnbaseline:
 			CL_ParseBaseline ();
 			break;
