@@ -142,7 +142,7 @@ void debug_printf(char *fmt, ...)
 	va_end (argptr);
 
 	if (dedicated->value)
-		gi.cprintf(NULL, PRINT_MEDIUM, bigbuffer);
+		gi.cprintf(NULL, PRINT_MEDIUM, "%s", bigbuffer);
 
 	for (i=0 ; i<maxclients->value ; i++)
 	{
@@ -150,7 +150,7 @@ void debug_printf(char *fmt, ...)
 		if (!cl_ent->inuse || cl_ent->is_bot)
 			continue;
 
-		gi.cprintf(cl_ent,  PRINT_MEDIUM, bigbuffer);
+		gi.cprintf(cl_ent,  PRINT_MEDIUM, "%s", bigbuffer);
 	}
 
 }
@@ -171,7 +171,7 @@ void safe_cprintf (edict_t *ent, int printlevel, char *fmt, ...)
 	len = vsprintf (bigbuffer,fmt,argptr);
 	va_end (argptr);
 
-	gi.cprintf(ent, printlevel, bigbuffer);
+	gi.cprintf(ent, printlevel, "%s", bigbuffer);
 	
 }
 
@@ -211,7 +211,7 @@ void safe_bprintf (int printlevel, char *fmt, ...)
 	va_end (argptr);
 
 	if (dedicated->value)
-		gi.cprintf(NULL, printlevel, bigbuffer);
+		gi.cprintf(NULL, printlevel, "%s", bigbuffer);
 
 	for (i=0 ; i<maxclients->value ; i++)
 	{
@@ -219,7 +219,7 @@ void safe_bprintf (int printlevel, char *fmt, ...)
 		if (!cl_ent->inuse || cl_ent->is_bot)
 			continue;
 
-		gi.cprintf(cl_ent, printlevel, bigbuffer);
+		gi.cprintf(cl_ent, printlevel, "%s", bigbuffer);
 	}
 }
 
