@@ -116,7 +116,7 @@ void ACESP_LoadBots(edict_t *ent, int playerleft)
 {
     FILE *pIn;
 	char userinfo[MAX_INFO_STRING];
-	int i, j, count;
+	int i, j, count, spawnkicknum;
 	char *info;
 	char *skin;
 	char bot_filename[128];
@@ -142,24 +142,37 @@ void ACESP_LoadBots(edict_t *ent, int playerleft)
 		return; // don't load any preconfigured bots.
 	}
 
+	if(g_duel->value) {
+		count = 1; //never more than 1 bot no matter what in duel mode
+		spawnkicknum = 2;
+	}
+	else if(sv_botkickthreshold->integer)
+		spawnkicknum = sv_botkickthreshold->integer;
+	else
+		spawnkicknum = 0;
+	
 	ent->client->resp.botnum = 0;
 
 	//probably want to count total REAL players here...
 	real_players = 0;
 
-	if(sv_botkickthreshold->integer) { //test for now
+	if(spawnkicknum) { //test for now
 		for (i=0 ; i<game.maxclients ; i++)
 		{
 			cl_ent = g_edicts + 1 + i;
 			if (cl_ent->inuse && !cl_ent->is_bot){
 				cl_ent->client->resp.botnum = 0;
-				if(!game.clients[i].resp.spectator)
+				if(g_duel->value) 
+					real_players++;
+				else if(!game.clients[i].resp.spectator)
 					real_players++;
 			}
 		}
 	}
 	real_players -= playerleft; //done for when this is called as a player is disconnecting
 	
+	
+
 	total_players = 0;
 	for(i=0;i<count;i++)
 	{
@@ -173,35 +186,35 @@ void ACESP_LoadBots(edict_t *ent, int playerleft)
 
 		strcpy(ent->client->resp.bots[i].name, info);
 
-		if(sv_botkickthreshold->integer) { 
+		if(spawnkicknum) { 
 				for (j=0 ; j<game.maxclients ; j++)
 				{
 					cl_ent = g_edicts + 1 + j;
 					if (cl_ent->inuse) {
-						if(total_players <= sv_botkickthreshold->integer) //we actually added one
+						if(total_players <= spawnkicknum) //we actually added one
 							cl_ent->client->resp.botnum = i+1;
 						cl_ent->client->ps.botnum = cl_ent->client->resp.botnum;
 						strcpy(cl_ent->client->ps.bots[i].name, info);
 					}
 				}
 		}
-		else
+		else {
 			ent->client->resp.botnum++;
+		}
         
 		//look for existing bots of same name, so that server doesn't fill up with bots
 		//when clients enter the game
 		found = false;
 		found = ACESP_FindBot(info);
 
-		if(!found && ((total_players <= sv_botkickthreshold->integer) || !sv_botkickthreshold->integer)) { 
+		if(!found && ((total_players <= spawnkicknum) || !spawnkicknum)) { 
 
 			if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value) 
 				ACESP_SpawnBot(NULL, info, skin, NULL); //we may be changing the info further on
 			else 
-				ACESP_SpawnBot (NULL, NULL, NULL, userinfo);
-			
+				ACESP_SpawnBot (NULL, NULL, NULL, userinfo);			
 		}
-		else if(found && ((total_players > sv_botkickthreshold->integer) && sv_botkickthreshold->integer)) 
+		else if(found && ((total_players > spawnkicknum) && spawnkicknum)) 
 			ACESP_KickBot(info);
 		
 	}
@@ -368,6 +381,8 @@ void ACESP_PutClientInServer (edict_t *bot, qboolean respawn, int team)
 	// clear entity values
 	bot->groundentity = NULL;
 	bot->client = &game.clients[index];
+	if(g_spawnprotect->value)
+		bot->client->spawnprotected = true;
 	bot->takedamage = DAMAGE_AIM;
 	bot->movetype = MOVETYPE_WALK;
 	bot->viewheight = 24;
@@ -445,7 +460,7 @@ void ACESP_PutClientInServer (edict_t *bot, qboolean respawn, int team)
 	}
 	playermodel[i-1] = 0;
 
-	sprintf(modelpath, "data1/players/%s/helmet.md2", playermodel);
+	sprintf(modelpath, "players/%s/helmet.md2", playermodel);
 	Q2_FindFile (modelpath, &file); //does a helmet exist?
 	if(file) {
 		sprintf(modelpath, "players/%s/helmet.md2", playermodel);
@@ -466,7 +481,7 @@ void ACESP_PutClientInServer (edict_t *bot, qboolean respawn, int team)
 
 	//check for class file
 	bot->ctype = 0;
-	sprintf(modelpath, "data1/players/%s/human", playermodel);
+	sprintf(modelpath, "players/%s/human", playermodel);
 	Q2_FindFile (modelpath, &file);
 	if(file) { //human
 		bot->ctype = 1;
@@ -483,7 +498,7 @@ void ACESP_PutClientInServer (edict_t *bot, qboolean respawn, int team)
 		fclose(file);
 	}
 	else {
-		sprintf(modelpath, "data1/players/%s/robot", playermodel);
+		sprintf(modelpath, "players/%s/robot", playermodel);
 		Q2_FindFile (modelpath, &file);
 		if(file) { //robot
 			bot->ctype = 2;
@@ -597,6 +612,7 @@ void ACESP_PutClientInServer (edict_t *bot, qboolean respawn, int team)
 		gi.WriteByte (MZ_LOGIN);
 		gi.multicast (bot->s.origin, MULTICAST_PVS);
 	}
+	client->spawnprotecttime = level.time;
 	
 }
 
@@ -766,9 +782,10 @@ void ACESP_SetName(edict_t *bot, char *name, char *skin, char *team)
 ///////////////////////////////////////////////////////////////////////
 void ACESP_SpawnBot (char *team, char *name, char *skin, char *userinfo)
 {
-	edict_t *bot;
+	edict_t *bot, *cl_ent;
 	char *info;
 	char sound[64];
+	int	i;
 
 	bot = ACESP_FindFreeClient ();
 
@@ -777,7 +794,7 @@ void ACESP_SpawnBot (char *team, char *name, char *skin, char *userinfo)
 		safe_bprintf (PRINT_MEDIUM, "Server is full, increase Maxclients.\n");
 		return;
 	}
-
+	
 	bot->yaw_speed = 100; // yaw speed
 	bot->inuse = true;
 	bot->is_bot = true;
@@ -807,6 +824,14 @@ void ACESP_SpawnBot (char *team, char *name, char *skin, char *userinfo)
 
 	InitClientResp (bot->client);
 
+	game.num_bots = 0;
+	for (i=0; i<game.maxclients ; i++) //this is a more safe way to do this, ensuring we have perfect numbers
+	{
+		cl_ent = g_edicts + 1 + i;
+		if (cl_ent->inuse && cl_ent->is_bot)
+			game.num_bots++;
+	}
+
 	//play sound announcing arrival of bot
 	info = Info_ValueForKey (bot->client->pers.userinfo, "name");
 	sprintf(sound, "bots/%s.wav", info);
@@ -814,6 +839,11 @@ void ACESP_SpawnBot (char *team, char *name, char *skin, char *userinfo)
 
 	ACESP_PutClientInServer (bot,false,0);
 
+	if(g_duel->value) {
+		ClientPlaceInQueue(bot);
+		ClientCheckQueue(bot);
+	}
+
 	// make sure all view stuff is valid
 	ClientEndServerFrame (bot);
 
@@ -851,6 +881,8 @@ void ACESP_RemoveBot(char *name)
 
 	if(!freed)	
 		safe_bprintf (PRINT_MEDIUM, "%s not found\n", name);
+	else
+		game.num_bots--;
 	
 	ACESP_SaveBots(); // Save them again
 }
@@ -878,7 +910,7 @@ int ACESP_FindBot(char *name)
 
 void ACESP_KickBot(char *name)
 {
-	int i;
+	int i,j;
 	qboolean freed=false;
 	edict_t *bot;
 
@@ -925,11 +957,24 @@ void ACESP_KickBot(char *name)
 			if(freed) {
 				bot->client->resp.botnum--; //we have one less bot
 				bot->client->ps.botnum = bot->client->resp.botnum;
-			}
+			
 
+				//if in duel mode, we need to bump people down the queue if its the player in game leaving
+	
+				if(g_duel->value) if(g_duel->value) { 
+					MoveClientsDownQueue(bot);
+					if(!bot->client->resp.spectator) {
+						for (j = 0; j < maxclients->value; j++)  //clear scores if player was in duel
+							if(g_edicts[j+1].inuse && g_edicts[j+1].client && !g_edicts[j+1].is_bot)
+								g_edicts[j+1].client->resp.score = 0;
+					}
+				}
+			}
 		}
 	}
 
-	if(!freed)	
+	if(!freed)
 		safe_bprintf (PRINT_MEDIUM, "%s not found\n", name);
+	else
+		game.num_bots--;
 }
