@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -36,13 +36,6 @@ char *ClientTeam (edict_t *ent)
 	if (!p)
 		return value;
 
-	if ((int)(dmflags->value) & DF_MODELTEAMS)
-	{
-		*p = 0;
-		return value;
-	}
-
-	// if ((int)(dmflags->value) & DF_SKINTEAMS)
 	return ++p;
 }
 
@@ -51,7 +44,7 @@ qboolean OnSameTeam (edict_t *ent1, edict_t *ent2)
 	char	ent1Team [512];
 	char	ent2Team [512];
 
-	if ((!((int)(dmflags->value) & (DF_MODELTEAMS | DF_SKINTEAMS))) && !ctf->value && !tca->value && !cp->value)
+	if ((!((int)(dmflags->value) & (DF_SKINTEAMS))) && !ctf->value && !tca->value && !cp->value)
 		return false;
 
 	strcpy (ent1Team, ClientTeam (ent1));
@@ -205,7 +198,7 @@ void Cmd_Give_f (edict_t *ent)
 				continue;
 			if (!(it->flags & IT_AMMO))
 				continue;
-			Add_Ammo (ent, it, 1000);
+			Add_Ammo (ent, it, 1000, true, true);
 		}
 		if (!give_all)
 			return;
@@ -229,20 +222,6 @@ void Cmd_Give_f (edict_t *ent)
 			return;
 	}
 
-	if (give_all || Q_stricmp(name, "Power Shield") == 0)
-	{
-		it = FindItem("Power Shield");
-		it_ent = G_Spawn();
-		it_ent->classname = it->classname;
-		SpawnItem (it_ent, it);
-		Touch_Item (it_ent, ent, NULL, NULL);
-		if (it_ent->inuse)
-			G_FreeEdict(it_ent);
-
-		if (!give_all)
-			return;
-	}
-
 	if (give_all)
 	{
 		for (i=0 ; i<game.num_items ; i++)
@@ -303,7 +282,7 @@ void Cmd_Give_f (edict_t *ent)
 		if (it_ent->inuse)
 			G_FreeEdict(it_ent);
 	}
-	
+
 }
 
 
@@ -806,12 +785,15 @@ void Cmd_Say_f (edict_t *ent, qboolean team, qboolean arg0)
 	if (gi.argc () < 2 && !arg0)
 		return;
 
+	if (strlen(gi.args()) < 3) //no text, don't send
+		return;
+
 	gi.WriteByte (svc_temp_entity);
 	gi.WriteByte (TE_SAYICON);
 	gi.WritePosition (ent->s.origin);
 	gi.multicast (ent->s.origin, MULTICAST_PVS);
 
-	if (!((((int)(dmflags->value) & (DF_MODELTEAMS | DF_SKINTEAMS))) || ctf->value || tca->value || cp->value))
+	if (!((((int)(dmflags->value) & (DF_SKINTEAMS))) || ctf->value || tca->value || cp->value))
 		team = false;
 
 	if (team)
@@ -854,7 +836,7 @@ void Cmd_Say_f (edict_t *ent, qboolean team, qboolean arg0)
         i = cl->flood_whenhead - flood_msgs->value + 1;
         if (i < 0)
             i = (sizeof(cl->flood_when)/sizeof(cl->flood_when[0])) + i;
-		if (cl->flood_when[i] && 
+		if (cl->flood_when[i] &&
 			level.time - cl->flood_when[i] < flood_persecond->value) {
 			cl->flood_locktill = level.time + flood_waitdelay->value;
 			safe_cprintf(ent, PRINT_CHAT, "Flood protection:  You can't talk for %d seconds.\n",
