@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -87,9 +87,9 @@ typedef enum
 	DAMAGE_AIM			// auto targeting recognizes this
 } damage_t;
 
-typedef enum 
+typedef enum
 {
-	WEAPON_READY, 
+	WEAPON_READY,
 	WEAPON_ACTIVATING,
 	WEAPON_DROPPING,
 	WEAPON_FIRING
@@ -162,11 +162,6 @@ typedef enum
 #define ARMOR_BODY				3
 #define ARMOR_SHARD				4
 
-// power armor types
-#define POWER_ARMOR_NONE		0
-#define POWER_ARMOR_SCREEN		1
-#define POWER_ARMOR_SHIELD		2
-
 // handedness values
 #define RIGHT_HANDED			0
 #define LEFT_HANDED				1
@@ -227,20 +222,22 @@ typedef struct
 #define IT_POWERUP		16
 
 // gitem_t->weapmodel for weapons indicates model index
-#define WEAP_BLASTER			1 
-#define WEAP_SMARTGUN			2 
-#define WEAP_CHAINGUN			3 
-#define WEAP_FLAMETHROWER		5 
-#define WEAP_ROCKETLAUNCHER		8 
-#define WEAP_DISRUPTOR			9 
+#define WEAP_BLASTER			1
+#define WEAP_SMARTGUN			2
+#define WEAP_CHAINGUN			3
+#define WEAP_FLAMETHROWER		5
+#define WEAP_ROCKETLAUNCHER		8
+#define WEAP_DISRUPTOR			9
 #define WEAP_BEAMGUN			10
 #define WEAP_VAPORIZER			11
-#define WEAP_BOMBER				12
-#define WEAP_STRAFER			13
-#define WEAP_DEATHBALL			14
-#define WEAP_HOVER				15
+#define WEAP_VIOLATOR			12
+#define WEAP_BOMBER				13
+#define WEAP_STRAFER			14
+#define WEAP_DEATHBALL			15
+#define WEAP_HOVER				16
 #define WEAP_GRAPPLE			16
 
+
 typedef struct gitem_s
 {
 	char		*classname;	// spawning name
@@ -296,6 +293,9 @@ typedef struct
 	// items
 	int			num_items;
 
+	//bots
+	int			num_bots;
+
 	qboolean	autosaved;
 } game_locals_t;
 
@@ -448,8 +448,6 @@ typedef struct
 	float		idle_time;
 	int			linkcount;
 
-	int			power_armor_type;
-	int			power_armor_power;
 } monsterinfo_t;
 
 
@@ -474,6 +472,7 @@ extern  int print3;
 // means of death
 #define MOD_UNKNOWN			0
 #define MOD_BLASTER			1
+#define MOD_VIOLATOR		2
 #define MOD_CGALTFIRE		3
 #define MOD_CHAINGUN		5
 #define MOD_FLAME			6
@@ -510,13 +509,13 @@ extern	int	meansOfDeath;
 
 extern	edict_t			*g_edicts;
 
-#define	FOFS(x) (int)&(((edict_t *)0)->x)
-#define	STOFS(x) (int)&(((spawn_temp_t *)0)->x)
-#define	LLOFS(x) (int)&(((level_locals_t *)0)->x)
-#define	CLOFS(x) (int)&(((gclient_t *)0)->x)
+#define FOFS(x)(ptrdiff_t)&(((edict_t *)0)->x)
+#define STOFS(x)(ptrdiff_t)&(((spawn_temp_t *)0)->x)
+#define LLOFS(x)(ptrdiff_t)&(((level_locals_t *)0)->x)
+#define CLOFS(x)(ptrdiff_t)&(((gclient_t *)0)->x)
 
-#define random()	((rand () & 0x7fff) / ((float)0x7fff))
-#define crandom()	(2.0 * (random() - 0.5))
+#define random() ((rand() & 0x7fff) / ((float)0x7fff))
+#define crandom() (2.0 * (random() - 0.5))
 
 extern	cvar_t	*maxentities;
 extern	cvar_t	*deathmatch;
@@ -573,6 +572,25 @@ extern  cvar_t  *excessive;
 extern  cvar_t  *grapple;
 extern  cvar_t  *classbased;
 
+//duel mode
+extern	cvar_t	*g_duel;
+
+extern	cvar_t	*g_losehealth;
+extern	cvar_t	*g_losehealth_num;
+
+//weapons
+extern	cvar_t	*wep_selfdmgmulti;
+
+//health/max health/max ammo
+extern	cvar_t	*g_spawnhealth;
+extern	cvar_t	*g_maxhealth;
+extern	cvar_t	*g_maxbullets;
+extern	cvar_t	*g_maxshells;
+extern	cvar_t	*g_maxrockets;
+extern	cvar_t	*g_maxgrenades;
+extern	cvar_t	*g_maxcells;
+extern	cvar_t	*g_maxslugs;
+
 //quick weapon change
 extern  cvar_t  *quickweap;
 
@@ -580,9 +598,14 @@ extern  cvar_t  *quickweap;
 extern  cvar_t  *anticamp;
 extern  cvar_t  *camptime;
 
+extern	cvar_t  *g_randomquad;
+
 //warmup time
 extern cvar_t   *warmuptime;
 
+//spawn protection
+extern cvar_t   *g_spawnprotect;
+
 //jousting
 extern cvar_t   *joustmode;
 
@@ -605,7 +628,7 @@ extern cvar_t   *joustmode;
 #define FFL_NOSPAWN			2
 
 typedef enum {
-	F_INT, 
+	F_INT,
 	F_FLOAT,
 	F_LSTRING,			// string on disk, pointer in memory, TAG_LEVEL
 	F_GSTRING,			// string on disk, pointer in memory, TAG_GAME
@@ -654,15 +677,19 @@ void SpawnItem (edict_t *ent, gitem_t *item);
 void DoRespawn (edict_t *ent);
 void Think_Weapon (edict_t *ent);
 int ArmorIndex (edict_t *ent);
-int PowerArmorType (edict_t *ent);
 gitem_t	*GetItemByIndex (int index);
-qboolean Add_Ammo (edict_t *ent, gitem_t *item, int count);
+qboolean Add_Ammo (edict_t *ent, gitem_t *item, int count, qboolean weapon, qboolean dropped);
 void Touch_Item (edict_t *ent, edict_t *other, cplane_t *plane, csurface_t *surf);
+
 //CTF
 void CTFDeadDropFlag(edict_t *self);
 void CTFEffects(edict_t *player);
 void CTFScoreboardMessage (edict_t *ent, edict_t *killer);
 void CTFPrecache(void);
+void CTFFlagSetup (edict_t *ent);
+qboolean CTFPickup_Flag (edict_t *ent, edict_t *other);
+qboolean CTFDrop_Flag(edict_t *ent, gitem_t *item);
+
 //Vehicles
 void Reset_player(edict_t *ent);
 void Jet_Explosion(edict_t *ent);
@@ -670,9 +697,17 @@ qboolean Jet_Active(edict_t *ent);
 void Jet_ApplyJet( edict_t *ent, usercmd_t *ucmd );
 qboolean Jet_AvoidGround( edict_t *ent );
 void VehicleDeadDrop(edict_t *self);
+void VehicleSetup (edict_t *ent);
+qboolean Get_in_vehicle (edict_t *ent, edict_t *other);
+qboolean Leave_vehicle(edict_t *ent, gitem_t *item);
+
 //deathball
 void ResetDeathball();
 void DeadDropDeathball(edict_t *self);
+void DeathballSetup (edict_t *ent);
+qboolean Pickup_deathball (edict_t *ent, edict_t *other);
+qboolean DeathballDrop(edict_t *ent, gitem_t *item);
+
 //
 // g_utils.c
 //
@@ -742,10 +777,8 @@ void M_SetEffects (edict_t *ent);
 //
 // g_misc.c
 //
-void ThrowHead (edict_t *self, char *gibname, int damage, int type, int effects);
 void ThrowClientHead (edict_t *self, int damage);
 void ThrowGib (edict_t *self, char *gibname, int damage, int type, int effects);
-void ThrowBloodStain (edict_t *self, char *gibname);
 void BecomeExplosion1 (edict_t *self);
 
 //
@@ -773,7 +806,6 @@ qboolean FacingIdeal(edict_t *self);
 void ThrowDebris (edict_t *self, char *modelname, float speed, vec3_t origin);
 void ThrowDebris2 (edict_t *self, char *modelname, float speed, vec3_t origin);
 
-qboolean fire_hit (edict_t *self, vec3_t aim, int damage, int kick);
 void fire_bullet (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int kick, int hspread, int vspread, int mod);
 void fire_shotgun (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int kick, int hspread, int vspread, int count, int mod);
 void fire_blaster (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int speed, int effect, qboolean hyper);
@@ -792,6 +824,7 @@ void fire_energy_field (edict_t *self, vec3_t start, vec3_t aimdir, int damage,
 void fire_blasterball (edict_t *self, vec3_t start, vec3_t dir, int damage, int speed, int effect, qboolean hyper);
 void fire_prox (edict_t *self, vec3_t start, vec3_t dir, int damage, int speed, float damage_radius, int radius_damage, float timer);
 void fire_fireball (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int speed, float damage_radius, int radius_damage);
+void fire_violator(edict_t *self, vec3_t start, vec3_t aimdir, int damage, int kick, int alt);
 
 //deathball
 void fire_deathball (edict_t *self, vec3_t start, vec3_t dir, int speed);
@@ -823,7 +856,7 @@ edict_t *PlayerTrail_PickNext (edict_t *self);
 edict_t	*PlayerTrail_LastSpot (void);
 
 //
-// g_client.c
+// p_client.c
 //
 void respawn (edict_t *ent);
 void BeginIntermission (edict_t *targ);
@@ -834,6 +867,9 @@ void InitClientResp (gclient_t *client);
 void InitBodyQue (void);
 void ClientBeginServerFrame (edict_t *ent);
 int Q2_FindFile (char *filename, FILE **file);
+void ClientPlaceInQueue(edict_t *ent);
+void ClientCheckQueue(edict_t *ent);
+void MoveClientsDownQueue(edict_t *ent);
 
 //
 // g_player.c
@@ -911,6 +947,13 @@ void GetChaseTarget(edict_t *ent);
 #define	ANIM_DEATH		5
 #define	ANIM_REVERSE	6
 
+#define BASE_ROCKETS	10
+#define BASE_SHELLS		10
+#define BASE_CELLS		50
+#define BASE_SLUGS		10
+#define BASE_GRENADES	50
+#define BASE_BULLETS	50
+
 
 // client data that stays across multiple level loads
 typedef struct
@@ -944,7 +987,9 @@ typedef struct
 	int			game_helpchanged;
 	int			helpchanged;
 
-	qboolean	spectator;			// client is a spectator
+	int			spectator;			// client is a spectator
+	int	queue;				// client queue position for duel mode
+
 } client_persistant_t;
 
 // client data that stays across deathmatch respawns
@@ -960,10 +1005,10 @@ typedef struct
 	bot_t bots[100];
 
 	//weapon accuracy info
-	int weapon_shots[8];
-	int weapon_hits[8];
+	int weapon_shots[9];
+	int weapon_hits[9];
 
-	qboolean	spectator;			// client is a spectator
+	int			spectator;			// client is a spectator
 } client_respawn_t;
 
 // this structure is cleared on each PutClientInServer(),
@@ -1013,7 +1058,6 @@ struct gclient_s
 	// sum up damage over an entire frame, so
 	// shotgun blasts give a single big kick
 	int			damage_armor;		// damage absorbed by armor
-	int			damage_parmor;		// damage absorbed by power armor
 	int			damage_blood;		// damage taken out of health
 	int			damage_knockback;	// impact damage
 	vec3_t		damage_from;		// origin for vector calculation
@@ -1052,6 +1096,8 @@ struct gclient_s
 	float		sproing_framenum;
 	float		regen_framenum;
 
+	float		losehealth_framenum;
+
 	qboolean	grenade_blew_up;
 	float		grenade_time;
 	int			silencer_shots;
@@ -1068,7 +1114,7 @@ struct gclient_s
 	edict_t		*chase_target;		// player we are chasing
 	qboolean	update_chase;		// need to update chase info?
 
-	//team 
+	//team
 	int			dmteam;
 
 	//chasecam
@@ -1080,7 +1126,7 @@ struct gclient_s
 	qboolean in_vehicle;
 	float	Jet_framenum;   /*burn out time when jet is activated*/
     float	Jet_remaining;  /*remaining fuel time*/
-    float	Jet_next_think; 
+    float	Jet_next_think;
 
 	//deathball
 	qboolean in_deathball;
@@ -1089,13 +1135,16 @@ struct gclient_s
 	void		*ctf_grapple;		// entity of grapple
 	int			ctf_grapplestate;		// true if pulling
 	float		ctf_grapplereleasetime;	// time of grapple release
-	
+
 	//kill streaks
 	int kill_streak; //obviously this *will* get cleared at each respawn in most cases
 
 	//joust attempts - for limiting how many times you can joust at a time
 	int joustattempts;
 
+	float spawnprotecttime;
+	qboolean spawnprotected;
+
 };
 
 
@@ -1112,7 +1161,7 @@ struct edict_s
 
 	// FIXME: move these fields to a server private sv_entity_t
 	link_t		area;				// linked to a division node or leaf
-	
+
 	int			num_clusters;		// if -1, use headnode instead
 	int			clusternums[MAX_ENT_CLUSTERS];
 	int			headnode;			// unused if num_clusters != -1
@@ -1137,7 +1186,7 @@ struct edict_s
 
 	char		*model;
 	float		freetime;			// sv.time when the object was freed
-	
+
 	//
 	// only used locally in game, not by server
 	//
@@ -1194,8 +1243,6 @@ struct edict_s
 	int			deadflag;
 	qboolean	show_hostile;
 
-	float		powerarmor_time;
-
 	char		*map;			// target_changelevel
 
 	int			viewheight;		// height above origin where eyesight is determined
@@ -1255,9 +1302,9 @@ struct edict_s
 // ACEBOT_ADD
 	qboolean is_bot;
 	qboolean is_jumping;
-	
+
 	// For movement
-	vec3_t move_vector; 
+	vec3_t move_vector;
 	float next_move_time;
 	float wander_timeout;
 	float suicide_timeout;
