@@ -145,7 +145,7 @@ spawn_t	spawns[] = {
 	{"target_changelevel", SP_target_changelevel},
 	{"target_secret", SP_target_secret},
 	{"target_splash", SP_target_splash},
-	{"target_steam", SP_target_steam},  
+	{"target_steam", SP_target_steam},
 	{"target_spawner", SP_target_spawner},
 	{"target_blaster", SP_target_blaster},
 	{"target_crosslevel_trigger", SP_target_crosslevel_trigger},
@@ -208,13 +208,13 @@ void ED_CallSpawn (edict_t *ent)
 	{
 		if (!item->classname)
 			continue;
-		
+
 		//-JD - removing old weapons, and in the case of the vaporizer, duplicates.
 		if(!Q_stricmp(ent->classname, "weapon_grenadelauncher"))
 			ent->classname = "weapon_rocketlauncher"; //hack to remove old weapons
 		if(!Q_stricmp(ent->classname, "weapon_machinegun"))
 			ent->classname = "weapon_bfg"; //hack to remove old weapons
-		
+
 		if (!strcmp(item->classname, ent->classname))
 		{	// found it
 			SpawnItem (ent, item);
@@ -249,7 +249,7 @@ char *ED_NewString (char *string)
 {
 	char	*newb, *new_p;
 	int		i,l;
-	
+
 	l = strlen(string) + 1;
 
 	newb = gi.TagMalloc (l, TAG_LEVEL);
@@ -269,7 +269,7 @@ char *ED_NewString (char *string)
 		else
 			*new_p++ = string[i];
 	}
-	
+
 	return newb;
 }
 
@@ -351,7 +351,7 @@ char *ED_ParseEdict (char *data, edict_t *ent)
 
 // go through all the dictionary pairs
 	while (1)
-	{	
+	{
 	// parse key
 		com_token = COM_Parse (&data);
 		if (com_token[0] == '}')
@@ -360,8 +360,8 @@ char *ED_ParseEdict (char *data, edict_t *ent)
 			gi.error ("ED_ParseEntity: EOF without closing brace");
 
 		strncpy (keyname, com_token, sizeof(keyname)-1);
-		
-	// parse value	
+
+	// parse value
 		com_token = COM_Parse (&data);
 		if (!data)
 			gi.error ("ED_ParseEntity: EOF without closing brace");
@@ -369,7 +369,7 @@ char *ED_ParseEdict (char *data, edict_t *ent)
 		if (com_token[0] == '}')
 			gi.error ("ED_ParseEntity: closing brace without data");
 
-		init = true;	
+		init = true;
 
 	// keynames with a leading underscore are used for utility comments,
 	// and are immediately discarded by quake
@@ -481,7 +481,7 @@ void SpawnEntities (char *mapname, char *entities, char *spawnpoint)
 // parse ents
 	while (1)
 	{
-		// parse the opening brace	
+		// parse the opening brace
 		com_token = COM_Parse (&entities);
 		if (!entities)
 			break;
@@ -505,20 +505,20 @@ void SpawnEntities (char *mapname, char *entities, char *spawnpoint)
 			{
 				if ( ent->spawnflags & SPAWNFLAG_NOT_DEATHMATCH )
 				{
-					G_FreeEdict (ent);	
+					G_FreeEdict (ent);
 					inhibit++;
 					continue;
 				}
 			}
 			else
 			{
-				if ( 
+				if (
 					((skill->value == 0) && (ent->spawnflags & SPAWNFLAG_NOT_EASY)) ||
 					((skill->value == 1) && (ent->spawnflags & SPAWNFLAG_NOT_MEDIUM)) ||
 					(((skill->value == 2) || (skill->value == 3)) && (ent->spawnflags & SPAWNFLAG_NOT_HARD))
 					)
 					{
-						G_FreeEdict (ent);	
+						G_FreeEdict (ent);
 						inhibit++;
 						continue;
 					}
@@ -528,7 +528,7 @@ void SpawnEntities (char *mapname, char *entities, char *spawnpoint)
 		}
 
 		ED_CallSpawn (ent);
-	}	
+	}
 
 	gi.dprintf ("%i entities inhibited\n", inhibit);
 
@@ -564,70 +564,6 @@ void SpawnEntities (char *mapname, char *entities, char *spawnpoint)
 
 #endif
 
-char *single_statusbar = 
-
-//background
-"yb -256 "
-"xl	 0 "
-"pic 0 "
-
-// health
-"yb	-29 "
-"xl	11 "
-"hnum "
-
-// ammo
-"if 2 "
-"	xl	76 "
-"   yb  -29 "
-"	anum "
-"	xl	14 "
-"	yb  -124 "
-"	pic 2 "
-"endif "
-
-// armor
-"if 4 "
-"	xl	142 "
-"   yb  -29 "
-"	rnum "
-"	xl	14 "
-"   yb -156 "
-"	pic 4 "
-"endif "
-
-// selected item
-"if 6 "
-"	xv	296 "
-"   yb  -56"
-"	pic 6 "
-"endif "
-
-// picked up item
-"if 7 "
-"	xl	99 "
-"	yb	-66 "
-"	stat_string 8 "
-"	yb	-36 "
-"endif "
-
-// timer
-"if 9 "
-"	xv	262 "
-"   yb  -36 "
-"	num	2	10 "
-"	xv	296 "
-"   yb  -56 "
-"	pic	9 "
-"endif "
-
-//  help / weapon icon 
-"if 11 "
-"	xl	220 "
-"	pic	11 "
-"endif "
-;
-
 char *dm_statusbar =
 //background
 "yb -256 "
@@ -654,13 +590,6 @@ char *dm_statusbar =
 "	rnum "
 "endif "
 
-// picked up item
-"if 7 "
-"	xl	99 "
-"	yb	-66 "
-"	stat_string 8 "
-"endif "
-
 // timer
 "if 9 "
 "	xv	262 "
@@ -671,17 +600,17 @@ char *dm_statusbar =
 "	pic	9 "
 "endif "
 
-//  help / weapon icon 
+// weapon icon
 "if 11 "
-"	xl	220 "
-"   yb  -50 "
+"	xr	-72 "
+"   yt  196 "
 "	pic	11 "
 "endif "
 
 //  frags
 "xr	-67 "
 "yt 16 "
-"num 3 14" 
+"num 3 14"
 
 //  deaths
 "xr	-67 "
@@ -719,13 +648,6 @@ char *team_statusbar =
 "	rnum "
 "endif "
 
-// selected item
-"if 6 "
-"	xv	296 "
-"   yb  -56"
-"	pic 6 "
-"endif "
-
 // timer
 "if 9 "
 "	xv	262 "
@@ -736,17 +658,17 @@ char *team_statusbar =
 "	pic	9 "
 "endif "
 
-//  help / weapon icon 
+// weapon icon
 "if 11 "
-"	xl	220 "
-"   yb  -50 "
+"	xr	-72 "
+"   yt  196 "
 "	pic	11 "
 "endif "
 
 //  frags
 "xr	-67 "
 "yt 16 "
-"num 3 14" 
+"num 3 14"
 
 //  deaths
 "xr	-67 "
@@ -760,7 +682,7 @@ char *team_statusbar =
 //  red team
 "yt 132 "
 "num 3 21 "
-//  blue team 
+//  blue team
 "yt 166 "
 "num 3 22 "
 
@@ -817,23 +739,17 @@ void SP_worldspawn (edict_t *ent)
 	gi.configstring (CS_SKYAXIS, va("%f %f %f",
 		st.skyaxis[0], st.skyaxis[1], st.skyaxis[2]) );
 
-	gi.configstring (CS_CDTRACK, va("%i", ent->sounds) );
-
 	gi.configstring (CS_MAXCLIENTS, va("%i", (int)(maxclients->value) ) );
 
 	// status bar program
-	if (deathmatch->value) {
-		if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value)
-		{
-			gi.configstring (CS_STATUSBAR, team_statusbar);
-			if(ctf->value)
-				CTFPrecache();
-		}
-		else
-			gi.configstring (CS_STATUSBAR, dm_statusbar);
+	if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value)
+	{
+		gi.configstring (CS_STATUSBAR, team_statusbar);
+		if(ctf->value)
+			CTFPrecache();
 	}
 	else
-		gi.configstring (CS_STATUSBAR, single_statusbar);
+		gi.configstring (CS_STATUSBAR, dm_statusbar);
 
 	//---------------
 
@@ -854,6 +770,7 @@ void SP_worldspawn (edict_t *ent)
 	snd_fry = gi.soundindex ("player/fry.wav");	// standing in lava / slime
 
 	PrecacheItem (FindItem ("Blaster"));
+	PrecacheItem (FindItem ("Violator"));
 
 	gi.soundindex ("player/lava1.wav");
 	gi.soundindex ("player/lava2.wav");
@@ -870,9 +787,9 @@ void SP_worldspawn (edict_t *ent)
 	gi.soundindex ("*death3.wav");
 	gi.soundindex ("*death4.wav");
 	gi.soundindex ("*fall1.wav");
-	gi.soundindex ("*fall2.wav");	
+	gi.soundindex ("*fall2.wav");
 	gi.soundindex ("*gurp1.wav");		// drowning damage
-	gi.soundindex ("*gurp2.wav");	
+	gi.soundindex ("*gurp2.wav");
 	gi.soundindex ("*jump1.wav");		// player jump
 	gi.soundindex ("*pain25_1.wav");
 	gi.soundindex ("*pain25_2.wav");
@@ -892,7 +809,7 @@ void SP_worldspawn (edict_t *ent)
 	gi.soundindex ("player/watr_out.wav");	// feet leaving water
 
 	gi.soundindex ("player/watr_un.wav");	// head going underwater
-	
+
 	gi.soundindex ("items/damage.wav");
 	gi.soundindex ("items/protect.wav");
 	gi.soundindex ("items/protect4.wav");
@@ -900,6 +817,16 @@ void SP_worldspawn (edict_t *ent)
 
 	gi.soundindex ("weapons/whoosh.wav");
 
+	gi.soundindex ("misc/1frags.wav");
+	gi.soundindex ("misc/2frags.wav");
+	gi.soundindex ("misc/3frags.wav");
+	gi.soundindex ("misc/one.wav");
+	gi.soundindex ("misc/two.wav");
+	gi.soundindex ("misc/three.wav");
+	gi.soundindex ("misc/godlike.wav");
+	gi.soundindex ("misc/rampage.wav");
+	gi.soundindex ("misc/fight.wav");
+
 	//precache any gibs
 	sm_meat_index = gi.modelindex ("models/objects/gibs/sm_meat/tris.md2");
 	gi.modelindex ("models/objects/gibs/mart_gut/tris.md2");
@@ -933,6 +860,7 @@ void SP_worldspawn (edict_t *ent)
 	gi.modelindex ("#w_hyperblaster.md2");
 	gi.modelindex ("#w_railgun.md2");
 	gi.modelindex ("#w_bfg.md2");
+	gi.modelindex ("#w_violator.md2");
 
 //
 // Setup light animation tables. 'a' is total darkness, 'z' is doublebright.
@@ -940,40 +868,40 @@ void SP_worldspawn (edict_t *ent)
 
 	// 0 normal
 	gi.configstring(CS_LIGHTS+0, "m");
-	
+
 	// 1 FLICKER (first variety)
 	gi.configstring(CS_LIGHTS+1, "mmnmmommommnonmmonqnmmo");
-	
+
 	// 2 SLOW STRONG PULSE
 	gi.configstring(CS_LIGHTS+2, "abcdefghijklmnopqrstuvwxyzyxwvutsrqponmlkjihgfedcba");
-	
+
 	// 3 CANDLE (first variety)
 	gi.configstring(CS_LIGHTS+3, "mmmmmaaaaammmmmaaaaaabcdefgabcdefg");
-	
+
 	// 4 FAST STROBE
 	gi.configstring(CS_LIGHTS+4, "mamamamamama");
-	
+
 	// 5 GENTLE PULSE 1
 	gi.configstring(CS_LIGHTS+5,"jklmnopqrstuvwxyzyxwvutsrqponmlkj");
-	
+
 	// 6 FLICKER (second variety)
 	gi.configstring(CS_LIGHTS+6, "nmonqnmomnmomomno");
-	
+
 	// 7 CANDLE (second variety)
 	gi.configstring(CS_LIGHTS+7, "mmmaaaabcdefgmmmmaaaammmaamm");
-	
+
 	// 8 CANDLE (third variety)
 	gi.configstring(CS_LIGHTS+8, "mmmaaammmaaammmabcdefaaaammmmabcdefmmmaaaa");
-	
+
 	// 9 SLOW STROBE (fourth variety)
 	gi.configstring(CS_LIGHTS+9, "aaaaaaaazzzzzzzz");
-	
+
 	// 10 FLUORESCENT FLICKER
 	gi.configstring(CS_LIGHTS+10, "mmamammmmammamamaaamammma");
 
 	// 11 SLOW PULSE NOT FADE TO BLACK
 	gi.configstring(CS_LIGHTS+11, "abcdefghijklmnopqrrqponmlkjihgfedcba");
-	
+
 	// styles 32-62 are assigned by the light program for switchable lights
 
 	// 63 testing
