@@ -3,110 +3,6 @@
 int floater_timer;
 int prox_timer;
 
-/*
-=================
-check_dodge
-
-This is a support routine used when a client is firing
-a non-instant attack weapon.  It checks to see if a
-monster's dodge function should be called.
-=================
-*/
-static void check_dodge (edict_t *self, vec3_t start, vec3_t dir, int speed)
-{
-	vec3_t	end;
-	vec3_t	v;
-	trace_t	tr;
-	float	eta;
-
-	// easy mode only ducks one quarter the time
-	if (skill->value == 0)
-	{
-		if (random() > 0.25)
-			return;
-	}
-	VectorMA (start, 8192, dir, end);
-	tr = gi.trace (start, NULL, NULL, end, self, MASK_SHOT);
-	if ((tr.ent) && (tr.ent->svflags & SVF_MONSTER) && (tr.ent->health > 0) && (tr.ent->monsterinfo.dodge) && infront(tr.ent, self))
-	{
-		VectorSubtract (tr.endpos, start, v);
-		eta = (VectorLength(v) - tr.ent->maxs[0]) / speed;
-		tr.ent->monsterinfo.dodge (tr.ent, self, eta);
-	}
-}
-
-
-/*
-=================
-fire_hit
-
-Used for all impact (hit/punch/slash) attacks
-=================
-*/
-qboolean fire_hit (edict_t *self, vec3_t aim, int damage, int kick)
-{
-	trace_t		tr;
-	vec3_t		forward, right, up;
-	vec3_t		v;
-	vec3_t		point;
-	float		range;
-	vec3_t		dir;
-
-	//see if enemy is in range
-	VectorSubtract (self->enemy->s.origin, self->s.origin, dir);
-	range = VectorLength(dir);
-	if (range > aim[0])
-		return false;
-
-	if (aim[1] > self->mins[0] && aim[1] < self->maxs[0])
-	{
-		// the hit is straight on so back the range up to the edge of their bbox
-		range -= self->enemy->maxs[0];
-	}
-	else
-	{
-		// this is a side hit so adjust the "right" value out to the edge of their bbox
-		if (aim[1] < 0)
-			aim[1] = self->enemy->mins[0];
-		else
-			aim[1] = self->enemy->maxs[0];
-	}
-
-	VectorMA (self->s.origin, range, dir, point);
-
-	tr = gi.trace (self->s.origin, NULL, NULL, point, self, MASK_SHOT);
-	if (tr.fraction < 1)
-	{
-		if (!tr.ent->takedamage)
-			return false;
-		// if it will hit any client/monster then hit the one we wanted to hit
-		if ((tr.ent->svflags & SVF_MONSTER) || (tr.ent->client))
-			tr.ent = self->enemy;
-	}
-
-	AngleVectors(self->s.angles, forward, right, up);
-	VectorMA (self->s.origin, range, forward, point);
-	VectorMA (point, aim[1], right, point);
-	VectorMA (point, aim[2], up, point);
-	VectorSubtract (point, self->enemy->s.origin, dir);
-
-	// do the damage
-	T_Damage (tr.ent, self, self, dir, point, vec3_origin, damage, kick/2, DAMAGE_NO_KNOCKBACK, MOD_HIT);
-
-	if (!(tr.ent->svflags & SVF_MONSTER) && (!tr.ent->client))
-		return false;
-
-	// do our special form of knockback here
-	VectorMA (self->enemy->absmin, 0.5, self->enemy->size, v);
-	VectorSubtract (v, point, v);
-	VectorNormalize (v);
-	VectorMA (self->enemy->velocity, kick, v, self->enemy->velocity);
-	if (self->enemy->velocity[2] > 0)
-		self->enemy->groundentity = NULL;
-	return true;
-}
-
-
 /*
 =================
 fire_lead
@@ -325,11 +221,12 @@ void blaster_touch (edict_t *self, edict_t *other, cplane_t *plane, csurface_t *
 		else
 			gi.WriteDir (plane->normal);
 		gi.multicast (self->s.origin, MULTICAST_PVS);
-		
+
 	}
 
 	G_FreeEdict (self);
 }
+
 void blasterball_touch (edict_t *self, edict_t *other, cplane_t *plane, csurface_t *surf)
 {
 	int		mod;
@@ -359,17 +256,18 @@ void blasterball_touch (edict_t *self, edict_t *other, cplane_t *plane, csurface
 	else
 	{
 		gi.WriteByte (svc_temp_entity);
-		gi.WriteByte (TE_BLASTER); 
+		gi.WriteByte (TE_BLASTER);
 		gi.WritePosition (self->s.origin);
 		if (!plane)
 			gi.WriteDir (vec3_origin);
 		else
 			gi.WriteDir (plane->normal);
-		gi.multicast (self->s.origin, MULTICAST_PVS);		
+		gi.multicast (self->s.origin, MULTICAST_PVS);
 	}
-	T_RadiusDamage(self, self->owner, 75, other, 150, MOD_PLASMA_SPLASH, 0);
+	T_RadiusDamage(self, self->owner, 95, other, 150, MOD_PLASMA_SPLASH, 0);
 	G_FreeEdict (self);
 }
+
 void fire_blasterball (edict_t *self, vec3_t start, vec3_t dir, int damage, int speed, int effect, qboolean hyper)
 {
 	edict_t	*bolt;
@@ -399,11 +297,8 @@ void fire_blasterball (edict_t *self, vec3_t start, vec3_t dir, int damage, int
 	bolt->think = G_FreeEdict;
 	bolt->dmg = damage;
 	bolt->classname = "bolt";
-	
-	gi.linkentity (bolt);
 
-	if (self->client)
-		check_dodge (self, bolt->s.origin, dir, speed);
+	gi.linkentity (bolt);
 
 	tr = gi.trace (self->s.origin, NULL, NULL, bolt->s.origin, bolt, MASK_SHOT);
 	if (tr.fraction < 1.0)
@@ -411,17 +306,17 @@ void fire_blasterball (edict_t *self, vec3_t start, vec3_t dir, int damage, int
 		VectorMA (bolt->s.origin, -10, dir, bolt->s.origin);
 		bolt->touch (bolt, tr.ent, NULL, NULL);
 	}
-}	
+}
 void fire_blaster (edict_t *self, vec3_t start, vec3_t aimdir, int damage,
 int speed, int effect, qboolean hyper)
-{   
+{
 	vec3_t		from;
 	vec3_t		end;
 	trace_t		tr;
 	edict_t		*ignore;
 	int			mask;
 	qboolean	water;
-	
+
 	self->client->resp.weapon_shots[6]++;
 
 	VectorMA (start, 8192, aimdir, end);
@@ -451,42 +346,40 @@ int speed, int effect, qboolean hyper)
 				gi.sound (self, CHAN_VOICE, gi.soundindex("misc/hit.wav"), 1, ATTN_STATIC, 0);
 			}
 		}
-
 		VectorCopy (tr.endpos, from);
 	}
 
 	VectorMA (start, 8192, aimdir, end);
 	VectorCopy (start, from);
 
-	// trace for end point of laser beam.      // the laser aim is perfect. 
+	// trace for end point of laser beam.      // the laser aim is perfect.
 	// no random aim like the machinegun
-	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);      
+	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);
 
 	// send laser beam temp entity to clients
 	VectorCopy (tr.endpos, from);
 
 	gi.WriteByte (svc_temp_entity);
-	gi.WriteByte (TE_SHOTGUN);
+	gi.WriteByte (TE_LASERBEAM);
 	gi.WritePosition (start);
 	gi.WritePosition (tr.endpos);
-	gi.multicast (self->s.origin, MULTICAST_PHS);   
-      
-	if ((tr.ent != self) && (tr.ent->takedamage)) {
-        T_Damage (tr.ent, self, self, aimdir, tr.endpos, tr.plane.normal, damage, 0, 0, MOD_BEAMGUN);
+	gi.multicast (self->s.origin, MULTICAST_PHS);
+
+	if ((tr.ent != self) && (tr.ent->takedamage))
+	{
+        	T_Damage (tr.ent, self, self, aimdir, tr.endpos, tr.plane.normal, damage, 0, 0, MOD_BEAMGUN);
 		self->client->resp.weapon_hits[6]++;
 		gi.sound (self, CHAN_VOICE, gi.soundindex("misc/hit.wav"), 1, ATTN_STATIC, 0);
 	}
 	else if (!((tr.surface) && (tr.surface->flags & SURF_SKY)))
-    {  
-        gi.WriteByte (svc_temp_entity);
-        gi.WriteByte (TE_SCREEN_SPARKS);
+	{
+		gi.WriteByte (svc_temp_entity);
+		gi.WriteByte (TE_SCREEN_SPARKS);
 		gi.WritePosition (tr.endpos);
-        gi.WriteDir (tr.plane.normal);
-        gi.multicast (self->s.origin, MULTICAST_PVS);
-
+		gi.WriteDir (tr.plane.normal);
+		gi.multicast (self->s.origin, MULTICAST_PVS);
 	}
-    
-}       
+}
 
 /*
 =================
@@ -496,7 +389,6 @@ fire_rocket
 void rocket_touch (edict_t *ent, edict_t *other, cplane_t *plane, csurface_t *surf)
 {
 	vec3_t		origin;
-	int			n;
 
 	if (other == ent->owner)
 		return;
@@ -519,19 +411,6 @@ void rocket_touch (edict_t *ent, edict_t *other, cplane_t *plane, csurface_t *su
 		ent->owner->client->resp.weapon_hits[5]++;
 		gi.sound (ent->owner, CHAN_VOICE, gi.soundindex("misc/hit.wav"), 1, ATTN_STATIC, 0);
 	}
-	else
-	{
-		// don't throw any debris in net games
-		if (!deathmatch->value)
-		{
-			if ((surf) && !(surf->flags & (SURF_WARP|SURF_TRANS33|SURF_TRANS66|SURF_FLOWING)))
-			{
-				n = rand() % 5;
-				while(n--)
-					ThrowDebris (ent, "models/objects/debris2/tris.md2", 2, ent->s.origin);
-			}
-		}
-	}
 
 	T_RadiusDamage(ent, ent->owner, ent->radius_dmg, other, ent->dmg_radius, MOD_R_SPLASH, 5);
 
@@ -574,9 +453,6 @@ void fire_rocket (edict_t *self, vec3_t start, vec3_t dir, int damage, int speed
 	rocket->s.sound = gi.soundindex ("weapons/rockfly.wav");
 	rocket->classname = "rocket";
 
-	if (self->client)
-		check_dodge (self, rocket->s.origin, dir, speed);
-
 	gi.linkentity (rocket);
 }
 
@@ -660,7 +536,7 @@ void fire_blaster_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage,
 	while (ignore)
 	{
 		tr = gi.trace (from, NULL, NULL, end, ignore, mask);
-		
+
 		if (tr.contents & (CONTENTS_SLIME|CONTENTS_LAVA))
 		{
 			mask &= ~(CONTENTS_SLIME|CONTENTS_LAVA);
@@ -672,24 +548,24 @@ void fire_blaster_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage,
 				ignore = tr.ent;
 			else
 				ignore = NULL;
-			
+
 			if ((tr.ent != self) && (tr.ent->takedamage)) {
 				T_Damage (tr.ent, self, self, aimdir, tr.endpos, tr.plane.normal, damage, kick, 0, MOD_BLASTER);
 				self->client->resp.weapon_hits[0]++;
 				gi.sound (self, CHAN_VOICE, gi.soundindex("misc/hit.wav"), 1, ATTN_STATIC, 0);
 			}
 		}
-		
+
 		VectorCopy (tr.endpos, from);
 	}
 
 	VectorMA (start, 8192, aimdir, end);
 	VectorCopy (start, from);
 
-	// trace for end point of laser beam.      // the laser aim is perfect. 
+	// trace for end point of laser beam.      // the laser aim is perfect.
 	// no random aim like the machinegun
-	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);  
-    
+	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);
+
 	// send laser beam temp entity to clients
 	VectorCopy (tr.endpos, from);
 
@@ -697,12 +573,12 @@ void fire_blaster_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage,
 	gi.WriteByte (TE_BLASTERBEAM);
 	gi.WritePosition (start);
 	gi.WritePosition (tr.endpos);
-	gi.multicast (self->s.origin, MULTICAST_PHS);   
-	
+	gi.multicast (self->s.origin, MULTICAST_PHS);
+
 	gi.WriteByte (svc_temp_entity);
 	gi.WriteByte (TE_BLASTER);
 	gi.WritePosition (tr.endpos);
-	gi.WriteDir (vec3_origin);
+	gi.WriteDir (tr.plane.normal);
 	gi.multicast (tr.endpos, MULTICAST_PVS);
 
 	if(detonate) {
@@ -716,7 +592,7 @@ void fire_blaster_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage,
 		bomb->think = G_FreeEdict;
 		bomb->classname = "bomb";
 		gi.linkentity (bomb);
-		T_RadiusDamage(bomb, self, 50, NULL, 200, MOD_VAPORALTFIRE, 0); 
+		T_RadiusDamage(bomb, self, 50, NULL, 200, MOD_VAPORALTFIRE, 0);
 		G_FreeEdict (bomb);
 	}
 
@@ -762,9 +638,9 @@ void fire_blaster_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage,
 				gi.WriteByte (color);
 				gi.multicast (tr.endpos, MULTICAST_PVS);
 			}
-			
+
 		}
-			
+
 	}
 	// if went through water, determine where the end and make a bubble trail
 	if (water)
@@ -809,7 +685,7 @@ void fire_hover_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage, in
 	while (ignore)
 	{
 		tr = gi.trace (from, NULL, NULL, end, ignore, mask);
-		
+
 		if (tr.contents & (CONTENTS_SLIME|CONTENTS_LAVA))
 		{
 			mask &= ~(CONTENTS_SLIME|CONTENTS_LAVA);
@@ -821,22 +697,24 @@ void fire_hover_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage, in
 				ignore = tr.ent;
 			else
 				ignore = NULL;
-			
+
 			if ((tr.ent != self) && (tr.ent->takedamage))
 				T_Damage (tr.ent, self, self, aimdir, tr.endpos, tr.plane.normal, damage, kick, 0, MOD_BLASTER);
-				gi.sound (self, CHAN_VOICE, gi.soundindex("misc/hit.wav"), 1, ATTN_STATIC, 0);
-		}
-		
+				if (tr.ent->health > 0)
+				{
+					gi.sound (self, CHAN_VOICE, gi.soundindex("misc/hit.wav"), 1, ATTN_STATIC, 0);
+				}
+			}
 		VectorCopy (tr.endpos, from);
 	}
 
 	VectorMA (start, 8192, aimdir, end);
 	VectorCopy (start, from);
 
-	// trace for end point of laser beam.      // the laser aim is perfect. 
+	// trace for end point of laser beam.      // the laser aim is perfect.
 	// no random aim like the machinegun
-	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);  
-    
+	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);
+
 	// send laser beam temp entity to clients
 	VectorCopy (tr.endpos, from);
 
@@ -844,8 +722,8 @@ void fire_hover_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage, in
 	gi.WriteByte (TE_REDLASER);
 	gi.WritePosition (start);
 	gi.WritePosition (tr.endpos);
-	gi.multicast (self->s.origin, MULTICAST_PHS);   
-	
+	gi.multicast (self->s.origin, MULTICAST_PHS);
+
 
 	if(detonate) {
 		//spawn a new ent at end of explosion - and detonate it
@@ -858,8 +736,8 @@ void fire_hover_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage, in
 		bomb->think = G_FreeEdict;
 		bomb->classname = "bomb";
 		gi.linkentity (bomb);
-		T_RadiusDamage(bomb, self, 50, NULL, 200, MOD_VAPORALTFIRE, -1); 
-	
+		T_RadiusDamage(bomb, self, 100, NULL, 200, MOD_VAPORALTFIRE, -1);
+
 		gi.WriteByte (svc_temp_entity);
 		if (bomb->waterlevel)
 		gi.WriteByte (TE_ROCKET_EXPLOSION_WATER);
@@ -867,7 +745,7 @@ void fire_hover_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage, in
 		gi.WriteByte (TE_ROCKET_EXPLOSION);
 		gi.WritePosition (bomb->s.origin);
 		gi.multicast (bomb->s.origin, MULTICAST_PHS);
-		
+
 		G_FreeEdict (bomb);
 	}
 
@@ -913,9 +791,9 @@ void fire_hover_beam (edict_t *self, vec3_t start, vec3_t aimdir, int damage, in
 				gi.WriteByte (color);
 				gi.multicast (tr.endpos, MULTICAST_PVS);
 			}
-			
+
 		}
-			
+
 	}
 	// if went through water, determine where the end and make a bubble trail
 	if (water)
@@ -985,19 +863,19 @@ void fire_plasma (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int ki
 	VectorMA (start, 8192, aimdir, end);
 	VectorCopy (start, from);
 
-	// trace for end point of laser beam.      // the laser aim is perfect. 
+	// trace for end point of laser beam.      // the laser aim is perfect.
 	// no random aim like the machinegun
-	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);     
-	
+	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);
+
 	// send laser beam temp entity to clients
 	VectorCopy (tr.endpos, from);
-	
+
 	gi.WriteByte (svc_temp_entity);
 	gi.WriteByte (TE_RAILTRAIL);
 	gi.WritePosition (start);
 	gi.WritePosition (tr.endpos);
-	gi.multicast (self->s.origin, MULTICAST_PHS);   
-	
+	gi.multicast (self->s.origin, MULTICAST_PHS);
+
 	if (self->client)
 		PlayerNoise(self, tr.endpos, PNOISE_IMPACT);
 }
@@ -1047,23 +925,23 @@ void fire_energy_field (edict_t *self, vec3_t start, vec3_t aimdir, int damage,
 
 		VectorCopy (tr.endpos, from);
 	}
-	
+
 	VectorMA (start, 8192, aimdir, end);
 	VectorCopy (start, from);
 
-	// trace for end point of laser beam.      // the laser aim is perfect. 
+	// trace for end point of laser beam.      // the laser aim is perfect.
 	// no random aim like the machinegun
-	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);     
-	
+	tr = gi.trace (from, NULL, NULL, end, self, MASK_SHOT);
+
 	// send laser beam temp entity to clients
 	VectorCopy (tr.endpos, from);
-	
+
 	gi.WriteByte (svc_temp_entity);
-	gi.WriteByte (TE_HEATBEAM);
+	gi.WriteByte (TE_VAPORBEAM);
 	gi.WritePosition (start);
 	gi.WritePosition (tr.endpos);
-	gi.multicast (self->s.origin, MULTICAST_PHS);   
-	
+	gi.multicast (self->s.origin, MULTICAST_PHS);
+
 	gi.WriteByte (svc_temp_entity);
 	gi.WriteByte (TE_BFG_BIGEXPLOSION);
 	gi.WritePosition (tr.endpos);
@@ -1093,7 +971,7 @@ void homing_think (edict_t *ent)
 	edict_t *blip = NULL;
 	vec3_t  targetdir, blipdir;
 	vec_t   speed;
-	
+
 	while ((blip = findradius(blip, ent->s.origin, 1000)) != NULL)
 	{
 		if (!(blip->svflags & SVF_MONSTER) && !blip->client)
@@ -1116,7 +994,7 @@ void homing_think (edict_t *ent)
 			VectorCopy(blipdir, targetdir);
 		}
 	}
-	
+
 	if (target != NULL)
 	{
 		// target acquired, nudge our direction toward it
@@ -1129,7 +1007,7 @@ void homing_think (edict_t *ent)
 		speed = VectorLength(ent->velocity);
 		VectorScale(targetdir, speed, ent->velocity);
 	}
-	
+
 	ent->nextthink = level.time + .1;
 }
 
@@ -1153,30 +1031,27 @@ void fire_homingrocket (edict_t *self, vec3_t start, vec3_t dir, int damage, int
 	rocket->s.modelindex = gi.modelindex ("models/objects/rocket/tris.md2");
 	rocket->owner = self;
 	rocket->touch = rocket_touch;
-	
+
 	// CCH: if they have 5 cells, start homing, otherwise normal rocket think
 	if (self->client->pers.inventory[ITEM_INDEX(FindItem("Cells"))] >= 5)
 	{
 		self->client->pers.inventory[ITEM_INDEX(FindItem("Cells"))] -= 5;
 		rocket->nextthink = level.time + .1;
 		rocket->think = homing_think;
-	} 
+	}
 	else
 	{
 		safe_cprintf(self, PRINT_HIGH, "No cells for homing missile.\n");
 		rocket->nextthink = level.time + 8000/speed;
 		rocket->think = G_FreeEdict;
 	}
-    
+
     rocket->dmg = damage;
 	rocket->radius_dmg = radius_damage;
 	rocket->dmg_radius = damage_radius;
 	rocket->s.sound = gi.soundindex ("weapons/rockfly.wav");
 	rocket->classname = "rocket";
 
-	if (self->client)
-		check_dodge (self, rocket->s.origin, dir, speed);
-
 	gi.linkentity (rocket);
 }
 
@@ -1240,10 +1115,9 @@ void floater_think (edict_t *self)
 			// hurt it if we can
 			if ((tr.ent->takedamage) && !(tr.ent->flags & FL_IMMUNE_LASER) && (tr.ent != self->owner)) {
 				T_Damage (tr.ent, self, self->owner, dir, tr.endpos, vec3_origin, dmg, 1, DAMAGE_ENERGY, MOD_SMARTGUN);
-				self->owner->client->resp.weapon_hits[2]++;
 				self->owner->client->resp.weapon_shots[2]++;
+				self->owner->client->resp.weapon_hits[2]++;
 				gi.sound (self->owner, CHAN_VOICE, gi.soundindex("misc/hit.wav"), 1, ATTN_STATIC, 0);
-	
 			}
 			// if we hit something that's not a monster or player we're done
 			if (!(tr.ent->svflags & SVF_MONSTER) && (!tr.ent->client))
@@ -1270,7 +1144,7 @@ void floater_think (edict_t *self)
 
 		target = ent;
 	}
-	
+
 	self->nextthink = level.time + FRAMETIME;
 	floater_timer++;
 
@@ -1304,7 +1178,7 @@ void prox_think (edict_t *self)
 
 		if (!ent->takedamage)
 			continue;
-		
+
 		T_RadiusDamage(self, self->owner, self->radius_dmg, self->enemy, self->dmg_radius, MOD_R_SPLASH, -1);
 		self->owner->client->resp.weapon_hits[2]++;
 
@@ -1319,7 +1193,7 @@ void prox_think (edict_t *self)
 		G_FreeEdict (self);
 		return;
 	}
-	
+
 	self->nextthink = level.time + FRAMETIME;
 	prox_timer++;
 
@@ -1390,9 +1264,7 @@ void fire_floater (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int s
 	floater->classname = "grenade";
 	floater_timer = 0;
 
-	if (self->client)
-		check_dodge (self, floater->s.origin, dir, speed);
-    
+
 	gi.linkentity (floater);
 }
 void fire_prox (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int speed, float damage_radius, int radius_damage, float timer)
@@ -1401,7 +1273,7 @@ void fire_prox (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int spee
     vec3_t	dir, forward, right, up;
 
 	self->client->resp.weapon_shots[2]++;
-	
+
 	vectoangles(aimdir, dir);
 	AngleVectors(dir, forward, right, up);
 
@@ -1429,13 +1301,10 @@ void fire_prox (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int spee
 	prox->classname = "mine";
 	prox_timer = 0;
 
-	if (self->client)
-		check_dodge (self, prox->s.origin, dir, speed);
-    
 	gi.linkentity (prox);
 }
 
-//vehicles 
+//vehicles
 void bomb_think (edict_t *self)
 {
 	self->nextthink = level.time + FRAMETIME;
@@ -1472,9 +1341,8 @@ void bomb_touch (edict_t *ent, edict_t *other, cplane_t *plane, csurface_t *surf
 		T_Damage (other, ent, ent->owner, ent->velocity, ent->s.origin, plane->normal, ent->dmg, 0, 0, MOD_ROCKET);
 		ent->owner->client->resp.weapon_hits[7]++;
 		gi.sound (ent->owner, CHAN_VOICE, gi.soundindex("misc/hit.wav"), 1, ATTN_STATIC, 0);
-	
 	}
-	
+
 	T_RadiusDamage(ent, ent->owner, ent->radius_dmg, other, ent->dmg_radius, MOD_R_SPLASH, 7);
 
 	//advance to expoding frame
@@ -1484,7 +1352,7 @@ void bomb_touch (edict_t *ent, edict_t *other, cplane_t *plane, csurface_t *surf
 	gi.WriteByte (TE_BFG_BIGEXPLOSION);
 	gi.WritePosition (origin);
 	gi.multicast (ent->s.origin, MULTICAST_PHS);
-	
+
 	gi.sound (ent, CHAN_WEAPON, gi.soundindex("vehicles/explodebomb.wav"), 1, ATTN_NORM, 0);
 
 	//shake the ground a bit(it's a big ass bomb, right?)
@@ -1538,9 +1406,6 @@ void fire_bomb (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int spee
 	bomb->s.sound = gi.soundindex ("vehicles/flybomb.wav"); //get a new sound
 	bomb->classname = "grenade";
 
-	if (self->client)
-		check_dodge (self, bomb->s.origin, dir, speed);
-    
 	gi.linkentity (bomb);
 }
 
@@ -1562,7 +1427,7 @@ void Fire_Think (edict_t *self)
 		G_FreeEdict (self);
 		return;
 	}
-	
+
 	if (!self->owner)
 	{
 		G_FreeEdict (self);
@@ -1574,7 +1439,7 @@ void Fire_Think (edict_t *self)
 		G_FreeEdict (self);
 		return;
 	}
-	damage = self->FlameDamage;	
+	damage = self->FlameDamage;
 	VectorAdd (self->orb->mins, self->orb->maxs, v);
 	VectorMA (self->orb->s.origin, 0.5, v, v);
 	VectorSubtract (self->s.origin, v, v);
@@ -1668,8 +1533,8 @@ void fire_flamethrower(edict_t *self, vec3_t start, vec3_t dir, int damage, int
 	flame->solid = SOLID_BBOX;
 	flame->s.effects |= EF_SHIPEXHAUST;
 	flame->s.renderfx = RF_TRANSLUCENT;
-	VectorSet (flame->mins,-20,-20,-20);
-	VectorSet (flame->maxs,20,20,20);
+	VectorClear (flame->mins);
+	VectorClear (flame->maxs);
 	flame->s.modelindex = gi.modelindex ("models/objects/fireball/tris.md2");
 	flame->owner = self;
 	flame->touch = flame_touch;
@@ -1681,10 +1546,6 @@ void fire_flamethrower(edict_t *self, vec3_t start, vec3_t dir, int damage, int
 	flame->classname = "flame";
 	flame->s.sound = gi.soundindex ("weapons/grenlf1a.wav");
 
-
-	if (self->client)
-		check_dodge (self, flame->s.origin, dir, speed);
-
 	gi.linkentity (flame);
 }
 void fireball_touch (edict_t *ent, edict_t *other, cplane_t *plane, csurface_t *surf)
@@ -1766,16 +1627,13 @@ void fire_fireball (edict_t *self, vec3_t start, vec3_t aimdir, int damage, int
 	fireball->s.sound = gi.soundindex ("weapons/grenlf1a.wav");
 	fireball->classname = "flame";
 
-	if (self->client)
-		check_dodge (self, fireball->s.origin, dir, speed);
-    
 	gi.linkentity (fireball);
 }
 //deathball
 static void DeathballTouch(edict_t *ent, edict_t *other, cplane_t *plane, csurface_t *surf)
 {
 	//owner (who dropped us) can't touch for two secs
-//	if (other == ent->owner && 
+//	if (other == ent->owner &&
 //		ent->nextthink - level.time > 2)
 //		return;
 
@@ -1787,7 +1645,7 @@ static void DeathballThink(edict_t *ent)
 
 	ResetDeathball();
 	safe_bprintf(PRINT_HIGH, "The ball has returned!\n");
-	
+
 }
 void fire_deathball (edict_t *self, vec3_t start, vec3_t aimdir, int speed)
 {
@@ -1819,19 +1677,16 @@ void fire_deathball (edict_t *self, vec3_t start, vec3_t aimdir, int speed)
 	ball->owner = self; //important for scoring
 
 	ball->classname = "item_deathball";
-	ball->think = DeathballThink; 
+	ball->think = DeathballThink;
 	ball->nextthink = level.time + 30;
 	ball->touch = DeathballTouch;
 	ball->s.frame = 229;
 
-	if (self->client)
-		check_dodge (self, ball->s.origin, dir, speed);
-    
 	gi.linkentity (ball);
 
 	//remove deathball from players inventory
 	//set everything back
-	
+
 	self->in_deathball = false;
 	if(instagib->value)
 		self->client->newweapon = FindItem("Alien Disruptor");
@@ -1842,3 +1697,40 @@ void fire_deathball (edict_t *self, vec3_t start, vec3_t aimdir, int speed)
 	self->client->pers.inventory[ITEM_INDEX(deathball_item)] = 0;
 	self->s.modelindex4 = 0;
 }
+void fire_violator(edict_t *self, vec3_t start, vec3_t aimdir, int damage, int kick, int alt)
+{
+
+	vec3_t		from;
+	vec3_t		end;
+	trace_t		tr;
+	edict_t		*ignore;
+
+	VectorMA (start, 6.4, aimdir, end);
+	VectorCopy (start, from);
+	ignore = self;
+
+	while (ignore)
+	{
+		tr = gi.trace (from, NULL, NULL, end, ignore, MASK_PLAYERSOLID);
+
+		if ((tr.ent->svflags & SVF_MONSTER) || (tr.ent->client))
+			ignore = tr.ent;
+		else
+			ignore = NULL;
+
+		if ((tr.ent != self) && (tr.ent->takedamage)) {
+			T_Damage (tr.ent, self, self, aimdir, tr.endpos, tr.plane.normal, damage, kick, 0, MOD_VIOLATOR);
+			self->client->resp.weapon_hits[8]++;
+			gi.sound (self, CHAN_VOICE, gi.soundindex("misc/hit.wav"), 1, ATTN_STATIC, 0);
+			gi.WriteByte (svc_temp_entity);
+			gi.WriteByte (TE_LASER_SPARKS);
+			gi.WriteByte (4);
+			gi.WritePosition (tr.endpos);
+			gi.WriteDir (tr.plane.normal);
+			gi.WriteByte (self->s.skinnum);
+			gi.multicast (tr.endpos, MULTICAST_PVS);
+
+		}
+		VectorCopy (tr.endpos, from);
+	}
+}
