@@ -86,8 +86,11 @@ void PlaceWinnerOnVictoryPad(edict_t *winner, int offset)
 
 	if(winner->deadflag == DEAD_DEAD)
 		zoffset = -40;
-	else 
+	else  {
 		zoffset = 0;
+		if(winner->in_vehicle)
+			Reset_player(winner);
+	}
 
 	VectorCopy (level.intermission_angle, winner->s.angles);
 	
@@ -150,13 +153,18 @@ void PlaceWinnerOnVictoryPad(edict_t *winner, int offset)
 	movedir[2] = -1;
 	VectorCopy(pad->s.origin, origin);
 	origin[2] -= 24;
-	gi.WriteByte (svc_temp_entity);
-	gi.WriteByte (TE_STEAM);
-	gi.WriteByte (100);
-	gi.WritePosition (origin);
-	gi.WriteDir (movedir);
-	gi.WriteByte (0);
-	gi.multicast (origin, MULTICAST_PVS);
+
+	//if map is going to repeat - don't put these here as we have no way to remove them 
+	//if map is not reloaded
+	if(strcmp(level.mapname, level.changemap)) {
+		gi.WriteByte (svc_temp_entity);
+		gi.WriteByte (TE_STEAM);
+		gi.WriteByte (100);
+		gi.WritePosition (origin);
+		gi.WriteDir (movedir);
+		gi.WriteByte (0);
+		gi.multicast (origin, MULTICAST_PVS);
+	}
 
 	//now we want to allow the winners to actually see themselves on the podium, creating a
 	//simple chasecam
@@ -390,13 +398,46 @@ void BeginIntermission (edict_t *targ)
 
 }
 
+void CheckDuelWinner(void) {
+	int	i;
+	int highscore, numplayers;
 
+	highscore = 0;
+	numplayers = 0;
+
+	for (i = 0; i < maxclients->value; i++) {
+		if(g_edicts[i+1].inuse && g_edicts[i+1].client) { 
+			if(g_edicts[i+1].client->resp.score > highscore)
+				highscore = g_edicts[i+1].client->resp.score;
+			if(g_edicts[i+1].client->pers.queue) //only people who are connected
+				numplayers++;
+		}
+	}
+
+	for (i = 0; i < maxclients->value; i++) {
+		if(g_edicts[i+1].inuse && g_edicts[i+1].client) {
+			if((g_edicts[i+1].client->resp.score < highscore) && g_edicts[i+1].client->pers.queue < 3) {
+				g_edicts[i+1].client->pers.queue = numplayers+1; //loser, kicked to the back of the line
+			}
+		}
+	}
+	for (i = 0; i < maxclients->value; i++) {
+		if(g_edicts[i+1].inuse && g_edicts[i+1].client) {
+			//move everyone else down a notch(never less than 0)
+			if(g_edicts[i+1].client->pers.queue > 1) 
+					g_edicts[i+1].client->pers.queue-=1; 
+		}
+	}
+}
 
 void EndIntermission(void)
 {
 	int		i;
 	edict_t	*ent;
 
+	if(g_duel->value)
+		CheckDuelWinner();
+
 	for (i=0 ; i<maxclients->value; i++)
 	{
 		ent = g_edicts + 1 + i;
@@ -457,7 +498,7 @@ void DeathmatchScoreboardMessage (edict_t *ent, edict_t *killer)
 	for (i=0 ; i<game.maxclients ; i++)
 	{
 		cl_ent = g_edicts + 1 + i;
-		if (!cl_ent->inuse || game.clients[i].resp.spectator)
+		if (!cl_ent->inuse || (!g_duel->value && game.clients[i].resp.spectator))
 			continue;
 
 		score = game.clients[i].resp.score;
@@ -503,9 +544,16 @@ void DeathmatchScoreboardMessage (edict_t *ent, edict_t *killer)
 		stringlength += j;
 		
 		// send the layout
-		Com_sprintf (entry, sizeof(entry),
-			"client %i %i %i %i %i %i ",
-			x, y, sorted[i], cl->resp.score, cl->ping, (level.framenum - cl->resp.enterframe)/600);
+		if(!cl->resp.spectator)
+			Com_sprintf (entry, sizeof(entry),
+				"client %i %i %i %i %i %i ",
+				x, y, sorted[i], cl->resp.score, cl->ping, (level.framenum - cl->resp.enterframe)/600);
+		else //duel mode will have queued spectators
+			Com_sprintf (entry, sizeof(entry),
+				"queued %i %i %i %i %i %i ",
+				x, y, sorted[i], cl->resp.score, cl->ping, cl->pers.queue-2);
+	
+		
 		j = strlen(entry);
 		if (stringlength + j > 1024)
 			break;
@@ -543,7 +591,7 @@ void DeathmatchScoreboardMessage (edict_t *ent, edict_t *killer)
 		strcpy(string + stringlength, entry);
 		stringlength +=j;
 	}
-	for(i = 0; i < 8; i++) {
+	for(i = 0; i < 9; i++) {
 
 		//in case of scenarios where a weapon is scoring multiple hits per shot(ie smartgun)
 		if(ent->client->resp.weapon_hits[i] > ent->client->resp.weapon_shots[i])
@@ -580,9 +628,12 @@ void DeathmatchScoreboardMessage (edict_t *ent, edict_t *killer)
 			case 7:
 				strcpy(weapname, "vaporizer");
 				break;
+			case 8:
+				strcpy(weapname, "violator");
+				break;
 		}
 		Com_sprintf(entry, sizeof(entry),
-			"xv %i yv %i string %s xv %i string %s ", x, y+((i+1)*8)+64, weapname, x+96, acc);
+			"xv %i yv %i string %s xv %i string %s ", x, y+((i+1)*9)+64, weapname, x+96, acc);
 		j = strlen(entry);
 		if(stringlength + j < 1024) {
 			strcpy(string + stringlength, entry);
@@ -731,8 +782,7 @@ G_SetStats
 void G_SetStats (edict_t *ent)
 {
 	gitem_t		*item;
-	int			index, cells;
-	int			power_armor_type;
+	int			index;
 	edict_t *e2;
 	int i, j;
 	int high_score = 0;
@@ -766,25 +816,9 @@ void G_SetStats (edict_t *ent)
 	//
 	// armor
 	//
-	power_armor_type = PowerArmorType (ent);
-	if (power_armor_type)
-	{
-		cells = ent->client->pers.inventory[ITEM_INDEX(FindItem ("cells"))];
-		if (cells == 0)
-		{	// ran out of cells for power armor
-			ent->flags &= ~FL_POWER_ARMOR;
-			gi.sound(ent, CHAN_ITEM, gi.soundindex("misc/power2.wav"), 1, ATTN_NORM, 0);
-			power_armor_type = 0;;
-		}
-	}
 
 	index = ArmorIndex (ent);
-	if (power_armor_type && (!index || (level.framenum & 8) ) )
-	{	// flash between power armor and other armor icon
-		ent->client->ps.stats[STAT_ARMOR_ICON] = gi.imageindex ("i_powershield");
-		ent->client->ps.stats[STAT_ARMOR] = cells;
-	}
-	else if (index)
+	if (index)
 	{
 		item = GetItemByIndex (index);
 		ent->client->ps.stats[STAT_ARMOR_ICON] = gi.imageindex (item->icon);
@@ -922,10 +956,7 @@ void G_SetStats (edict_t *ent)
 	//
 	// help icon / current weapon if not shown
 	//
-	if (ent->client->pers.helpchanged && (level.framenum&8) )
-		ent->client->ps.stats[STAT_HELPICON] = 0; //Gonna print something instead
-	else if ( (ent->client->pers.hand == CENTER_HANDED || ent->client->ps.fov > 91)
-		&& ent->client->pers.weapon)
+	if (ent->client->pers.weapon)
 		ent->client->ps.stats[STAT_HELPICON] = gi.imageindex (ent->client->pers.weapon->icon);
 	else
 		ent->client->ps.stats[STAT_HELPICON] = 0;
