@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -44,20 +44,20 @@ float SV_CalcRoll (vec3_t angles, vec3_t velocity)
 	float	sign;
 	float	side;
 	float	value;
-	
+
 	side = DotProduct (velocity, right);
 	sign = side < 0 ? -1 : 1;
 	side = fabs(side);
-	
+
 	value = sv_rollangle->value;
 
 	if (side < sv_rollspeed->value)
 		side = side * value / sv_rollspeed->value;
 	else
 		side = value;
-	
+
 	return side*sign;
-	
+
 }
 
 
@@ -75,7 +75,6 @@ void P_DamageFeedback (edict_t *player)
 	float	realcount, count, kick;
 	vec3_t	v;
 	int		r, l;
-	static	vec3_t	power_color = {0.0, 1.0, 0.0};
 	static	vec3_t	acolor = {1.0, 1.0, 1.0};
 	static	vec3_t	bcolor = {1.0, 0.0, 0.0};
 
@@ -89,7 +88,7 @@ void P_DamageFeedback (edict_t *player)
 		client->ps.stats[STAT_FLASHES] |= 2;
 
 	// total points of damage shot at the player this frame
-	count = (client->damage_blood + client->damage_armor + client->damage_parmor);
+	count = (client->damage_blood + client->damage_armor);
 	if (count == 0)
 		return;		// didn't take any damage
 
@@ -157,8 +156,6 @@ void P_DamageFeedback (edict_t *player)
 	// the color of the blend will vary based on how much was absorbed
 	// by different armors
 	VectorClear (v);
-	if (client->damage_parmor)
-		VectorMA (v, (float)client->damage_parmor/realcount, power_color, v);
 	if (client->damage_armor)
 		VectorMA (v, (float)client->damage_armor/realcount,  acolor, v);
 	if (client->damage_blood)
@@ -181,10 +178,10 @@ void P_DamageFeedback (edict_t *player)
 
 		VectorSubtract (client->damage_from, player->s.origin, v);
 		VectorNormalize (v);
-		
+
 		side = DotProduct (v, right);
 		client->v_dmg_roll = kick*side*0.3;
-		
+
 		side = -DotProduct (v, forward);
 		client->v_dmg_pitch = kick*side*0.3;
 
@@ -196,7 +193,6 @@ void P_DamageFeedback (edict_t *player)
 	//
 	client->damage_blood = 0;
 	client->damage_armor = 0;
-	client->damage_parmor = 0;
 	client->damage_knockback = 0;
 }
 
@@ -213,7 +209,7 @@ Auto pitching on slopes?
   fall from 256: 580 = 336400
   fall from 384: 720 = 518400
   fall from 512: 800 = 640000
-  fall from 640: 960 = 
+  fall from 640: 960 =
 
   damage = deltavelocity*deltavelocity  * 0.0001
 
@@ -225,10 +221,7 @@ void SV_CalcViewOffset (edict_t *ent)
 	float		bob;
 	float		ratio;
 	float		delta;
-	vec3_t		v;
-
-
-//===================================
+	vec3_t	v;
 
 	// base angles
 	angles = ent->client->ps.kick_angles;
@@ -245,11 +238,9 @@ void SV_CalcViewOffset (edict_t *ent)
 	else
 	{
 		// add angles based on weapon kick
-
 		VectorCopy (ent->client->kick_angles, angles);
 
 		// add angles based on damage kick
-
 		ratio = (ent->client->v_dmg_time - level.time) / DAMAGE_TIME;
 		if (ratio < 0)
 		{
@@ -262,21 +253,19 @@ void SV_CalcViewOffset (edict_t *ent)
 
 		// add pitch based on fall kick
 
-		ratio = (ent->client->fall_time - level.time) / FALL_TIME;
-		if (ratio < 0)
-			ratio = 0;
-		angles[PITCH] += ratio * ent->client->fall_value;
+// 		ratio = (ent->client->fall_time - level.time) / FALL_TIME;
+// 		if (ratio < 0)
+// 			ratio = 0;
+// 		angles[PITCH] += ratio * ent->client->fall_value;
 
 		// add angles based on velocity
-
 		delta = DotProduct (ent->velocity, forward);
 		angles[PITCH] += delta*run_pitch->value;
-		
+
 		delta = DotProduct (ent->velocity, right);
 		angles[ROLL] += delta*run_roll->value;
 
 		// add angles based on bob
-
 		delta = bobfracsin * bob_pitch->value * xyspeed;
 		if (ent->client->ps.pmove.pm_flags & PMF_DUCKED)
 			delta *= 6;		// crouching
@@ -289,57 +278,48 @@ void SV_CalcViewOffset (edict_t *ent)
 		angles[ROLL] += delta;
 	}
 
-//===================================
-
 	// base origin
-
 	VectorClear (v);
 
 	// add view height
-
 	v[2] += ent->viewheight;
 
 	// add fall height
-
 	ratio = (ent->client->fall_time - level.time) / FALL_TIME;
 	if (ratio < 0)
 		ratio = 0;
-	v[2] -= ratio * ent->client->fall_value * 0.4;
+	v[2] -= ratio * ent->client->fall_value;
 
 	// add bob height
-
 	bob = bobfracsin * xyspeed * bob_up->value;
 	if (bob > 6)
 		bob = 6;
-	//gi.DebugGraph (bob *2, 255);
 	v[2] += bob;
 
 	// add kick offset
-
 	VectorAdd (v, ent->client->kick_origin, v);
 
 	// absolutely bound offsets
 	// so the view can never be outside the player box
-
 	if (!ent->client->chasetoggle)
-    {
-	    if (v[0] < -14)
-		    v[0] = -14;
-        else if (v[0] > 14)
-            v[0] = 14;
-        if (v[1] < -14)
-            v[1] = -14;
-        else if (v[1] > 14)
-            v[1] = 14;
-        if (v[2] < -22)
-            v[2] = -22;
-        else if (v[2] > 30)
-            v[2] = 30; 
+	{
+	if (v[0] < -14)
+		v[0] = -14;
+	else if (v[0] > 14)
+		v[0] = 14;
+	if (v[1] < -14)
+		v[1] = -14;
+	else if (v[1] > 14)
+		v[1] = 14;
+	if (v[2] < -22)
+		v[2] = -22;
+	else if (v[2] > 30)
+		v[2] = 30;
 	}
 	else
-	{ 
-        VectorSet (v, 0, 0, 0);
-        if (ent->client->chasecam != NULL)
+	{
+        	VectorSet (v, 0, 0, 0);
+        	if (ent->client->chasecam != NULL)
         {
             ent->client->ps.pmove.origin[0] = ent->client->chasecam->s.origin[0]*8;
             ent->client->ps.pmove.origin[1] = ent->client->chasecam->s.origin[1]*8;
@@ -358,7 +338,6 @@ SV_CalcGunOffset
 void SV_CalcGunOffset (edict_t *ent)
 {
 	int		i;
-	float	delta;
 
 	// gun angles from bobbing
 	ent->client->ps.gunangles[ROLL] = xyspeed * bobfracsin * 0.005;
@@ -371,26 +350,7 @@ void SV_CalcGunOffset (edict_t *ent)
 
 	ent->client->ps.gunangles[PITCH] = xyspeed * bobfracsin * 0.005;
 
-	// gun angles from delta movement
-	for (i=0 ; i<3 ; i++)
-	{
-		delta = ent->client->oldviewangles[i] - ent->client->ps.viewangles[i];
-		if (delta > 180)
-			delta -= 360;
-		if (delta < -180)
-			delta += 360;
-		if (delta > 45)
-			delta = 45;
-		if (delta < -45)
-			delta = -45;
-		if (i == YAW)
-			ent->client->ps.gunangles[ROLL] += 0.1*delta;
-		ent->client->ps.gunangles[i] += 0.2 * delta;
-	}
-
-	// gun height
 	VectorClear (ent->client->ps.gunoffset);
-//	ent->ps->gunorigin[2] += bob;
 
 	// gun_x / gun_y / gun_z are development tools
 	for (i=0 ; i<3 ; i++)
@@ -398,6 +358,14 @@ void SV_CalcGunOffset (edict_t *ent)
 		ent->client->ps.gunoffset[i] += forward[i]*(gun_y->value);
 		ent->client->ps.gunoffset[i] += right[i]*gun_x->value;
 		ent->client->ps.gunoffset[i] += up[i]* (-gun_z->value);
+
+	}
+	
+	//landing on jumps
+	if(ent->s.event == EV_FALLSHORT || ent->s.event == EV_FALL || ent->s.event == EV_FALLFAR) {
+		ent->client->ps.gunoffset[2] -=1.5;
+		ent->client->ps.gunangles[PITCH] -= 1;
+		ent->client->ps.gunangles[ROLL] -= 1;
 	}
 }
 
@@ -434,7 +402,7 @@ void SV_CalcBlend (edict_t *ent)
 	vec3_t	vieworg;
 	int		remaining;
 
-	ent->client->ps.blend[0] = ent->client->ps.blend[1] = 
+	ent->client->ps.blend[0] = ent->client->ps.blend[1] =
 		ent->client->ps.blend[2] = ent->client->ps.blend[3] = 0;
 
 	// add for contents
@@ -456,11 +424,11 @@ void SV_CalcBlend (edict_t *ent)
 	//vehicles(flying)
 	if ( Jet_Active(ent) )
 	{
-		
+
 		/*update the fuel time*/
 		ent->client->Jet_remaining = ent->client->Jet_framenum - level.framenum;
 
-		/*if no fuel remaining, remove vehicle from inventory*/ 
+		/*if no fuel remaining, remove vehicle from inventory*/
 		if ( ent->client->Jet_remaining == 0 ) {
 		  ent->client->pers.inventory[ITEM_INDEX(FindItem("bomber"))] = 0;
 		  ent->client->pers.inventory[ITEM_INDEX(FindItem("strafer"))] = 0;
@@ -473,7 +441,7 @@ void SV_CalcBlend (edict_t *ent)
 		/*Play jetting sound every 0.6 secs (sound of monster icarus)*/
 		if ( ((int)ent->client->Jet_remaining % 6) == 0 ) {
 		  gi.sound (ent, CHAN_AUTO, gi.soundindex("vehicles/bomberidle.wav"), 0.9, ATTN_NORM, 0);
-		  
+
 		  // send muzzle flash
 		  gi.WriteByte (svc_muzzleflash);
 		  gi.WriteShort (ent-g_edicts);
@@ -498,7 +466,7 @@ void SV_CalcBlend (edict_t *ent)
 		if (remaining > 30 || (remaining & 4) )
 			SV_AddBlend (0, 0, 1, 0.08, ent->client->ps.blend);
 	}
-	else if (ent->client->invincible_framenum > level.framenum)
+	else if (ent->client->invincible_framenum > level.framenum || ent->client->spawnprotected)
 	{
 		remaining = ent->client->invincible_framenum - level.framenum;
 		if (remaining == 30)	// beginning to fade
@@ -558,6 +526,9 @@ void P_FallingDamage (edict_t *ent)
 
 	if (ent->movetype == MOVETYPE_NOCLIP)
 		return;
+	
+	if(joustmode->value)
+		return;
 
 	if ((ent->client->oldvelocity[2] < 0) && (ent->velocity[2] > ent->client->oldvelocity[2]) && (!ent->groundentity))
 	{
@@ -573,7 +544,7 @@ void P_FallingDamage (edict_t *ent)
 
 	// never take damage if just release grapple or on grapple
 	if (level.time - ent->client->ctf_grapplereleasetime <= FRAMETIME * 2 ||
-		(ent->client->ctf_grapple && 
+		(ent->client->ctf_grapple &&
 		ent->client->ctf_grapplestate > CTF_GRAPPLE_STATE_FLY))
 		return;
 
@@ -585,18 +556,18 @@ void P_FallingDamage (edict_t *ent)
 	if (ent->waterlevel == 1)
 		delta *= 0.5;
 
-	if (delta < 1)
+	if (delta < 3)
 		return;
 
-	if (delta < 15)
-	{
-		ent->s.event = EV_FOOTSTEP;
-		return;
-	}
-
-	ent->client->fall_value = delta*0.5;
-	if (ent->client->fall_value > 40)
-		ent->client->fall_value = 40;
+// 	if (delta < 15)
+// 	{
+// 		ent->s.event = EV_FOOTSTEP;
+// 		return;
+// 	}
+	
+	ent->client->fall_value = delta;
+	if (ent->client->fall_value > 20)
+		ent->client->fall_value = 20;
 	ent->client->fall_time = level.time + FALL_TIME;
 
 	if (delta > 30)
@@ -612,6 +583,8 @@ void P_FallingDamage (edict_t *ent)
 		damage = (delta-30)/2;
 		if (damage < 1)
 			damage = 1;
+		if (damage > 10)
+			damage = 10;
 		VectorSet (dir, 0, 0, 1);
 
 		if (!deathmatch->value || !((int)dmflags->value & DF_NO_FALLING) )
@@ -705,7 +678,7 @@ void P_WorldEffects (void)
 		// if out of air, start drowning
 		if (current_player->air_finished < level.time)
 		{	// drown!
-			if (current_player->client->next_drown_time < level.time 
+			if (current_player->client->next_drown_time < level.time
 				&& current_player->health > 0)
 			{
 				current_player->client->next_drown_time = level.time + 1;
@@ -782,7 +755,6 @@ G_SetClientEffects
 */
 void G_SetClientEffects (edict_t *ent)
 {
-	int		pa_type;
 	int		remaining;
 
 	ent->s.effects = 0;
@@ -791,26 +763,12 @@ void G_SetClientEffects (edict_t *ent)
 	if (ent->health <= 0 || level.intermissiontime)
 		return;
 
-	if (ent->powerarmor_time > level.time)
-	{
-		pa_type = PowerArmorType (ent);
-		if (pa_type == POWER_ARMOR_SCREEN)
-		{
-			ent->s.effects |= EF_POWERSCREEN;
-		}
-		else if (pa_type == POWER_ARMOR_SHIELD)
-		{
-			ent->s.effects |= EF_COLOR_SHELL;
-			ent->s.renderfx |= RF_SHELL_GREEN;
-		}
-	}
-
 	if(ctf->value)
 		CTFEffects(ent);
 
 	if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value)
 		TeamEffects(ent);
-	
+
 	if (ent->client->quad_framenum > level.framenum)
 	{
 		remaining = ent->client->quad_framenum - level.framenum;
@@ -832,6 +790,9 @@ void G_SetClientEffects (edict_t *ent)
 		ent->s.renderfx |= (RF_SHELL_RED|RF_SHELL_GREEN|RF_SHELL_BLUE);
 	}
 
+	if(ent->client->spawnprotected)
+		ent->s.effects |= EF_PENT;
+
 }
 
 
@@ -883,12 +844,8 @@ void G_SetClientSound (edict_t *ent)
 
 	if (ent->waterlevel && (ent->watertype&(CONTENTS_LAVA|CONTENTS_SLIME)) )
 		ent->s.sound = snd_fry;
-	else if (strcmp(weap, "weapon_railgun") == 0)
-		ent->s.sound = gi.soundindex("weapons/rg_hum.wav");
-	else if (strcmp(weap, "weapon_machinegun") == 0)
-		ent->s.sound = gi.soundindex("world/hum1.wav");
 	else if (strcmp(weap, "weapon_bfg") == 0)
-		ent->s.sound = gi.soundindex("world/hum1.wav");
+		ent->s.sound = gi.soundindex("weapons/vaporizer_hum.wav");
 	else if (strcmp(weap, "weapon_shotgun") == 0)
 		ent->s.sound = gi.soundindex("weapons/smartgun_hum.wav");
 	else if (ent->client->weapon_sound)
@@ -907,27 +864,10 @@ void G_SetClientFrame (edict_t *ent)
 	gclient_t	*client;
 	qboolean	duck, run;
 	//vehicles
-	gitem_t *vehicle;
-	
-	vehicle = FindItemByClassname("item_bomber");
 
-	if (ent->client->pers.inventory[ITEM_INDEX(vehicle)]) { //don't animate the vehicle(yet!)
+	if (ent->in_vehicle) { //don't animate the vehicle(yet!)
 		ent->s.frame = 0;
-		return;	
-	}
-
-	vehicle = FindItemByClassname("item_strafer");
-
-	if (ent->client->pers.inventory[ITEM_INDEX(vehicle)]) { //don't animate the vehicle(yet!)
-		ent->s.frame = 0;
-		return;	
-	}
-	
-	vehicle = FindItemByClassname("item_hover");
-
-	if (ent->client->pers.inventory[ITEM_INDEX(vehicle)]) { //don't animate the vehicle(yet!)
-		ent->s.frame = 0;
-		return;	
+		return;
 	}
 
 	if (ent->s.modelindex != 255)
@@ -951,7 +891,7 @@ void G_SetClientFrame (edict_t *ent)
 		goto newanim;
 	if (!ent->groundentity && client->anim_priority <= ANIM_WAVE)
 		goto newanim;
-	
+
 	//check for running while shooting
 	if (run && client->anim_priority == ANIM_ATTACK)
 		goto newanim;
@@ -1048,13 +988,13 @@ void ClientEndServerFrame (edict_t *ent)
 	qboolean haste, sproing;
 	current_player = ent;
 	current_client = ent->client;
-	
+
 
 	//
 	// If the origin or velocity have changed since ClientThink(),
 	// update the pmove values.  This will happen when the client
 	// is pushed by a bmodel or kicked by an explosion.
-	// 
+	//
 	// If it wasn't updated here, the view position would lag a frame
 	// behind the body position when pushed -- "sinking into plats"
 	//
@@ -1098,14 +1038,14 @@ void ClientEndServerFrame (edict_t *ent)
 	// calculate speed and cycle to be used for
 	// all cyclic walking effects
 	//
-	
+
 	haste = current_client->haste_framenum > level.framenum;
 	if(haste) {
 		AngleVectors (ent->s.angles, addspeed, right, up);
 		addspeed[0] *= 100;
 		addspeed[1] *= 100;
  		VectorAdd(ent->velocity, addspeed, ent->velocity);
-		
+
 	}
 	sproing = current_client->sproing_framenum > level.framenum;
 	if(sproing)
@@ -1127,7 +1067,7 @@ void ClientEndServerFrame (edict_t *ent)
 		else
 			bobmove = 0.0625;
 	}
-	
+
 	bobtime = (current_client->bobtime += bobmove);
 
 	if (current_client->ps.pmove.pm_flags & PMF_DUCKED)
