@@ -97,36 +97,20 @@ void PlayerNoise(edict_t *who, vec3_t where, int type)
 
 qboolean Pickup_Weapon (edict_t *ent, edict_t *other)
 {
-	int			index;
+	int		index;
 	gitem_t		*ammo;
-	gitem_t *vehicle;
-	
-	vehicle = FindItemByClassname("item_bomber");
 
-	if (other->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return false;	
+	if (other->in_vehicle) {
+		return false;
 	}
 
-	vehicle = FindItemByClassname("item_strafer");
-
-	if (other->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return false;	
-	}
-
-	vehicle = FindItemByClassname("item_hover");
-
-	if (other->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return false;	
-	}
-
-
 	index = ITEM_INDEX(ent->item);
 
 	//mutators
 	if(instagib->value || rocket_arena->value)
 		return false; //why pick them up in these modes?
 
-	if ( ( ((int)(dmflags->value) & DF_WEAPONS_STAY)) 
+	if ( ( ((int)(dmflags->value) & DF_WEAPONS_STAY))
 		&& other->client->pers.inventory[index])
 	{
 		if (!(ent->spawnflags & (DROPPED_ITEM | DROPPED_PLAYER_ITEM) ) )
@@ -135,14 +119,17 @@ qboolean Pickup_Weapon (edict_t *ent, edict_t *other)
 
 	other->client->pers.inventory[index]++;
 
+
 	if (!(ent->spawnflags & DROPPED_ITEM) )
 	{
 		// give them some ammo with it
 		ammo = FindItem (ent->item->ammo);
 		if ( (int)dmflags->value & DF_INFINITE_AMMO )
-			Add_Ammo (other, ammo, 1000);
+			Add_Ammo (other, ammo, 1000, true, true);
+		else if (ent->spawnflags & DROPPED_PLAYER_ITEM)
+			Add_Ammo (other, ammo, ammo->quantity, true, true); //DROPPED WEAPON give full ammo
 		else
-			Add_Ammo (other, ammo, ammo->quantity);
+			Add_Ammo (other, ammo, ammo->quantity, true, false);
 
 		if (! (ent->spawnflags & DROPPED_PLAYER_ITEM) )
 		{
@@ -151,12 +138,12 @@ qboolean Pickup_Weapon (edict_t *ent, edict_t *other)
 				if ((int)(dmflags->value) & DF_WEAPONS_STAY)
 					ent->flags |= FL_RESPAWN;
 				else
-					SetRespawn (ent, 20); //was 30
+					SetRespawn (ent, 5); //was 30
 			}
 		}
 	}
 
-	if (other->client->pers.weapon != ent->item && 
+	if (other->client->pers.weapon != ent->item &&
 		(other->client->pers.inventory[index] == 1) &&
 		( !deathmatch->value || other->client->pers.weapon == FindItem("blaster") ) )
 		other->client->newweapon = ent->item;
@@ -177,15 +164,37 @@ a seperate file.
 
 int Q2_FindFile (char *filename, FILE **file)
 {
-			
-	*file = fopen (filename, "rb");
+	char	name[MAX_OSPATH];
+	cvar_t	*game;
+	qboolean found = false;
+
+	game = gi.cvar("game", "", 0);
+
+	if (!*game->string) //if there is a gamedir try here first
+		sprintf (name, "%s/%s", GAMEVERSION, filename);
+	else
+		sprintf (name, "%s/%s", game->string, filename);
+
+	*file = fopen (name, "rb");
 	if (!*file) {
 		*file = NULL;
-		return -1;
+		found = false;
 	}
 	else
 		return 1;
 
+	if(!found) { //try basedir
+		sprintf (name, "%s/%s", GAMEVERSION, filename);
+		*file = fopen (name, "rb");
+		if (!*file) {
+			*file = NULL;
+			return -1;
+		}
+		else
+			return 1;
+	}
+	else
+		return -1;
 }
 
 /*
@@ -205,7 +214,7 @@ void ChangeWeapon (edict_t *ent)
 	int done;
 	char	weaponpath[MAX_OSPATH] = " ";
 	FILE *file;
-	
+
 	ent->client->pers.lastweapon = ent->client->pers.weapon;
 	ent->client->pers.weapon = ent->client->newweapon;
 	ent->client->newweapon = NULL;
@@ -235,6 +244,10 @@ void ChangeWeapon (edict_t *ent)
 	ent->client->ps.gunframe = 0;
 	ent->client->ps.gunindex = gi.modelindex(ent->client->pers.weapon->view_model);
 
+	if (ent->in_vehicle) {
+		return;
+	}
+
 	//set up code to set player world weapon model, as well as some hacks :(
 
 	info = Info_ValueForKey (ent->client->pers.userinfo, "skin");
@@ -256,7 +269,9 @@ void ChangeWeapon (edict_t *ent)
 	weaponmodel[0] = 0;
 
 	sprintf(weaponmodel, "players/%s%s", weaponame, "weapon.md2"); //default
-	
+
+	if(ent->client->pers.weapon->view_model == "models/weapons/v_violator/tris.md2")
+		sprintf(weaponmodel, "players/%s%s", weaponame, "w_violator.md2");
 	if(ent->client->pers.weapon->view_model == "models/weapons/v_rocket/tris.md2")
 		sprintf(weaponmodel, "players/%s%s", weaponame, "w_rlauncher.md2");
 	if(ent->client->pers.weapon->view_model == "models/weapons/v_blast/tris.md2")
@@ -275,12 +290,12 @@ void ChangeWeapon (edict_t *ent)
 		sprintf(weaponmodel, "players/%s%s", weaponame, "w_chaingun.md2");
 	if(ent->client->pers.weapon->view_model == "vehicles/deathball/v_wep.md2")
 		sprintf(weaponmodel, "players/%s%s", weaponame, "w_machinegun.md2");
-	
-	
-	sprintf(weaponpath, "data1/%s", weaponmodel);
+
+
+	sprintf(weaponpath, "%s", weaponmodel);
 	Q2_FindFile (weaponpath, &file); //does it really exist?
 	if(!file) {
-		sprintf(weaponpath, "data1/%s", weaponame, "weapon.md2"); //no w_weaps, do we have this model?
+		sprintf(weaponpath, "%s", weaponame, "weapon.md2"); //no w_weaps, do we have this model?
 		Q2_FindFile (weaponpath, &file);
 		if(!file) //server does not have this player model
 			sprintf(weaponmodel, "players/martianenforcer/weapon.md2");//default player(martian)
@@ -300,7 +315,7 @@ void ChangeWeapon (edict_t *ent)
 	//play a sound like in Q3, except for blaster, so it doesn't do it on spawn.
 	if(!(ent->client->pers.weapon->view_model == "models/weapons/v_blast/tris.md2"))
 		gi.sound(ent, CHAN_VOICE, gi.soundindex("weapons/whoosh.wav"), 1, ATTN_NORM, 0);
-		
+
 	ent->client->anim_priority = ANIM_PAIN;
 	if(ent->client->ps.pmove.pm_flags & PMF_DUCKED)
 	{
@@ -311,7 +326,7 @@ void ChangeWeapon (edict_t *ent)
 	{
 			ent->s.frame = FRAME_pain301;
 			ent->client->anim_end = FRAME_pain304;
-			
+
 	}
 
 }
@@ -357,7 +372,7 @@ void NoAmmoWeaponChange (edict_t *ent)
 		ent->client->newweapon = FindItem ("Alien Smartgun");
 		return;
 	}
-	
+
 	if ( ent->client->pers.inventory[ITEM_INDEX(FindItem("cells"))]
 		&& ent->client->pers.inventory[ITEM_INDEX(FindItem("Alien Disruptor"))] )
 	{
@@ -409,29 +424,8 @@ void Use_Weapon (edict_t *ent, gitem_t *item)
 	int			ammo_index;
 	gitem_t		*ammo_item;
 
-	gitem_t *vehicle;
-	
-	vehicle = FindItemByClassname("item_bomber");
-
-	if (ent->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return;	
-	}
-
-	vehicle = FindItemByClassname("item_strafer");
-
-	if (ent->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return;	
-	}
-
-	vehicle = FindItemByClassname("item_hover");
-
-	if (ent->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return;	
-	}
-
-	vehicle = FindItemByClassname("item_deathball");
-	if (ent->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return;	
+	if (ent->in_vehicle || ent->in_deathball) {
+		return;
 	}
 
 	//mutators
@@ -529,7 +523,7 @@ void Weapon_Generic (edict_t *ent, int FRAME_ACTIVATE_LAST, int FRAME_FIRE_LAST,
 			ent->client->ps.gunframe = FRAME_IDLE_FIRST;
 			return;
 		}
-		else if (ent->client->ps.gunframe == FRAME_ACTIVATE_LAST)
+		else if (ent->client->ps.gunframe == FRAME_ACTIVATE_LAST-2)
 		{
 			ent->client->weaponstate = WEAPON_READY;
 			ent->client->ps.gunframe = FRAME_IDLE_FIRST;
@@ -543,7 +537,7 @@ void Weapon_Generic (edict_t *ent, int FRAME_ACTIVATE_LAST, int FRAME_FIRE_LAST,
 	if ((ent->client->newweapon) && (ent->client->weaponstate != WEAPON_FIRING))
 	{
 		ent->client->weaponstate = WEAPON_DROPPING;
-		ent->client->ps.gunframe = FRAME_DEACTIVATE_FIRST;
+		ent->client->ps.gunframe = FRAME_DEACTIVATE_FIRST+2;
 		return;
 	}
 
@@ -551,8 +545,10 @@ void Weapon_Generic (edict_t *ent, int FRAME_ACTIVATE_LAST, int FRAME_FIRE_LAST,
 	{
 		if ( ((ent->client->latched_buttons|ent->client->buttons) & BUTTON_ATTACK) )
 		{
+			ent->client->spawnprotected = false;
+
 			ent->client->latched_buttons &= ~BUTTON_ATTACK;
-			if ((!ent->client->ammo_index) || 
+			if ((!ent->client->ammo_index) ||
 				( ent->client->pers.inventory[ent->client->ammo_index] >= ent->client->pers.weapon->quantity))
 			{
 				ent->client->ps.gunframe = FRAME_FIRE_FIRST;
@@ -586,8 +582,10 @@ void Weapon_Generic (edict_t *ent, int FRAME_ACTIVATE_LAST, int FRAME_FIRE_LAST,
 		//alt fire
 		else if ( ((ent->client->latched_buttons|ent->client->buttons) & BUTTON_ATTACK2) )
 		{
+			ent->client->spawnprotected = false;
+
 			ent->client->latched_buttons &= ~BUTTON_ATTACK2;
-			if ((!ent->client->ammo_index) || 
+			if ((!ent->client->ammo_index) ||
 				( ent->client->pers.inventory[ent->client->ammo_index] >= ent->client->pers.weapon->quantity))
 			{
 				ent->client->ps.gunframe = FRAME_FIRE_FIRST;
@@ -670,26 +668,26 @@ void weapon_plasma_fire (edict_t *ent)
 	vec3_t		start;
 	vec3_t		forward, right;
 	vec3_t		offset;
-	int			damage;
-	int			kick;
-	int			buildup;
+
+	int		damage;
+	int		kick;
+	int		buildup;
 
 	if(instagib->value) {
 		damage = 200;
 		kick = 200;
+	} else {
+		damage = 60;
+		kick = 60;
 	}
-	else {
-		damage = 55;
-		kick = 50;
-	}
-	
+
 	if (is_quad)
 	{
 		damage *= 4;
 		kick *= 4;
 	}
 
-	//alt fire 
+	//alt fire
 	if (ent->client->buttons & BUTTON_ATTACK2) {
 		ent->client->ps.fov = 20;
 		buildup = damage_buildup; //int, for the pic flag
@@ -713,7 +711,7 @@ void weapon_plasma_fire (edict_t *ent)
 
 	//alt fire - reset some things
 	ent->client->ps.fov = atoi(Info_ValueForKey(ent->client->pers.userinfo, "fov")); //alt fire - reset the fov;
-	ent->client->ps.stats[STAT_ZOOMED] = 0;	
+	ent->client->ps.stats[STAT_ZOOMED] = 0;
 	damage_buildup = 1.0;
 
 	// send muzzle flash
@@ -731,7 +729,7 @@ void weapon_plasma_fire (edict_t *ent)
 
 void Weapon_Disruptor (edict_t *ent)
 {
-	static int	pause_frames[]	= {15, 0};
+	static int	pause_frames[]	= {42, 0};
 	static int	fire_frames[]	= {5, 0};
 	static int	excessive_fire_frames[] = {5,7,9,11,0};
 
@@ -746,22 +744,10 @@ void weapon_energy_field_fire (edict_t *ent)
 	vec3_t		start;
 	vec3_t		forward, right;
 	vec3_t		offset;
-	int			damage, radius_damage, damage_radius;
-	int			kick;
-
-	radius_damage = 100;
-	damage_radius = 150;
-
-	if (deathmatch->value)
-	{	// normal damage is too extreme in dm
-		damage = 100;
-		kick = 200;
-	}
-	else
-	{
-		damage = 500;
-		kick = 200;
-	}
+	int		damage = 100;
+	int		radius_damage = 100;
+	int		damage_radius = 150;
+	int		kick = 200;
 
 	if (is_quad)
 	{
@@ -790,7 +776,7 @@ void weapon_energy_field_fire (edict_t *ent)
 
 	VectorSet(offset, 32, 5,  ent->viewheight-5);
 	P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
-	
+
 	if(ent->client->ps.gunframe == 12) {
 
 		VectorAdd(start, forward, start);
@@ -819,7 +805,7 @@ void weapon_energy_field_fire (edict_t *ent)
 		else {
 				fire_energy_field (ent, start, forward, damage, kick);
 				if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
-					ent->client->pers.inventory[ent->client->ammo_index]= ent->client->pers.inventory[ent->client->ammo_index]-2;	
+					ent->client->pers.inventory[ent->client->ammo_index]= ent->client->pers.inventory[ent->client->ammo_index]-2;
 		}
 
 		// send muzzle flash
@@ -835,7 +821,7 @@ void weapon_energy_field_fire (edict_t *ent)
 		gi.WritePosition (start);
 		gi.multicast (start, MULTICAST_PVS);
 
-	
+
 		gi.sound(ent, CHAN_AUTO, gi.soundindex("weapons/energyfield.wav"), 1, ATTN_NORM, 0);
 		ent->client->weapon_sound = 0;
 
@@ -845,7 +831,7 @@ void weapon_energy_field_fire (edict_t *ent)
 }
 void Weapon_Vaporizer (edict_t *ent)
 {
-	static int	pause_frames[]	= {25, 0};
+	static int	pause_frames[]	= {48, 0};
 	static int	fire_frames[]	= {6, 7, 12, 13, 0};
 
 	Weapon_Generic (ent, 5, 18, 48, 52, pause_frames, fire_frames, weapon_energy_field_fire);
@@ -863,11 +849,11 @@ void weapon_flamethrower_fire (edict_t *ent)
 {
 	vec3_t	offset, start;
 	vec3_t	forward, right;
-	int		damage = 25;
+	int	damage = 25;
 	float	damage_radius = 200;
 
 	if((ent->client->buttons & BUTTON_ATTACK2) && ent->client->ps.gunframe == 6) { //shoot a fireball
-		
+
 		AngleVectors (ent->client->v_angle, forward, right, NULL);
 
 		VectorSet(offset, 8, 8, ent->viewheight-8);
@@ -893,7 +879,7 @@ void weapon_flamethrower_fire (edict_t *ent)
 
 		return;
 	}
-		
+
 	if (!(ent->client->buttons & BUTTON_ATTACK))
 	{
 		ent->client->ps.gunframe = 17;
@@ -926,12 +912,12 @@ void weapon_flamethrower_fire (edict_t *ent)
 		if(ent->client->pers.inventory[ent->client->ammo_index] < 0)
 			ent->client->pers.inventory[ent->client->ammo_index] = 0;
 	}
-		
+
 }
 
 void Weapon_Flame (edict_t *ent)
 {
-	static int	pause_frames[]	= {20, 0};
+	static int	pause_frames[]	= {36, 0};
 	static int	fire_frames[]	= {5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 0};
 
 	Weapon_Generic (ent, 5, 16, 36, 40, pause_frames, fire_frames, weapon_flamethrower_fire);
@@ -996,8 +982,8 @@ void Weapon_RocketLauncher_Fire (edict_t *ent)
 
 void Weapon_RocketLauncher (edict_t *ent)
 {
-	static int	pause_frames[]	= {18, 0};
-	static int	fire_frames[]	= {7, 0};
+	static int	pause_frames[]	= {52, 0};
+	static int	fire_frames[]	= {6, 0};
 	static int	excessive_fire_frames[]	= {5,7,9,11,13, 0};
 
 	if(excessive->value)
@@ -1009,7 +995,7 @@ void Weapon_RocketLauncher (edict_t *ent)
 /*
 ======================================================================
 
-BLASTER 
+BLASTER
 
 ======================================================================
 */
@@ -1054,11 +1040,11 @@ void Blaster_Fire (edict_t *ent, vec3_t g_offset, int damage, qboolean hyper, in
 	}
 	else {
 		if(ent->client->buttons & BUTTON_ATTACK2) { //alt fire
-			fire_blaster_beam (ent, start, forward, damage/2, 0, false);
+			fire_blaster_beam (ent, start, forward, (int)((float)damage/1.4), 0, false);
 			gi.sound(ent, CHAN_AUTO, gi.soundindex("vehicles/shootlaser.wav"), 1, ATTN_NORM, 0);
 		}
 		else
-			fire_blasterball (ent, start, forward, damage, 1000, effect, hyper);
+			fire_blasterball (ent, start, forward, damage, 1200, effect, hyper);
 	}
 	// send muzzle flash
 	if(!(ent->client->buttons & BUTTON_ATTACK2)){
@@ -1066,7 +1052,7 @@ void Blaster_Fire (edict_t *ent, vec3_t g_offset, int damage, qboolean hyper, in
 		gi.WriteShort (ent-g_edicts);
 		if (hyper)
 			gi.WriteByte (MZ_HYPERBLASTER | is_silenced);
-		else 
+		else
 			gi.WriteByte (MZ_BLASTER | is_silenced);
 		gi.multicast (ent->s.origin, MULTICAST_PVS);
 		PlayerNoise(ent, start, PNOISE_WEAPON);
@@ -1088,17 +1074,15 @@ void Weapon_Blaster_Fire (edict_t *ent)
 {
 	int		damage;
 
-	if (deathmatch->value)
-		damage = 20; //was 15
-	else
-		damage = 25;
+	damage = 30;
+
 	Blaster_Fire (ent, vec3_origin, damage, false, EF_BLASTER);
 	ent->client->ps.gunframe++;
 }
 
 void Weapon_Blaster (edict_t *ent)
 {
-	static int	pause_frames[]	= {10, 0};
+	static int	pause_frames[]	= {52, 0};
 	static int	fire_frames[]	= {5,0};
 	static int  excessive_fire_frames[] = {5,6,7,8,0};
 
@@ -1116,7 +1100,7 @@ void Weapon_Bomber_Fire (edict_t *ent)
 	int		damage;
 	float	damage_radius;
 	int		radius_damage;
-    
+
 	damage = 150;
 	radius_damage = 175;
 	damage_radius = 250;
@@ -1135,8 +1119,8 @@ void Weapon_Bomber_Fire (edict_t *ent)
 	P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
 	forward[0] = forward[0] * 2.6;
 	forward[1] = forward[1] * 2.6;
-	fire_bomb (ent, start, forward, damage, 250, damage_radius, radius_damage, 8); 
-	
+	fire_bomb (ent, start, forward, damage, 250, damage_radius, radius_damage, 8);
+
 	// send muzzle flash
 	gi.WriteByte (svc_muzzleflash);
 	gi.WriteShort (ent-g_edicts);
@@ -1186,11 +1170,11 @@ void Weapon_Strafer_Fire (edict_t *ent)
 
 	right[0] = right[0] * 5;
 	right[1] = right[1] * 5;
-	
+
 	P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
 
 	fire_blaster_beam (ent, start, forward, damage, 0, true);
-	
+
 	// send muzzle flash
 	gi.WriteByte (svc_muzzleflash);
 	gi.WriteShort (ent-g_edicts);
@@ -1218,7 +1202,7 @@ void Weapon_Strafer_Fire (edict_t *ent)
 	P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
 
 	fire_blaster_beam (ent, start, forward, damage, 0, true);
-	
+
 	// send muzzle flash
 	gi.WriteByte (svc_muzzleflash);
 	gi.WriteShort (ent-g_edicts);
@@ -1271,7 +1255,7 @@ void Weapon_Hover_Fire (edict_t *ent)
 	P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
 
 	fire_hover_beam (ent, start, forward, damage, 0, true);
-	
+
 	// send muzzle flash
 	gi.WriteByte (svc_muzzleflash);
 	gi.WriteShort (ent-g_edicts);
@@ -1280,10 +1264,10 @@ void Weapon_Hover_Fire (edict_t *ent)
 
 	VectorAdd(start, forward, start);
 	gi.WriteByte (svc_temp_entity);
-	gi.WriteByte (TE_BLASTER_MUZZLEFLASH);
+	gi.WriteByte (TE_CHAINGUNSMOKE);
 	gi.WritePosition (start);
 	gi.multicast (start, MULTICAST_PVS);
-	
+
 	ent->client->ps.gunframe++;
 
 	gi.sound (ent, CHAN_WEAPON, gi.soundindex("weapons/biglaser.wav"), 1, ATTN_NORM, 0);
@@ -1308,7 +1292,7 @@ void Weapon_Beamgun_Fire (edict_t *ent)
 
 	if (!((ent->client->buttons & BUTTON_ATTACK) || (ent->client->buttons & BUTTON_ATTACK2)))
 	{
-		ent->client->ps.gunframe++;
+		ent->client->ps.gunframe = 25;
 	}
 	else
 	{
@@ -1345,15 +1329,15 @@ void Weapon_Beamgun_Fire (edict_t *ent)
 		}
 
 		ent->client->ps.gunframe++;
-		if (ent->client->ps.gunframe == 19 && ent->client->pers.inventory[ent->client->ammo_index])
+		if (ent->client->ps.gunframe == 24 && ent->client->pers.inventory[ent->client->ammo_index])
 			ent->client->ps.gunframe = 6;
 	}
 }
 
 void Weapon_Beamgun (edict_t *ent)
 {
-	static int	pause_frames[]	= {28, 0};
-	static int	fire_frames[]	= {6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 0};
+	static int	pause_frames[]	= {53, 0};
+	static int	fire_frames[]	= {6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 21, 22, 23, 24, 0};
 
 	Weapon_Generic (ent, 5, 24, 53, 57, pause_frames, fire_frames, Weapon_Beamgun_Fire);
 }
@@ -1385,7 +1369,7 @@ void Machinegun_Fire (edict_t *ent)
 	else
 		damage = 20;
 
-	if ((ent->client->ps.gunframe == 6) && !(ent->client->buttons & BUTTON_ATTACK || ent->client->buttons & BUTTON_ATTACK2))
+	if ((ent->client->ps.gunframe == 5) && !(ent->client->buttons & BUTTON_ATTACK || ent->client->buttons & BUTTON_ATTACK2))
 	{
 		ent->client->ps.gunframe = 14;
 		ent->client->weapon_sound = 0;
@@ -1396,6 +1380,15 @@ void Machinegun_Fire (edict_t *ent)
 	{
 		ent->client->ps.gunframe = 5;
 	}
+	else if (ent->client->buttons & BUTTON_ATTACK2 && ent->client->ps.gunframe > 6)
+	{
+		if(ent->client->ps.gunframe == 7 || ent->client->ps.gunframe == 12) {
+			ent->client->ps.gunframe = 14;
+			return;
+		}
+		ent->altfire = true;
+		ent->client->ps.gunframe = 14;
+	}
 	else if (ent->client->buttons & BUTTON_ATTACK2)
 	{
 		ent->client->ps.gunframe++;
@@ -1407,7 +1400,7 @@ void Machinegun_Fire (edict_t *ent)
 	}
 	else
 		ent->client->ps.gunframe++;
-	
+
 	shots = 1;
 
 	if (ent->client->pers.inventory[ent->client->ammo_index] < 0)
@@ -1433,15 +1426,9 @@ void Machinegun_Fire (edict_t *ent)
 		kick *= 4;
 	}
 
-	for (i=0 ; i<3 ; i++)
-	{
-		ent->client->kick_origin[i] = crandom() * 8;
-		ent->client->kick_angles[i] = crandom() * 0.7;
-	}
-
 	AngleVectors (ent->client->v_angle, forward, right, NULL);//was up
-	VectorScale (forward, -16, ent->client->kick_origin);
-//	ent->client->kick_angles[0] = -3;
+	VectorScale (forward, -16 * random(), ent->client->kick_origin);
+	ent->client->kick_angles[0] = -6 * random();
 
 	if(ent->client->ps.gunframe == 6 && ent->client->buttons & BUTTON_ATTACK2) {
 		int bullet_count = DEFAULT_SSHOTGUN_COUNT;
@@ -1451,18 +1438,18 @@ void Machinegun_Fire (edict_t *ent)
 		VectorSet(offset, 1, 1, ent->viewheight-0.5);
 		P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
 		fire_shotgun (ent, start, forward, damage/2, kick, DEFAULT_SHOTGUN_HSPREAD, DEFAULT_SHOTGUN_VSPREAD, bullet_count, MOD_CGALTFIRE);
-		
+
 		//play a booming sound
 		gi.sound(ent, CHAN_AUTO, gi.soundindex("world/rocket.wav"), 1, ATTN_NORM, 0);
-	
+
 		// send muzzle flash
 		gi.WriteByte (svc_muzzleflash);
 		gi.WriteShort (ent-g_edicts);
 		gi.WriteByte ((MZ_CHAINGUN1 + shots - 1) | is_silenced);
 		gi.multicast (ent->s.origin, MULTICAST_PVS);
 
-		//create visual muzzle flash sprite!
-		
+		//create smoke effect
+
 		forward[0] = forward[0] * 24;
 		forward[1] = forward[1] * 24;
 		right[0] = right[0] * 3;
@@ -1472,12 +1459,16 @@ void Machinegun_Fire (edict_t *ent)
 		VectorAdd(start, forward, start);
 		VectorAdd(start, right, start);
 		gi.WriteByte (svc_temp_entity);
-		gi.WriteByte (TE_BLASTER_MUZZLEFLASH);
+		gi.WriteByte (TE_CHAINGUNSMOKE);
 		gi.WritePosition (start);
 		gi.multicast (start, MULTICAST_PVS);
-			
+
 		if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
-			ent->client->pers.inventory[ent->client->ammo_index] -= 10;	
+			ent->client->pers.inventory[ent->client->ammo_index] -= 10;
+
+		//kick it ahead, we don't want spinning
+		ent->client->ps.gunframe = 12;
+
 	}
 	else if(!ent->altfire){
 		for (i=0 ; i<shots ; i++)
@@ -1486,7 +1477,7 @@ void Machinegun_Fire (edict_t *ent)
 			P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
 			fire_bullet (ent, start, forward, damage, kick, DEFAULT_BULLET_HSPREAD, DEFAULT_BULLET_VSPREAD, MOD_CHAINGUN);
 		}
-	
+
 		// send muzzle flash
 		gi.WriteByte (svc_muzzleflash);
 		gi.WriteShort (ent-g_edicts);
@@ -1494,7 +1485,7 @@ void Machinegun_Fire (edict_t *ent)
 		gi.multicast (ent->s.origin, MULTICAST_PVS);
 
 		//create visual muzzle flash sprite!
-		
+
 		forward[0] = forward[0] * 24;
 		forward[1] = forward[1] * 24;
 		right[0] = right[0] * 3;
@@ -1504,7 +1495,7 @@ void Machinegun_Fire (edict_t *ent)
 		VectorAdd(start, forward, start);
 		VectorAdd(start, right, start);
 		gi.WriteByte (svc_temp_entity);
-		gi.WriteByte (TE_BLASTER_MUZZLEFLASH);
+		gi.WriteByte (TE_CHAINGUNSMOKE);
 		gi.WritePosition (start);
 		gi.multicast (start, MULTICAST_PVS);
 		if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
@@ -1515,7 +1506,7 @@ void Machinegun_Fire (edict_t *ent)
 
 void Weapon_Chain (edict_t *ent)
 {
-	static int	pause_frames[]	= {17, 0};
+	static int	pause_frames[]	= {43, 0};
 	static int	fire_frames[]	= {5, 6, 7, 8, 9, 10, 11, 12, 13};
 
 	Weapon_Generic (ent, 4, 14, 43, 46, pause_frames, fire_frames, Machinegun_Fire);
@@ -1529,7 +1520,7 @@ void weapon_floater_fire (edict_t *ent)
 	int		damage;
 	float	damage_radius;
 	int		radius_damage;
-    
+
 	damage = 100 + (int)(random() * 20.0);
 	radius_damage = 120;
 	damage_radius = 120;
@@ -1550,12 +1541,12 @@ void weapon_floater_fire (edict_t *ent)
 	forward[1] = forward[1] * 2.6;
 	if(ent->altfire) {
 		if(excessive->value)
-			fire_floater (ent, start, forward, damage, 500, damage_radius, radius_damage, 8); 
+			fire_floater (ent, start, forward, damage, 500, damage_radius, radius_damage, 8);
 		else
-			fire_prox (ent, start, forward, damage-50, 500, damage_radius, radius_damage-50, 8); 
+			fire_prox (ent, start, forward, damage-50, 500, damage_radius, radius_damage-50, 8);
 	}
 	else
-		fire_floater (ent, start, forward, damage, 500, damage_radius, radius_damage, 8); 
+		fire_floater (ent, start, forward, damage, 500, damage_radius, radius_damage, 8);
 	// send muzzle flash
 	gi.WriteByte (svc_muzzleflash);
 	gi.WriteShort (ent-g_edicts);
@@ -1567,7 +1558,7 @@ void weapon_floater_fire (edict_t *ent)
 	PlayerNoise(ent, start, PNOISE_WEAPON);
 
 //create visual muzzle flash sprite!
-	
+
 	forward[0] = forward[0] * 10;
 	forward[1] = forward[1] * 10;
 
@@ -1583,7 +1574,7 @@ void weapon_floater_fire (edict_t *ent)
 
 void Weapon_Smartgun (edict_t *ent)
 {
-	static int	pause_frames[]	= {14, 0};
+	static int	pause_frames[]	= {31, 0};
 	static int	fire_frames[]	= {6, 0};
 
 	if(ent->client->buttons & BUTTON_ATTACK2)
@@ -1607,10 +1598,10 @@ void Weapon_Deathball_Fire (edict_t *ent)
 
 	VectorSet(offset, 32, 5,  ent->viewheight-5);
 	P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
-	
+
 
 	if(ent->client->ps.gunframe == 7) {
-		
+
 		fire_deathball (ent, start, forward, 550);
 
 		// send muzzle flash
@@ -1626,23 +1617,174 @@ void Weapon_Deathball_Fire (edict_t *ent)
 		gi.WritePosition (start);
 		gi.multicast (start, MULTICAST_PVS);
 
-	
+
 		gi.sound(ent, CHAN_AUTO, gi.soundindex("weapons/energyfield.wav"), 1, ATTN_NORM, 0);
 		ent->client->weapon_sound = 0;
 
 
-	
+
 	}
 	ent->client->ps.gunframe++;
 
 }
-void Weapon_Deathball (edict_t *ent) 
+void Weapon_Deathball (edict_t *ent)
 {
-	static int	pause_frames[]	= {30, 0};
+	static int	pause_frames[]	= {33, 0};
 	static int	fire_frames[]	= {7,0};
 
 	Weapon_Generic (ent, 5, 11, 33, 39, pause_frames, fire_frames, Weapon_Deathball_Fire);
 }
 
+/*
+======================================================================
+
+VIOALATOR
+
+======================================================================
+*/
+
+void Violator_Fire (edict_t *ent)
+{
+	vec3_t		start;
+	vec3_t		forward, right, left, back;
+	vec3_t		offset;
+	int			damage;
+	int			kick = 4;
+
+	if(excessive->value || instagib->value)
+		damage = 200;
+	else
+		damage = 40;
+	
+	if ((ent->client->ps.gunframe == 6) && !(ent->client->buttons & BUTTON_ATTACK || ent->client->buttons & BUTTON_ATTACK2))
+	{
+		ent->client->ps.gunframe = 14;
+		ent->client->weapon_sound = 0;
+		return;
+	}
+	else if (ent->client->ps.gunframe == 14 && (ent->client->buttons & BUTTON_ATTACK || ent->client->buttons & BUTTON_ATTACK2))
+	{
+		ent->client->ps.gunframe = 6;
+	}
+	else if (ent->client->buttons & BUTTON_ATTACK2 && ent->client->ps.gunframe > 6)
+	{
+		if(ent->client->ps.gunframe == 7 || ent->client->ps.gunframe == 13) {
+			ent->client->ps.gunframe = 14;
+			return;
+		}
+		ent->altfire = true;
+		ent->client->ps.gunframe = 14;
+	}
+	else if (ent->client->buttons & BUTTON_ATTACK2)
+	{
+		ent->client->ps.gunframe++;
+		ent->altfire = true;
+	}
+	else if (ent->client->buttons & BUTTON_ATTACK){
+		ent->client->ps.gunframe++;
+		ent->altfire = false;
+	}
+	else
+		ent->client->ps.gunframe++;
+
+	if (is_quad) {
+		damage *= 4;
+		kick *=4;
+	}
+
+	AngleVectors (ent->client->v_angle, forward, right, NULL);
+	VectorScale (forward, -6 * random(), ent->client->kick_origin);
+	ent->client->kick_angles[0] = -6 * random();
+	VectorScale(forward, 10, forward);
+	VectorScale(right, 10, right);
+	VectorScale (right, -10, left);
+	VectorScale (forward, -10, back);
+
+	if(ent->client->ps.gunframe == 6 && ent->client->buttons & BUTTON_ATTACK2) {
+	
+		VectorSet(offset, 1, 1, ent->viewheight-0.5);
+		P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
+		fire_violator(ent, start, forward, damage*2, kick, 1);
+		fire_violator(ent, start, right, damage*2, kick, 1);
+		fire_violator(ent, start, left, damage*2, kick, 1);
+		fire_violator(ent, start, back, damage*2, kick, 1);
+
+		ent->client->resp.weapon_shots[8]++;
+
+		gi.sound(ent, CHAN_AUTO, gi.soundindex("weapons/viofire2.wav"), 1, ATTN_NORM, 0);
+
+		// send muzzle flash and effects
+		gi.WriteByte (svc_muzzleflash);
+		gi.WriteShort (ent-g_edicts);
+		gi.WriteByte (MZ_RAILGUN | is_silenced);
+		gi.multicast (ent->s.origin, MULTICAST_PVS);
+		
+		VectorScale(forward, 1.4, forward);
+		VectorAdd(start, forward, start);
+		VectorScale(right, -0.5, right);
+		VectorAdd(start, right, start);
+
+		gi.WriteByte (svc_temp_entity);
+		gi.WriteByte (TE_VOLTAGE);
+		gi.WritePosition (start);
+		gi.WriteDir(forward);
+		gi.multicast (start, MULTICAST_PVS);
+
+		gi.WriteByte (svc_temp_entity);
+		gi.WriteByte (TE_BLUE_MUZZLEFLASH);
+		gi.WritePosition (start);
+		gi.multicast (start, MULTICAST_PVS);
+
+		//kick it ahead, we don't want it continuing to pump
+		ent->client->ps.gunframe = 12;
+
+	}
+	else if(!ent->altfire){
+
+		VectorSet(offset, 1, 1, ent->viewheight-0.5);
+		P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
+		fire_violator(ent, start, forward, damage, kick, 0);
+
+		gi.sound(ent, CHAN_AUTO, gi.soundindex("weapons/viofire1.wav"), 1, ATTN_NORM, 0);
+
+		ent->client->resp.weapon_shots[8]++;
+
+		// send muzzle flash
+		gi.WriteByte (svc_muzzleflash);
+		gi.WriteShort (ent-g_edicts);
+		gi.WriteByte (MZ_RAILGUN | is_silenced);
+		gi.multicast (ent->s.origin, MULTICAST_PVS);
+
+		VectorScale(forward, 1.4, forward);
+		VectorAdd(start, forward, start);
+		VectorScale(right, -0.5, right);
+		VectorAdd(start, right, start);
+	
+		gi.WriteByte (svc_temp_entity);
+		gi.WriteByte (TE_VOLTAGE);
+		gi.WritePosition (start);
+		gi.WriteDir(forward);
+		gi.multicast (start, MULTICAST_PVS);
+
+		gi.WriteByte (svc_temp_entity);
+		gi.WriteByte (TE_BLUE_MUZZLEFLASH);
+		gi.WritePosition (start);
+		gi.multicast (start, MULTICAST_PVS);
 
 
+	}
+
+}
+
+void Weapon_Violator (edict_t *ent)
+{
+	static int	pause_frames[]	= {43, 0};
+	static int	fire_frames[]	= {5, 6, 7, 8, 9, 10, 11, 12, 13, 14};
+	static int	bot_fire_frames[] = {5, 6, 7, 8, 9, 10, 11, 12, 13};
+	if(ent->is_bot) //done because bots need one frame in which to "escape" from firing 
+		Weapon_Generic (ent, 4, 14, 43, 46, pause_frames, bot_fire_frames, Violator_Fire);
+	else
+		Weapon_Generic (ent, 4, 14, 43, 46, pause_frames, fire_frames, Violator_Fire);
+
+}
+
