@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -17,7 +17,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
-	
+
 // q_shared.h -- included first by ALL program modules
 
 #ifdef _WIN32
@@ -35,6 +35,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <math.h>
 #include <stdio.h>
 #include <stdarg.h>
+#include <stddef.h>
 #include <string.h>
 #include <stdlib.h>
 #include <time.h>
@@ -99,7 +100,7 @@ typedef enum {false, true}	qboolean;
 
 #define	PRINT_ALL			0
 #define PRINT_DEVELOPER		1		// only print when "developer 1"
-#define PRINT_ALERT			2		
+#define PRINT_ALERT			2
 
 
 // destination class for gi.multicast()
@@ -166,8 +167,8 @@ void VectorMA (vec3_t veca, float scale, vec3_t vecb, vec3_t vecc);
 #define Vector4Set(v, a, b, c, d)	((v)[0]=(a),(v)[1]=(b),(v)[2]=(c),(v)[3] = (d))
 #define Vector4Copy(a,b)		((b)[0]=(a)[0],(b)[1]=(a)[1],(b)[2]=(a)[2],(b)[3]=(a)[3])
 #define Vector4Scale(in,scale,out)		((out)[0]=(in)[0]*scale,(out)[1]=(in)[1]*scale,(out)[2]=(in)[2]*scale,(out)[3]=(in)[3]*scale)
-#define Vector4Add(a,b,c)		((c)[0]=(((a[0])+(b[0]))),(c)[1]=(((a[1])+(b[1]))),(c)[2]=(((a[2])+(b[2]))),(c)[3]=(((a[3])+(b[3])))) 
-#define Vector4Avg(a,b,c)		((c)[0]=(((a[0])+(b[0]))*0.5f),(c)[1]=(((a[1])+(b[1]))*0.5f),(c)[2]=(((a[2])+(b[2]))*0.5f),(c)[3]=(((a[3])+(b[3]))*0.5f)) 
+#define Vector4Add(a,b,c)		((c)[0]=(((a[0])+(b[0]))),(c)[1]=(((a[1])+(b[1]))),(c)[2]=(((a[2])+(b[2]))),(c)[3]=(((a[3])+(b[3]))))
+#define Vector4Avg(a,b,c)		((c)[0]=(((a[0])+(b[0]))*0.5f),(c)[1]=(((a[1])+(b[1]))*0.5f),(c)[2]=(((a[2])+(b[2]))*0.5f),(c)[3]=(((a[3])+(b[3]))*0.5f))
 
 #define DEG2RAD( a ) ( a * M_PI ) / 180.0F
 #define RAD2DEG( a ) ( a * 180.0F ) / M_PI
@@ -492,7 +493,7 @@ typedef struct
 
 // pmove_state_t is the information necessary for client side movement
 // prediction
-typedef enum 
+typedef enum
 {
 	// can accelerate and turn
 	PM_NORMAL,
@@ -668,7 +669,7 @@ typedef struct
 #define	TE_BLOOD					1
 #define	TE_BLASTER					2
 #define	TE_RAILTRAIL				3
-#define	TE_SHOTGUN					4
+#define	TE_LASERBEAM				4
 #define	TE_EXPLOSION1				5
 #define	TE_EXPLOSION2				6
 #define	TE_ROCKET_EXPLOSION			7
@@ -687,15 +688,15 @@ typedef struct
 #define	TE_BFG_LASER				23
 #define	TE_GREENBLOOD				26
 #define	TE_LIGHTNING				33
-#define	TE_HEATBEAM					38
+#define	TE_VAPORBEAM				38
 #define	TE_STEAM					40
 #define	TE_SAYICON					45
 #define	TE_TELEPORT_EFFECT			48
 #define	TE_LEADERBLASTER			56
-#define	TE_BLASTER_MUZZLEFLASH		57
+#define	TE_CHAINGUNSMOKE			57
 #define	TE_BLUE_MUZZLEFLASH			58
 #define	TE_SMART_MUZZLEFLASH		59
-#define	TE_LEADERFIELD				60
+#define	TE_VOLTAGE					60
 #define	TE_DEATHFIELD				61
 #define	TE_BLASTERBEAM				62
 #define	TE_STAIN					63
@@ -769,7 +770,6 @@ typedef struct
 #define	DF_INSTANT_ITEMS	0x00000010	// 16
 #define	DF_SAME_LEVEL		0x00000020	// 32
 #define DF_SKINTEAMS		0x00000040	// 64
-#define DF_MODELTEAMS		0x00000080	// 128
 #define DF_NO_FRIENDLY_FIRE	0x00000100	// 256
 #define	DF_SPAWN_FARTHEST	0x00000200	// 512
 #define DF_FORCE_RESPAWN	0x00000400	// 1024
@@ -808,7 +808,6 @@ typedef struct
 // Each config string can be at most MAX_QPATH characters.
 //
 #define	CS_NAME				0
-#define	CS_CDTRACK			1
 #define	CS_SKY				2
 #define	CS_SKYAXIS			3		// %f %f %f format
 #define	CS_SKYROTATE		4
@@ -905,7 +904,7 @@ typedef struct
 	int			gunframe;
 
 	float		blend[4];		// rgba full screen effect
-	
+
 	float		fov;			// horizontal field of view
 
 	int			rdflags;		// refdef flags
