@@ -628,12 +628,18 @@ void LoadTGA (char *name, byte **pic, int *width, int *height)
 	targa_header.attributes = *buf_p++;
 
 	if (targa_header.image_type!=2 
-		&& targa_header.image_type!=10) 
-		Com_Error (ERR_DROP, "LoadTGA: Only type 2 and 10 targa RGB images supported\n");
+		&& targa_header.image_type!=10) {
+		//Com_Error (ERR_DROP, "LoadTGA: Only type 2 and 10 targa RGB images supported\n");
+		FS_FreeFile (buffer);
+		return;
+	}
 
 	if (targa_header.colormap_type !=0 
-		|| (targa_header.pixel_size!=32 && targa_header.pixel_size!=24))
-		Com_Error (ERR_DROP, "LoadTGA: Only 32 or 24 bit images supported (no colormaps)\n");
+		|| (targa_header.pixel_size!=32 && targa_header.pixel_size!=24)) {
+		//Com_Error (ERR_DROP, "LoadTGA: Only 32 or 24 bit images supported (no colormaps)\n");
+		FS_FreeFile (buffer);
+		return;
+	}
 
 	columns = targa_header.width;
 	rows = targa_header.height;
@@ -1594,11 +1600,9 @@ void GL_FreeUnusedImages (void)
 	r_hittexture->registration_sequence = registration_sequence;
 	r_bubbletexture->registration_sequence = registration_sequence;
 	r_shottexture->registration_sequence = registration_sequence;
+	r_bullettexture->registration_sequence = registration_sequence;
 	r_sayicontexture->registration_sequence = registration_sequence;
-	// MH - detail textures begin
-	// never free detail texture
-	r_detailtexture->registration_sequence = registration_sequence;
-	// MH - detail textures end
+	r_voltagetexture->registration_sequence = registration_sequence;
 
 	//minimap stuff - only if those textures are present, as this was a feature added later on
 	//and if crx has been updated via galaxy, clients may not have these images
