@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -42,10 +42,10 @@ int GL_TEXTURE0, GL_TEXTURE1, GL_TEXTURE2;
 
 model_t		*r_worldmodel;
 
-float		gldepthmin, gldepthmax;
+float			gldepthmin, gldepthmax;
 
-glconfig_t	gl_config;
-glstate_t	gl_state;
+glconfig_t		gl_config;
+glstate_t		gl_state;
 
 image_t		*r_notexture;		// use for bad textures
 image_t		*r_particletexture;	// little dot for particles
@@ -65,7 +65,7 @@ image_t		*r_bflashtexture;
 image_t		*r_cflashtexture;
 image_t		*r_leaderfieldtexture;
 image_t		*r_deathfieldtexture;
-image_t     *r_shelltexture;    // c14 added shell texture
+image_t		*r_shelltexture;    // c14 added shell texture
 image_t		*r_hittexture;
 image_t		*r_bubbletexture;
 image_t		*r_reflecttexture;
@@ -75,25 +75,23 @@ image_t		*r_flaretexture;
 image_t		*r_beamtexture;
 image_t		*r_beam2texture;
 image_t		*r_beam3texture;
+image_t		*r_bullettexture;
+image_t		*r_voltagetexture;
 image_t		*r_radarmap; // wall texture for radar texgen
 image_t		*r_around;
 
-cvar_t *rs_detail;
-// MH - detail textures begin
-cvar_t	*gl_detailtextures;
-// MH - detail textures begin
-cvar_t  *gl_normalmaps;
+cvar_t	*gl_normalmaps;
 cvar_t	*gl_arb_fragment_program; // jit
 
 entity_t	*currententity;
-model_t		*currentmodel;
+model_t	*currentmodel;
 
 cplane_t	frustum[4];
 
-int			r_visframecount;	// bumped when going to a new PVS
-int			r_framecount;		// used for dlight push checking
+int		r_visframecount;	// bumped when going to a new PVS
+int		r_framecount;		// used for dlight push checking
 
-int			c_brush_polys, c_alias_polys, c_flares;
+int		c_brush_polys, c_alias_polys, c_flares;
 
 float		v_blend[4];			// final blending color
 
@@ -141,7 +139,6 @@ cvar_t	*gl_ext_mtexcombine;
 // Vic - end
 
 cvar_t	*gl_nosubimage;
-cvar_t	*gl_allow_software;
 
 cvar_t	*gl_vertex_arrays;
 
@@ -161,12 +158,11 @@ cvar_t	*gl_ext_compiled_vertex_array;
 cvar_t	*gl_log;
 cvar_t	*gl_bitdepth;
 cvar_t	*gl_drawbuffer;
-cvar_t  *gl_driver;
+cvar_t	*gl_driver;
 cvar_t	*gl_lightmap;
 cvar_t	*gl_shadows;
 cvar_t	*gl_mode;
 cvar_t	*gl_dynamic;
-cvar_t  *gl_monolightmap;
 cvar_t	*gl_modulate;
 cvar_t	*gl_nobind;
 cvar_t	*gl_round_down;
@@ -179,14 +175,13 @@ cvar_t	*gl_cull;
 cvar_t	*gl_polyblend;
 cvar_t	*gl_flashblend;
 cvar_t	*gl_playermip;
-cvar_t  *gl_saturatelighting;
 cvar_t	*gl_swapinterval;
 cvar_t	*gl_texturemode;
 cvar_t	*gl_texturealphamode;
 cvar_t	*gl_texturesolidmode;
 cvar_t	*gl_lockpvs;
-cvar_t  *gl_rtlights;
-cvar_t  *gl_texres;
+cvar_t	*gl_rtlights;
+cvar_t	*gl_texres;
 
 cvar_t	*gl_3dlabs_broken;
 
@@ -194,24 +189,32 @@ cvar_t	*vid_fullscreen;
 cvar_t	*vid_gamma;
 cvar_t	*vid_ref;
 
-cvar_t  *r_shaders;
-cvar_t  *r_bloom;
-cvar_t  *r_lensflare;
-cvar_t  *r_lensflare_intens;
+cvar_t	*r_shaders;
+cvar_t	*r_bloom;
+cvar_t	*r_lensflare;
+cvar_t	*r_lensflare_intens;
 
-cvar_t  *arena_mode;
-qboolean    map_fog;
+qboolean	map_fog;
 
 cvar_t	*gl_reflection;			// MPO	alpha transparency, 1.0 is full bright
 cvar_t	*gl_reflection_debug;	// MPO	for debugging the reflection
 cvar_t	*gl_reflection_max;		// MPO  max number of water reflections
 
-cvar_t  *con_font;
+cvar_t	*con_font;
 
-cvar_t  *r_minimap_size; // GLOOM radar
-cvar_t  *r_minimap_zoom;
-cvar_t  *r_minimap_style;
-cvar_t  *r_minimap;
+cvar_t	*r_minimap_size; // GLOOM radar
+cvar_t	*r_minimap_zoom;
+cvar_t	*r_minimap_style;
+cvar_t	*r_minimap;
+
+cvar_t	*sys_affinity;
+cvar_t	*sys_priority;
+
+cvar_t	*gl_screenshot_type;
+cvar_t	*gl_screenshot_jpeg_quality;
+
+//no blood
+extern cvar_t *cl_noblood;
 
 //fog stuff
 struct r_fog
@@ -244,7 +247,7 @@ glows_t glow_effects[MAX_GLOWS];
 
 // sin and cos tables from 0 to 1 in 0.0625 increments to speed up glow rendering
 // also from gl_rmisc.c and externed in gl_quake.h - i also use them for alias model glows.
-float glowcos[17] = 
+float glowcos[17] =
 {
 	1.000000,
 	0.923879,
@@ -266,7 +269,7 @@ float glowcos[17] =
 };
 
 
-float glowsin[17] = 
+float glowsin[17] =
 {
 	0.000000,
 	0.382684,
@@ -325,19 +328,19 @@ void R_ReadFogScript(char config_file[128])
 		fread( buffer, length, 1, fp );
 	}
 	s = buffer;
-		
-	strcpy( a_string, COM_Parse( &s ) ); 
-	fog.red = atof(a_string); 
-	strcpy( a_string, COM_Parse( &s ) ); 
-	fog.green = atof(a_string); 
-	strcpy( a_string, COM_Parse( &s ) ); 
-	fog.blue = atof(a_string); 
-	strcpy( a_string, COM_Parse( &s ) ); 
+
+	strcpy( a_string, COM_Parse( &s ) );
+	fog.red = atof(a_string);
+	strcpy( a_string, COM_Parse( &s ) );
+	fog.green = atof(a_string);
+	strcpy( a_string, COM_Parse( &s ) );
+	fog.blue = atof(a_string);
+	strcpy( a_string, COM_Parse( &s ) );
 	fog.start = atof(a_string);
-	strcpy( a_string, COM_Parse( &s ) ); 
+	strcpy( a_string, COM_Parse( &s ) );
 	fog.end = atof(a_string);
-	strcpy( a_string, COM_Parse( &s ) ); 
-	fog.density = atof(a_string); 
+	strcpy( a_string, COM_Parse( &s ) );
+	fog.density = atof(a_string);
 	if ( fp != 0 )
 	{
 		fp = 0;
@@ -385,8 +388,8 @@ void R_ReadMusicScript(char config_file[128])
 		fread( buffer, length, 1, fp );
 	}
 	s = buffer;
-		
-	strcpy( map_music, COM_Parse( &s ) ); 
+
+	strcpy( map_music, COM_Parse( &s ) );
 	map_music[length] = 0; //clear any possible garbage
 
 	if ( fp != 0 )
@@ -470,86 +473,6 @@ void R_RotateForEntity (entity_t *e)
     qglRotatef (-e->angles[2],  1, 0, 0);
 }
 
-/*
-=============================================================
-
-  SPRITE MODELS
-
-=============================================================
-*/
-
-
-/*
-=================
-R_DrawSpriteModel
-
-=================
-*/
-void R_DrawSpriteModel (entity_t *e)
-{
-	float alpha = 1.0F;
-	vec3_t	point;
-	vec3_t		v_forward, v_right, v_up;
-	dsprframe_t	*frame;
-	float		*up, *right;
-	dsprite_t	*psprite;
-
-	// don't even bother culling, because it's just a single
-	// polygon without a surface cache
-
-	psprite = (dsprite_t *)currentmodel->extradata;
-
-	e->frame %= psprite->numframes;
-
-	frame = &psprite->frames[e->frame];
-
-	AngleVectors (currententity->angles, v_forward, v_right, v_up);
-	up = v_forward;
-	right = v_right;
-
-	GL_Bind (currentmodel->skins[e->frame]->texnum);
-	
-	alpha = 0.6;
-	qglDepthMask( GL_FALSE );
-	qglEnable( GL_BLEND );
-	qglBlendFunc (GL_SRC_ALPHA, GL_ONE);
-    GL_TexEnv( GL_MODULATE );
-	qglBegin (GL_QUADS);
-
-	qglColor4f( 1, 1, 1, alpha );
-	
-	qglTexCoord2f (0, 1);
-	VectorMA (e->origin, -frame->origin_y, up, point);
-	VectorMA (point, -frame->origin_x, right, point);
-	qglVertex3fv (point);
-
-	qglTexCoord2f (0, 0);
-	VectorMA (e->origin, frame->height - frame->origin_y, up, point);
-	VectorMA (point, -frame->origin_x, right, point);
-	qglVertex3fv (point);
-
-	qglTexCoord2f (1, 0);
-	VectorMA (e->origin, frame->height - frame->origin_y, up, point);
-	VectorMA (point, frame->width - frame->origin_x, right, point);
-	qglVertex3fv (point);
-
-	qglTexCoord2f (1, 1);
-	VectorMA (e->origin, -frame->origin_y, up, point);
-	VectorMA (point, frame->width - frame->origin_x, right, point);
-	qglVertex3fv (point);
-	
-	qglEnd ();
-
-	qglDisable (GL_ALPHA_TEST);
-	GL_TexEnv( GL_REPLACE );
-	qglDisable( GL_BLEND );
-	qglBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-	qglDepthMask( 1 );
-	qglColor4f( 1, 1, 1, 1 );
-}
-
-//==================================================================================
-
 /*
 =============
 R_DrawNullModel
@@ -619,11 +542,11 @@ void R_DrawEntitiesOnList (void)
 				RS_ReadyScript(rs);
 				currententity->script = rs;
 			}
-			else 
+			else
 				currententity->script = NULL;
 		}
-		
-	
+
+
 		if ( currententity->flags & RF_BEAM )
 		{
 			R_DrawBeam( currententity );
@@ -644,9 +567,6 @@ void R_DrawEntitiesOnList (void)
 			case mod_brush:
 				R_DrawBrushModel (currententity);
 				break;
-			case mod_sprite:
-				R_DrawSpriteModel (currententity);
-				break;
 			default:
 				Com_Error(ERR_DROP, "Bad modeltype");
 				break;
@@ -674,10 +594,10 @@ void R_DrawEntitiesOnList (void)
 				RS_ReadyScript(rs);
 				currententity->script = rs;
 			}
-			else 
+			else
 				currententity->script = NULL;
 		}
-		
+
 
 		if ( currententity->flags & RF_BEAM )
 		{
@@ -700,9 +620,6 @@ void R_DrawEntitiesOnList (void)
 			case mod_brush:
 				R_DrawBrushModel (currententity);
 				break;
-			case mod_sprite:
-				R_DrawSpriteModel (currententity);
-				break;
 			default:
 				Com_Error (ERR_DROP, "Bad modeltype");
 				break;
@@ -722,20 +639,20 @@ void GL_DrawParticles( int num_particles, gparticle_t particles[], const unsigne
 {
 	const gparticle_t *p;
 	int				i;
-	vec3_t			corner[4], up, right, pup, pright;
+	vec3_t			corner[4], up, right, pup, pright, dir;
 	float			scale, oldscale;
 	byte			color[4], oldcolor[4];
 	int			    oldtype;
 	int				texnum, blenddst, blendsrc;
 	float			*corner0 = corner[0];
 	vec3_t move, delta;
-	
+
 	if ( !num_particles )
 		return;
 
 	qglDepthMask( GL_FALSE );	 	// no z buffering
 	qglEnable( GL_BLEND);
-	GL_TexEnv( GL_MODULATE ); 
+	GL_TexEnv( GL_MODULATE );
 
 	for ( p = particles, i=0, oldtype=-1 ; i < num_particles ; i++,p++)
 	{
@@ -757,8 +674,8 @@ void GL_DrawParticles( int num_particles, gparticle_t particles[], const unsigne
 
 		color[3] = p->alpha*255;
 
-		if ( 
-			p->type != oldtype 
+		if (
+			p->type != oldtype
 			|| color[0] != oldcolor[0] || color[1] != oldcolor[1]
 			|| color[2] != oldcolor[2] || color[3] != oldcolor[3] || scale != oldscale)
 		{
@@ -766,7 +683,7 @@ void GL_DrawParticles( int num_particles, gparticle_t particles[], const unsigne
 			{
 				qglEnd ();
 			}
-			if ( scale != 1 ) 
+			if ( scale != 1 )
 			{
 				VectorScale (vup, scale, up);
 				VectorScale (vright, scale, right);
@@ -788,11 +705,7 @@ void GL_DrawParticles( int num_particles, gparticle_t particles[], const unsigne
 			qglBegin ( GL_QUADS );
 		}
 
-		if(p->type != PARTICLE_BEAM) {
-			VectorScale ( right, p->dist, pright );
-			VectorScale ( up, p->dist, pup );
-		}
-		else {
+		if(p->type == PARTICLE_BEAM || p->type == PARTICLE_SHOT) {
 
 			VectorSubtract(p->origin, p->angle, move);
 			VectorNormalize(move);
@@ -805,28 +718,57 @@ void GL_DrawParticles( int num_particles, gparticle_t particles[], const unsigne
 			VectorScale(pright, 5*scale, pright);
 			VectorScale(pup, 5*scale, pup);
 		}
+		else if(p->type == PARTICLE_DECAL) {
+			VectorCopy(p->angle, dir);
+			AngleVectors(dir, NULL, right, up);
+			VectorScale ( right, p->dist, pright );
+			VectorScale ( up, p->dist, pup );
+			VectorScale(pright, 5*scale, pright);
+			VectorScale(pup, 5*scale, pup);
 
-		VectorSet (corner[0], 
+		}
+		else if(p->type == PARTICLE_FLAT) {
+
+			VectorCopy(r_newrefdef.viewangles, dir);
+
+			dir[0] = -90;  // and splash particles horizontal by setting it
+			AngleVectors(dir, NULL, right, up);
+
+			if(p->origin[2] > r_newrefdef.vieworg[2]){  // it's above us
+				VectorScale(right, 5*scale, pright);
+				VectorScale(up, 5*scale, pup);
+			}
+			else {  // it's below us
+				VectorScale(right, 5*scale, pright);
+				VectorScale(up, -5*scale, pup);
+			}
+		}
+		else {
+			VectorScale ( right, p->dist, pright );
+			VectorScale ( up, p->dist, pup );
+		}
+
+		VectorSet (corner[0],
 			p->origin[0] + (pup[0] + pright[0])*(-0.5),
 			p->origin[1] + (pup[1] + pright[1])*(-0.5),
 			p->origin[2] + (pup[2] + pright[2])*(-0.5));
 
-		VectorSet ( corner[1], 
+		VectorSet ( corner[1],
 			corner0[0] + pup[0], corner0[1] + pup[1], corner0[2] + pup[2]);
-		VectorSet ( corner[2], corner0[0] + (pup[0]+pright[0]), 
+		VectorSet ( corner[2], corner0[0] + (pup[0]+pright[0]),
 			corner0[1] + (pup[1]+pright[1]), corner0[2] + (pup[2]+pright[2]));
-		VectorSet ( corner[3], 
+		VectorSet ( corner[3],
 			corner0[0] + pright[0], corner0[1] + pright[1], corner0[2] + pright[2]);
 
 		qglTexCoord2f( 1, 1 );
 		qglVertex3fv( corner[0] );
-		
+
 		qglTexCoord2f( 0, 1 );
 		qglVertex3fv ( corner[1] );
-		
+
 		qglTexCoord2f( 0, 0 );
 		qglVertex3fv ( corner[2] );
-		
+
 		qglTexCoord2f( 1, 0 );
 		qglVertex3fv ( corner[3] );
 	}
@@ -836,7 +778,7 @@ void GL_DrawParticles( int num_particles, gparticle_t particles[], const unsigne
 	qglColor4f( 1,1,1,1 );
 	qglDisable(GL_BLEND);
 	qglDepthMask( GL_TRUE );	// back to normal Z buffering
-	GL_TexEnv( GL_REPLACE );    
+	GL_TexEnv( GL_REPLACE );
 }
 
 /*
@@ -902,7 +844,7 @@ void R_DrawParticles (void)
 	for ( p = r_newrefdef.particles, i=0 ; i < r_newrefdef.num_particles ; i++,p++)
 	{
 		// hack a scale up to keep particles from disapearing
-		dist = ( p->origin[0] - r_origin[0] ) * vpn[0] + 
+		dist = ( p->origin[0] - r_origin[0] ) * vpn[0] +
 			    ( p->origin[1] - r_origin[1] ) * vpn[1] +
 			    ( p->origin[2] - r_origin[2] ) * vpn[2];
 
@@ -926,13 +868,13 @@ void R_DrawParticles (void)
 
 		gp++;
 		num_gparticles++;
-	
+
 	}
 	if(map_fog)
 		qglDisable(GL_FOG);
 	R_SortParticles ( gparticles, 0, num_gparticles - 1 );
-	
-	// we are always going to used textured particles!	
+
+	// we are always going to used textured particles!
 	GL_DrawParticles( num_gparticles, gparticles, d_8to24table);
 	if(map_fog)
 		qglEnable(GL_FOG);
@@ -1049,7 +991,7 @@ void R_SetupFrame (void)
 		if (!(r_newrefdef.rdflags & RDF_NOWORLDMODEL))
 		{
 			vec3_t temp;
-			
+
 			leaf = Mod_PointInLeaf(r_origin, r_worldmodel);
 			temp[0] = g_refl_X[g_active_refl];
 			temp[1] = g_refl_Y[g_active_refl];
@@ -1116,16 +1058,16 @@ void MYgluPerspective( GLdouble fovy, GLdouble aspect,
 		     GLdouble zNear, GLdouble zFar )
 {
 	GLdouble xmin, xmax, ymin, ymax;
-	
+
 	ymax = zNear * tan( fovy * M_PI / 360.0 );
 	ymin = -ymax;
-	
+
 	xmin = ymin * aspect;
 	xmax = ymax * aspect;
-	
+
 	xmin += -( 2 * gl_state.camera_separation ) / zNear;
 	xmax += -( 2 * gl_state.camera_separation ) / zNear;
-	
+
 	//qglFrustum( xmin, xmax, ymin, ymax, zNear, zFar );
 	mesa_frustum( xmin, xmax, ymin, ymax, zNear, zFar ); //MPO
 }
@@ -1211,9 +1153,9 @@ void R_SetupGL (void)
 	{
 		R_DoReflTransform();
 		qglTranslatef(0, 0, -0);
-	}	
+	}
 	// end MPO
-    
+
 //	if ( gl_state.camera_separation != 0 && gl_state.stereo_enabled )
 //		qglTranslatef ( gl_state.camera_separation, 0, 0 );
 
@@ -1230,14 +1172,14 @@ void R_SetupGL (void)
 	else
 		qglDisable(GL_CULL_FACE);
 
-// CDawg - start 
-	if (r_newrefdef.viewangles[2]) 
-		qglEnable(GL_BLEND); 
-	else 
-		qglDisable(GL_BLEND); 
-// CDawg - end 
+// CDawg - start
+	if (r_newrefdef.viewangles[2])
+		qglEnable(GL_BLEND);
+	else
+		qglDisable(GL_BLEND);
+// CDawg - end
 
-//qglDisable(GL_BLEND); //CDawg <-- comment this line. 
+//qglDisable(GL_BLEND); //CDawg <-- comment this line.
 
 	qglDisable(GL_ALPHA_TEST);
 	qglEnable(GL_DEPTH_TEST);
@@ -1291,7 +1233,7 @@ void R_DrawSpecialSurfaces(void);
 void R_RenderView (refdef_t *fd)
 {
 	GLfloat colors[4] = {(GLfloat) fog.red, (GLfloat) fog.green, (GLfloat) fog.blue, (GLfloat) 0.1};
-		
+
 	numRadarEnts=0;
 
 	if (r_norefresh->value)
@@ -1310,7 +1252,8 @@ void R_RenderView (refdef_t *fd)
 	}
 
 	R_PushDlights ();
-	R_PushStains ();
+	if(!cl_noblood->value)
+		R_PushStains ();
 
 	if (gl_finish->value)
 		qglFinish ();
@@ -1324,13 +1267,13 @@ void R_RenderView (refdef_t *fd)
 	// start MPO
 	// if we are doing a reflection, we want to do a clip plane now, after
 	// we've set up our projection/modelview matrices
-	
+
 	if (g_drawing_refl)
 	{
 		double clipPlane[] = { 0, 0, 0, 0 };
 
 		if(r_newrefdef.rdflags & RDF_UNDERWATER) {
-			
+
 			clipPlane[2] = -1;
 			clipPlane[3] = g_refl_Z[g_active_refl];
 		}
@@ -1362,15 +1305,17 @@ void R_RenderView (refdef_t *fd)
 
 	R_DrawWorld ();
 
-	if(r_lensflare->value)R_RenderFlares ();  
+	if(r_lensflare->value)
+		R_RenderFlares ();
 
 	R_DrawEntitiesOnList ();
-	
+
 	R_DrawAlphaSurfaces ();
-	
+
 	R_DrawSpecialSurfaces();
 
 	qglLoadMatrixf (r_world_matrix); //moving trans brushes
+
 	R_DrawParticles ();
 
 	R_BloomBlend( fd );//BLOOMS
@@ -1388,18 +1333,18 @@ void R_RenderView (refdef_t *fd)
 	else
 	{
 		R_Flash();
-	
+
 		if (r_speeds->value)
 		{
 			Com_Printf (PRINT_ALL, "%4i wpoly %4i epoly %i tex %i lmaps\n",
-				c_brush_polys, 
-				c_alias_polys, 
-				c_visible_textures, 
-				c_visible_lightmaps); 
+				c_brush_polys,
+				c_alias_polys,
+				c_visible_textures,
+				c_visible_lightmaps);
 		}
 	}
 	// stop MPO
-	
+
 	if(map_fog)
 		qglDisable(GL_FOG);
 
@@ -1459,7 +1404,7 @@ static void GL_DrawStereoPattern( void )
 			GL_DrawColoredStereoLinePair( 1, 1, 0, 12);
 			GL_DrawColoredStereoLinePair( 0, 1, 0, 14);
 		qglEnd();
-		
+
 		GLimp_EndFrame();
 	}
 }
@@ -1552,7 +1497,6 @@ void R_Register( void )
 	r_wave = Cvar_Get ("r_wave", "2", CVAR_ARCHIVE); // Water waves
 
 	gl_nosubimage = Cvar_Get( "gl_nosubimage", "0", 0 );
-	gl_allow_software = Cvar_Get( "gl_allow_software", "0", 0 );
 
 	gl_particle_min_size = Cvar_Get( "gl_particle_min_size", ".2", CVAR_ARCHIVE );
 	gl_particle_max_size = Cvar_Get( "gl_particle_max_size", "40", CVAR_ARCHIVE );
@@ -1564,7 +1508,7 @@ void R_Register( void )
 	gl_modulate = Cvar_Get ("gl_modulate", "2", CVAR_ARCHIVE );
 	gl_log = Cvar_Get( "gl_log", "0", 0 );
 	gl_bitdepth = Cvar_Get( "gl_bitdepth", "0", 0 );
-	gl_mode = Cvar_Get( "gl_mode", "3", CVAR_ARCHIVE );
+	gl_mode = Cvar_Get( "gl_mode", "6", CVAR_ARCHIVE );
 	gl_lightmap = Cvar_Get ("gl_lightmap", "0", 0);
 	gl_shadows = Cvar_Get ("gl_shadows", "2", CVAR_ARCHIVE );
 	gl_dynamic = Cvar_Get ("gl_dynamic", "1", CVAR_ARCHIVE);
@@ -1579,13 +1523,12 @@ void R_Register( void )
 	gl_polyblend = Cvar_Get ("gl_polyblend", "1", 0);
 	gl_flashblend = Cvar_Get ("gl_flashblend", "0", 0);
 	gl_playermip = Cvar_Get ("gl_playermip", "0", 0);
-	gl_monolightmap = Cvar_Get( "gl_monolightmap", "0", 0 );
 #ifdef __unix__
 	gl_driver = Cvar_Get( "gl_driver", "libGL.so.1", CVAR_ARCHIVE );
 #else
 	gl_driver = Cvar_Get( "gl_driver", "opengl32", CVAR_ARCHIVE );
 #endif
-	gl_texturemode = Cvar_Get( "gl_texturemode", "GL_LINEAR_MIPMAP_NEAREST", CVAR_ARCHIVE );
+	gl_texturemode = Cvar_Get( "gl_texturemode", "GL_LINEAR_MIPMAP_LINEAR", CVAR_ARCHIVE );
 	gl_texturealphamode = Cvar_Get( "gl_texturealphamode", "default", CVAR_ARCHIVE );
 	gl_texturesolidmode = Cvar_Get( "gl_texturesolidmode", "default", CVAR_ARCHIVE );
 	gl_lockpvs = Cvar_Get( "gl_lockpvs", "0", 0 );
@@ -1603,8 +1546,6 @@ void R_Register( void )
 	gl_drawbuffer = Cvar_Get( "gl_drawbuffer", "GL_BACK", 0 );
 	gl_swapinterval = Cvar_Get( "gl_swapinterval", "1", CVAR_ARCHIVE );
 
-	gl_saturatelighting = Cvar_Get( "gl_saturatelighting", "0", 0 );
-
 	gl_3dlabs_broken = Cvar_Get( "gl_3dlabs_broken", "1", CVAR_ARCHIVE );
 
 	r_shaders = Cvar_Get ("r_shaders", "1", CVAR_ARCHIVE);
@@ -1623,13 +1564,6 @@ void R_Register( void )
 	vid_gamma = Cvar_Get( "vid_gamma", "1.0", CVAR_ARCHIVE );
 	vid_ref = Cvar_Get( "vid_ref", "gl", CVAR_ARCHIVE );
 
-	arena_mode = Cvar_Get ("arena_mode", "0", CVAR_ARCHIVE );
-
-	// MH - detail textures begin
-	// the amount of scaling to apply to detail textures depends on the value of this
-	// cvar.  set to 0 to switch off detail texturing.  
-	gl_detailtextures = Cvar_Get ("gl_detailtextures", "0.0", CVAR_ARCHIVE);
-	// MH - detail textures begin
 	gl_normalmaps = Cvar_Get("gl_normalmaps", "0", CVAR_ARCHIVE);
 
 	r_lensflare = Cvar_Get( "r_lensflare", "1", CVAR_ARCHIVE );
@@ -1637,8 +1571,14 @@ void R_Register( void )
 
 	r_minimap_size = Cvar_Get ("r_minimap_size", "256", CVAR_ARCHIVE );
 	r_minimap_zoom = Cvar_Get ("r_minimap_zoom", "1", CVAR_ARCHIVE );
-	r_minimap_style = Cvar_Get ("r_minimap_style", "1", CVAR_ARCHIVE );  
-    r_minimap = Cvar_Get ("r_minimap", "0", CVAR_ARCHIVE ); 
+	r_minimap_style = Cvar_Get ("r_minimap_style", "1", CVAR_ARCHIVE );
+	r_minimap = Cvar_Get ("r_minimap", "0", CVAR_ARCHIVE );
+
+	sys_priority = Cvar_Get("sys_priority", "0", CVAR_ARCHIVE);
+	sys_affinity = Cvar_Get("sys_affinity", "1", CVAR_ARCHIVE);
+
+	gl_screenshot_type = Cvar_Get("gl_screenshot_type", "jpeg", CVAR_ARCHIVE);
+	gl_screenshot_jpeg_quality = Cvar_Get("gl_screenshot_jpeg_quality", "85", CVAR_ARCHIVE);
 
 	Cmd_AddCommand( "imagelist", GL_ImageList_f );
 	Cmd_AddCommand( "screenshot", GL_ScreenShot_f );
@@ -1705,7 +1645,7 @@ R_Init
 ===============
 */
 int R_Init( void *hinstance, void *hWnd )
-{	
+{
 	char renderer_buffer[1000];
 	char vendor_buffer[1000];
 	int		err;
@@ -1731,7 +1671,7 @@ int R_Init( void *hinstance, void *hWnd )
 	if ( !QGL_Init( gl_driver->string ) )
 	{
 		QGL_Shutdown();
-        Com_Printf ("ref_gl::R_Init() - could not load \"%s\"\n", gl_driver->string );
+		Com_Printf ("ref_gl::R_Init() - could not load \"%s\"\n", gl_driver->string );
 		return -1;
 	}
 
@@ -1749,7 +1689,7 @@ int R_Init( void *hinstance, void *hWnd )
 	if ( !R_SetMode () )
 	{
 		QGL_Shutdown();
-        Com_Printf ("ref_gl::R_Init() - could not R_SetMode()\n" );
+		Com_Printf ("ref_gl::R_Init() - could not R_SetMode()\n" );
 		return -1;
 	}
 
@@ -1797,26 +1737,9 @@ int R_Init( void *hinstance, void *hWnd )
 	else
 		gl_config.renderer = GL_RENDERER_OTHER;
 
-	if ( toupper( gl_monolightmap->string[1] ) != 'F' )
-	{
-		if ( gl_config.renderer == GL_RENDERER_PERMEDIA2 )
-		{
-			Cvar_Set( "gl_monolightmap", "A" );
-			Com_Printf ("...using gl_monolightmap 'a'\n" );
-		}
-		else if ( gl_config.renderer & GL_RENDERER_POWERVR ) 
-		{
-			Cvar_Set( "gl_monolightmap", "0" );
-		}
-		else
-		{
-			Cvar_Set( "gl_monolightmap", "0" );
-		}
-	}
-
 	// power vr can't have anything stay in the framebuffer, so
 	// the screen needs to redraw the tiled background every frame
-	if ( gl_config.renderer & GL_RENDERER_POWERVR ) 
+	if ( gl_config.renderer & GL_RENDERER_POWERVR )
 	{
 		Cvar_Set( "scr_drawall", "1" );
 	}
@@ -1825,10 +1748,6 @@ int R_Init( void *hinstance, void *hWnd )
 		Cvar_Set( "scr_drawall", "0" );
 	}
 
-#ifdef __unix__
-	Cvar_SetValue( "gl_finish", 1 );
-#endif
-
 	// MCD has buffering issues
 	if ( gl_config.renderer == GL_RENDERER_MCD )
 	{
@@ -1855,7 +1774,7 @@ int R_Init( void *hinstance, void *hWnd )
 	/*
 	** grab extensions
 	*/
-	if ( strstr( gl_config.extensions_string, "GL_EXT_compiled_vertex_array" ) || 
+	if ( strstr( gl_config.extensions_string, "GL_EXT_compiled_vertex_array" ) ||
 		 strstr( gl_config.extensions_string, "GL_SGI_compiled_vertex_array" ) )
 	{
 		Com_Printf ("...enabling GL_EXT_compiled_vertex_array\n" );
@@ -1887,7 +1806,7 @@ int R_Init( void *hinstance, void *hWnd )
 			qglPointParameterfEXT = (void(APIENTRY*)(GLenum, GLfloat))qwglGetProcAddress("glPointParameterfEXT");
 			qglPointParameterfvEXT = (void(APIENTRY*)(GLenum, const GLfloat*))qwglGetProcAddress("glPointParameterfvEXT");
 
-	
+
 		}
 		else
 		{
@@ -1920,7 +1839,7 @@ int R_Init( void *hinstance, void *hWnd )
 #endif
 
 	if ( !qglColorTableEXT &&
-		strstr( gl_config.extensions_string, "GL_EXT_paletted_texture" ) && 
+		strstr( gl_config.extensions_string, "GL_EXT_paletted_texture" ) &&
 		strstr( gl_config.extensions_string, "GL_EXT_shared_texture_palette" ) )
 	{
 		if ( gl_ext_palettedtexture->value )
@@ -2070,8 +1989,8 @@ int R_Init( void *hinstance, void *hWnd )
 	{
 		Com_Printf("...using GL_NV_texture_shader\n");
 		gl_state.texshaders=true;
-	} 
-	else 
+	}
+	else
 	{
 		Com_Printf("...GL_NV_texture_shader not found\n");
 		gl_state.texshaders=false;
@@ -2101,7 +2020,7 @@ int R_Init( void *hinstance, void *hWnd )
 		{
 			gl_state.fragment_program = false;
 			Com_Printf("...GL_ARB_fragment_program not found\n");
-			
+
 		}
 	}
 	else
@@ -2432,7 +2351,7 @@ void R_RenderGlowEffects (void)
 		for (i = 16; i >= 0; i--)
 		{
 			for (j = 0; j < 3; j++)
-				v[j] = glow_effects[k].origin[j] + vright[j] * glowcos[i] * 
+				v[j] = glow_effects[k].origin[j] + vright[j] * glowcos[i] *
 					glow_effects[k].radius + vup[j] * glowsin[i] * glow_effects[k].radius;
 
 			qglVertex3fv (v);
