@@ -24,7 +24,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 model_t	*loadmodel;
 int		modfilelen;
 
-void Mod_LoadSpriteModel (model_t *mod, void *buffer);
 void Mod_LoadBrushModel (model_t *mod, void *buffer);
 void Mod_LoadAliasModel (model_t *mod, void *buffer);
 model_t *Mod_LoadModel (model_t *mod, qboolean crash);
@@ -425,11 +424,6 @@ model_t *Mod_ForName (char *name, qboolean crash)
 		Mod_LoadAliasModel (mod, buf);
 		break;
 		
-	case IDSPRITEHEADER:
-		loadmodel->extradata = Hunk_Begin (0x10000);
-		Mod_LoadSpriteModel (mod, buf);
-		break;
-	
 	case IDBSPHEADER:
 		loadmodel->extradata = Hunk_Begin (0x1000000);
 		Mod_LoadBrushModel (mod, buf);
@@ -1443,53 +1437,6 @@ void Mod_LoadAliasModel (model_t *mod, void *buffer)
 	mod->maxs[1] = 32;
 	mod->maxs[2] = 32;
 }
-/*
-==============================================================================
-
-SPRITE MODELS
-
-==============================================================================
-*/
-
-/*
-=================
-Mod_LoadSpriteModel
-=================
-*/
-void Mod_LoadSpriteModel (model_t *mod, void *buffer)
-{
-	dsprite_t	*sprin, *sprout;
-	int			i;
-
-	sprin = (dsprite_t *)buffer;
-	sprout = Hunk_Alloc (modfilelen);
-
-	sprout->ident = LittleLong (sprin->ident);
-	sprout->version = LittleLong (sprin->version);
-	sprout->numframes = LittleLong (sprin->numframes);
-
-	if (sprout->version != SPRITE_VERSION)
-		Com_Error (ERR_DROP, "%s has wrong version number (%i should be %i)",
-				 mod->name, sprout->version, SPRITE_VERSION);
-
-	if (sprout->numframes > MAX_MD2SKINS)
-		Com_Error (ERR_DROP, "%s has too many frames (%i > %i)",
-				 mod->name, sprout->numframes, MAX_MD2SKINS);
-
-	// byte swap everything
-	for (i=0 ; i<sprout->numframes ; i++)
-	{
-		sprout->frames[i].width = LittleLong (sprin->frames[i].width);
-		sprout->frames[i].height = LittleLong (sprin->frames[i].height);
-		sprout->frames[i].origin_x = LittleLong (sprin->frames[i].origin_x);
-		sprout->frames[i].origin_y = LittleLong (sprin->frames[i].origin_y);
-		memcpy (sprout->frames[i].name, sprin->frames[i].name, MAX_SKINNAME);
-		mod->skins[i] = GL_FindImage (sprout->frames[i].name,
-			it_sprite);
-	}
-
-	mod->type = mod_sprite;
-}
 
 //=============================================================================
 
@@ -1517,14 +1464,14 @@ void R_BeginRegistration (char *model)
 {
 	char	fullname[MAX_QPATH];
 	cvar_t	*flushmap;
-	FILE *file;
-	int i;
+	FILE	*file;
+	int		i;
 
 	registration_sequence++;
 	r_oldviewcluster = -1;		// force markleafs
 
-	//check for fog file.  We'll probably make this alot more involved eventually.
-	Com_sprintf(fullname, sizeof(fullname), "data1/maps/scripts/%s.fog", model);
+	//check for fog file. (gamedir first) 
+	Com_sprintf(fullname, sizeof(fullname), "%s/maps/scripts/%s.fog", FS_Gamedir(), model);
 	i = 0;
 	do
 		fullname[i] = tolower(fullname[i]);
@@ -1538,24 +1485,63 @@ void R_BeginRegistration (char *model)
 		map_fog = true;
 	}
 	else
-
 		map_fog = false;
 
+	if(!map_fog) {
+		//check for fog file.  
+		Com_sprintf(fullname, sizeof(fullname), "%s/maps/scripts/%s.fog", BASEDIRNAME, model);
+		i = 0;
+		do
+			fullname[i] = tolower(fullname[i]);
+		while (fullname[i++]);
+
+		R_FindFile (fullname, &file); //does a fogfile exist?
+		if(file) {
+			//read the file, get fog information
+			fclose(file);
+			R_ReadFogScript(fullname);
+			map_fog = true;
+		}
+		else
+			map_fog = false;
+	}
+	
+
 	//check for music file.
-	Com_sprintf(fullname, sizeof(fullname), "data1/maps/scripts/%s.mus", model);
+	Com_sprintf(fullname, sizeof(fullname), "%s/maps/scripts/%s.mus", FS_Gamedir(), model);
 	i = 0;
 	do
 		fullname[i] = tolower(fullname[i]);
 	while (fullname[i++]);
 
-	R_FindFile (fullname, &file); //does a fogfile exist?
+	R_FindFile (fullname, &file); //does a music file exist?
 	if(file) {
 		//read the file, get music information
 		fclose(file);
 		R_ReadMusicScript(fullname);
+
 	}
-	else
+	else {
 		strcpy(map_music, "music/none.wav");
+	}
+
+	if(!strcmp(map_music, "music/none.wav")) {
+		//check for music file.
+		Com_sprintf(fullname, sizeof(fullname), "%s/maps/scripts/%s.mus", BASEDIRNAME, model);
+		i = 0;
+		do
+			fullname[i] = tolower(fullname[i]);
+		while (fullname[i++]);
+
+		R_FindFile (fullname, &file); //does a fogfile exist?
+		if(file) {
+			//read the file, get music information
+			fclose(file);
+			R_ReadMusicScript(fullname);
+		}
+		else
+			strcpy(map_music, "music/none.wav");
+	}
 
 	Com_sprintf (fullname, sizeof(fullname), "maps/%s.bsp", model);
 
@@ -1565,7 +1551,7 @@ void R_BeginRegistration (char *model)
 
 	if ( strcmp(mod_known[0].name, fullname) || flushmap->value)
 		Mod_Free (&mod_known[0]);
-	else if (arena_mode)
+	else
 		Mod_Free (&mod_known[0]);	//do it every time to fix shader bugs in AA
 
 	r_worldmodel = Mod_ForName(fullname, true);
@@ -1584,7 +1570,6 @@ struct model_s *R_RegisterModel (char *name)
 {
 	model_t	*mod;
 	int		i;
-	dsprite_t	*sprout;
 	dmdl_t		*pheader;
 
 	mod = Mod_ForName (name, false);
@@ -1593,13 +1578,7 @@ struct model_s *R_RegisterModel (char *name)
 		mod->registration_sequence = registration_sequence;
 
 		// register any images used by the models
-		if (mod->type == mod_sprite)
-		{
-			sprout = (dsprite_t *)mod->extradata;
-			for (i=0 ; i<sprout->numframes ; i++)
-				mod->skins[i] = GL_FindImage (sprout->frames[i].name, it_sprite);
-		}
-		else if (mod->type == mod_alias)
+		if (mod->type == mod_alias)
 		{
 			pheader = (dmdl_t *)mod->extradata;
 			for (i=0 ; i<pheader->num_skins ; i++)
